@@ -35,6 +35,7 @@ class AnyBase {
 public:
     AnyBase() = default;
     virtual ~AnyBase() = default;
+    AnyBase& operator=(const AnyBase& other);
 
     //! For values which are derived from an input file, set the line and column
     //! of this value in that file. Used for providing context for some error
@@ -250,6 +251,9 @@ public:
     template<class T>
     AnyValue& operator=(const map<string, T> items);
 
+    //! @see AnyMap::exclude()
+    static AnyValue exclude();
+
     //! Return the held `AnyMap` as a `map` where all of the values have
     //! the specified type.
     template<class T>
@@ -469,8 +473,13 @@ public:
 
     //! Add items from `other` to this AnyMap. If keys in `other` also exist in
     //! this AnyMap, the `keepExisting` option determines which item is used.
+    //! Local units defined in `other` are not retained.
     void update(const AnyMap& other, bool keepExisting=true);
 
+    //! Mark `key` as excluded from this map. This prevents `key` from being added
+    //! by update(). Explicitly setting a value for `key` overrides this exclusion.
+    void exclude(const string& key);
+
     //! Return a string listing the keys in this AnyMap, for use in error
     //! messages, for example
     string keys_str() const;
@@ -576,7 +585,7 @@ public:
     class OrderedProxy {
     public:
         OrderedProxy() {}
-        OrderedProxy(const AnyMap& data);
+        OrderedProxy(const AnyMap& data, bool withUnits);
         OrderedIterator begin() const;
         OrderedIterator end() const;
 
@@ -613,15 +622,16 @@ public:
         OrderedProxy::OrderVector::const_iterator m_stop;
     };
 
-    // Return a proxy object that allows iteration in an order determined by the
-    // order of insertion, the location in an input file, and rules specified by
-    // the addOrderingRules() method.
-    OrderedProxy ordered() const { return OrderedProxy(*this); }
+    //! Return a proxy object that allows iteration in an order determined by the order
+    //! of insertion, the location in an input file, and rules specified by the
+    //! addOrderingRules() method. The `withUnits` flag determines whether to include a
+    //! `units` directive, if any local units are defined (for use by the YAML emitter).
+    OrderedProxy ordered(bool withUnits=false) const {
+        return OrderedProxy(*this, withUnits);
+    }
 
     //! Returns the number of elements in this map
-    size_t size() const {
-        return m_data.size();
-    };
+    size_t size() const;
 
     bool operator==(const AnyMap& other) const;
     bool operator!=(const AnyMap& other) const;
@@ -667,7 +677,8 @@ public:
      * Enables specifying keys that should appear at either the beginning
      * or end of the generated YAML mapping. Only programmatically-added keys
      * are rearranged. Keys which come from YAML input retain their existing
-     * ordering, and are output after programmatically-added keys.
+     * ordering, and are output after programmatically-added keys. Keys are
+     * output in the order provided to this method.
      *
      * This function should be called exactly once for any given spec that
      * is to be added. To facilitate this, the method returns a bool so that
@@ -746,7 +757,8 @@ public:
         : CanteraError(
             procedure,
             formatError(
-                (sizeof...(args) == 0) ? message : fmt::format(message, args...),
+                (sizeof...(args) == 0) ? message
+                                       : fmt::format(fmt::runtime(message), args...),
                 node.m_line, node.m_column, node.m_metadata))
         {
         }
@@ -761,7 +773,8 @@ public:
         : CanteraError(
             procedure,
             formatError2(
-                (sizeof...(args) == 0) ? message : fmt::format(message, args...),
+                (sizeof...(args) == 0) ? message
+                                       : fmt::format(fmt::runtime(message), args...),
                 node1.m_line, node1.m_column, node1.m_metadata,
                 node2.m_line, node2.m_column, node2.m_metadata))
         {
