@@ -53,16 +53,12 @@ class AnyMap;
  *      function.
  *
  * %Cantera input files are written using YAML syntax. For more information on using
- * YAML files in %Cantera, see the
- * [YAML Users' Guide](https://cantera.org/tutorials/yaml/defining-phases.html)
- * or the [YAML Input File API Reference](../../../../sphinx/html/yaml/index.html).
- * %Cantera provides the
- * [`ck2yaml`](https://cantera.org/tutorials/ck2yaml-tutorial.html)
- * tool for converting Chemkin-format mechanisms to the YAML format. The utilities
- * [`cti2yaml`](https://cantera.org/tutorials/legacy2yaml.html#cti2yaml) and
- * [`ctml2yaml`](https://cantera.org/tutorials/legacy2yaml.html#ctml2yaml) should be
- * used to convert legacy CTI and XML input files (from %Cantera 2.6 and earlier) to the
- * YAML format.
+ * YAML files in %Cantera, see the [YAML Users' Guide](../userguide/input-tutorial.html)
+ * or the [YAML Input File API Reference](../yaml/index.html). %Cantera provides the
+ * [`ck2yaml`](../userguide/ck2yaml-tutorial.html) tool for converting Chemkin-format
+ * mechanisms to the YAML format. The utilities [`cti2yaml`](../yaml/cti2yaml.html) and
+ * [`ctml2yaml`](../yaml/ctml2yaml.html) should be used to convert legacy CTI and XML
+ * input files (from %Cantera 2.6 and earlier) to the YAML format.
  *
  * @ingroup ioGroup
  * @{
@@ -176,7 +172,7 @@ void writelog(const string& fmt, const Args&... args) {
     if (sizeof...(args) == 0) {
         writelog_direct(fmt);
     } else {
-        writelog_direct(fmt::format(fmt, args...));
+        writelog_direct(fmt::format(fmt::runtime(fmt), args...));
     }
 }
 
@@ -228,7 +224,7 @@ void warn_deprecated(const string& method, const string& msg, const Args&... arg
     if (sizeof...(args) == 0) {
         _warn_deprecated(method, msg);
     } else {
-        _warn_deprecated(method, fmt::format(msg, args...));
+        _warn_deprecated(method, fmt::format(fmt::runtime(msg), args...));
     }
 }
 
@@ -253,7 +249,7 @@ void warn(const string& warning, const string& method,
     if (sizeof...(args) == 0) {
         _warn(warning, method, msg);
     } else {
-        _warn(warning, method, fmt::format(msg, args...));
+        _warn(warning, method, fmt::format(fmt::runtime(msg), args...));
     }
 }
 
@@ -268,7 +264,7 @@ void warn_user(const string& method, const string& msg, const Args&... args) {
     if (sizeof...(args) == 0) {
         _warn("Cantera", method, msg);
     } else {
-        _warn("Cantera", method, fmt::format(msg, args...));
+        _warn("Cantera", method, fmt::format(fmt::runtime(msg), args...));
     }
 }
 
