@@ -94,6 +94,8 @@ class InterfaceRateBase
 public:
     InterfaceRateBase();
 
+    virtual ~InterfaceRateBase() = default;
+
     //! Perform object setup based on AnyMap node information
     //! @param node  AnyMap object containing reaction rate specification
     void setParameters(const AnyMap& node);
@@ -110,9 +112,7 @@ public:
 
     //! Store parameters needed to reconstruct coverage dependencies
     //! @param dependencies  AnyMap receiving coverage information
-    //! @param asVector  Optional boolean flag to override map output
-    //! @deprecated After %Cantera 3.0, the optional asVector argument will be removed.
-    void getCoverageDependencies(AnyMap& dependencies, bool asVector=false) const;
+    void getCoverageDependencies(AnyMap& dependencies) const;
 
     //! Add a coverage dependency for species *sp*, with exponential dependence
     //! *a*, power-law exponent *m*, and activation energy dependence *e*,
