@@ -16,27 +16,6 @@
 namespace Cantera
 {
 
-// Magic numbers are only used by legacy C API methods
-// Example: traditional MATLAB toolbox
-const int FourierFuncType = 1;
-const int PolyFuncType = 2;
-const int ArrheniusFuncType = 3;
-const int GaussianFuncType = 4;
-const int SumFuncType = 20;
-const int DiffFuncType = 25;
-const int ProdFuncType = 30;
-const int RatioFuncType = 40;
-const int PeriodicFuncType = 50;
-const int CompositeFuncType = 60;
-const int TimesConstantFuncType = 70;
-const int PlusConstantFuncType = 80;
-const int SinFuncType = 100;
-const int CosFuncType = 102;
-const int ExpFuncType = 104;
-const int PowFuncType = 106;
-const int ConstFuncType = 110;
-const int TabulatedFuncType = 120;
-
 class TimesConstant1;
 
 //! @defgroup func1 Functor Objects
@@ -45,8 +24,8 @@ class TimesConstant1;
 //! the implementation of generic mathematical expressions.
 //! @ingroup numerics
 
-//! @defgroup func1simple Simple Functors
-//! Simple functors implement standard mathematical expressions with a single
+//! @defgroup func1basic Basic Functors
+//! Basic functors implement standard mathematical expressions with a single
 //! parameter.
 //! The following simple functor types are implemented:
 //! - @c "sin" (class Sin1), @c "cos" (class Cos1),
@@ -59,7 +38,7 @@ class TimesConstant1;
 //! Advanced functors implement expressions that require multiple parameters.
 //! The following advanced functor types are implemented:
 //! - @c "tabulated-linear" and @c "tabulated-previous" (class Tabulated1),
-//! - @c "polynomial" (class Poly1),
+//! - @c "polynomial3" (class Poly13),
 //! - @c "Fourier" (class Fourier1),
 //! - @c "Gaussian" (class Gaussian1),
 //! - @c "Arrhenius" (class Arrhenius1).
@@ -97,35 +76,14 @@ class Func1
 public:
     Func1() = default;
 
-    Func1(shared_ptr<Func1> f1, shared_ptr<Func1> f2)
-        : m_f1_shared(f1), m_f2_shared(f2)
-    {
-        m_f1 = f1.get();
-        m_f2 = f2.get();
-    }
+    Func1(shared_ptr<Func1> f1, shared_ptr<Func1> f2) : m_f1(f1), m_f2(f2) {}
 
-    Func1(shared_ptr<Func1> f1, double A) : m_c(A), m_f1_shared(f1) {
-        m_f1 = f1.get();
-    }
+    Func1(shared_ptr<Func1> f1, double A) : m_c(A), m_f1(f1) {}
 
     virtual ~Func1() = default;
 
-    //! @deprecated To be removed after %Cantera 3.0. Only used by deprecated methods.
-    Func1(const Func1& right);
-
-    //! @deprecated To be removed after %Cantera 3.0. Only used by deprecated methods.
-    Func1& operator=(const Func1& right);
-
-    //! Duplicate the current function.
-    /*!
-     * This duplicates the current function, returning a reference to the newly
-     * created function.
-     * @deprecated To be removed after %Cantera 3.0. Only used by deprecated methods.
-     */
-    virtual Func1& duplicate() const;
-
-    //! @deprecated To be removed after %Cantera 3.0. Replaced by type.
-    virtual int ID() const;
+    // Func1(const Func1& right) = delete;  //! @todo Uncomment after %Cantera 3.1
+    Func1& operator=(const Func1& right) = delete;
 
     //! Returns a string describing the type of the function
     //! @since New in %Cantera 3.0.
@@ -145,97 +103,68 @@ public:
 
     //! Creates a derivative to the current function
     /*!
-     * This will create a new derivative function and return a reference to the
-     * function.
-     * @deprecated To be changed after %Cantera 3.0; for new behavior, see derivative3.
-     */
-    virtual Func1& derivative() const;
-
-    //! Creates a derivative to the current function
-    /*!
-     * This will create a new derivative function
      * @return  shared pointer to new derivative function.
-     * @since New in %Cantera 3.0.
+     * @since Starting in %Cantera 3.1, the return type is a `shared_ptr`.
      */
-    virtual shared_ptr<Func1> derivative3() const;
+    virtual shared_ptr<Func1> derivative() const;
 
     //! Routine to determine if two functions are the same.
     /*!
-     * Two functions are the same if they are the same function. This means
-     * that the ID and stored constant is the same. This means that the m_f1
-     * and m_f2 are identical if they are non-null.
+     * Two functions are the same if they are the same function. For example, either
+     * ID and stored constant are the same, or the #m_f1 and #m_f2 are identical if they
+     * are non-null. Functors of the base class Func1 are by default not identical, as
+     * they are used by callback functions that cannot be differentiated. In instances
+     * where exact comparisons are not implemented, `false` is returned to prevent false
+     * positives that could lead to incorrect simplifications of compound functors.
      */
-    bool isIdentical(Func1& other) const;
+    virtual bool isIdentical(shared_ptr<Func1> other) const;
 
+    //! Routine to determine if two functions are the same.
+    /*!
+     * @deprecated Deprecated in %Cantera 3.1 and removed thereafter; replaced by
+     *      isIdentical(shared_ptr<Func1>&).
+     * @todo Restore deleted copy constructor after removal.
+     */
+    virtual bool isIdentical(Func1& other) const;
+
+    /**
+     * @deprecated Deprecated in %Cantera 3.1 and removed thereafter; replaced by
+     *      internal function.
+     */
     virtual double isProportional(TimesConstant1& other);
+    /**
+     * @deprecated Deprecated in %Cantera 3.1 and removed thereafter; replaced by
+     *      internal function.
+     */
     virtual double isProportional(Func1& other);
 
     //! Write LaTeX string describing function.
     virtual string write(const string& arg) const;
 
-    //! Accessor function for the stored constant
+    //! Accessor function for the stored constant #m_c.
     double c() const;
 
-    //! Function to set the stored constant
-    //! @deprecated To be removed after %Cantera 3.0. Only used by deprecated methods.
-    void setC(double c);
-
-    //! accessor function for m_f1
-    //! @deprecated To be removed after %Cantera 3.0; replaced by func1_shared().
-    Func1& func1() const;
-
-    //! Accessor function for m_f1_shared
+    //! Accessor function for #m_f1.
     //! @since New in %Cantera 3.0.
     shared_ptr<Func1> func1_shared() const {
-        return m_f1_shared;
+        return m_f1;
     }
 
-    //! accessor function for m_f2
-    //! @deprecated To be removed after %Cantera 3.0. Only used by deprecated methods.
-    Func1& func2() const;
-
-    //! Accessor function for m_f2_shared
+    //! Accessor function for #m_f2.
     //! @since New in %Cantera 3.0.
     shared_ptr<Func1> func2_shared() const {
-        return m_f2_shared;
+        return m_f2;
     }
 
     //! Return the order of the function, if it makes sense
     virtual int order() const;
 
-    //! @deprecated To be removed after %Cantera 3.0. Only used by deprecated methods.
-    Func1& func1_dup() const;
-
-    //! @deprecated To be removed after %Cantera 3.0. Only used by deprecated methods.
-    Func1& func2_dup() const;
-
-    //! @deprecated To be removed after %Cantera 3.0. Only used by deprecated methods.
-    Func1* parent() const;
-
-    //! @deprecated To be removed after %Cantera 3.0. Only used by deprecated methods.
-    void setParent(Func1* p);
-
 protected:
     double m_c = 0.0;
-    Func1* m_f1 = nullptr;
-    Func1* m_f2 = nullptr;
-    Func1* m_parent = nullptr;
-
-    shared_ptr<Func1> m_f1_shared;
-    shared_ptr<Func1> m_f2_shared;
+    shared_ptr<Func1> m_f1;
+    shared_ptr<Func1> m_f2;
 };
 
-
-// all functions using references are deprecated
-Func1& newSumFunction(Func1& f1, Func1& f2);
-Func1& newDiffFunction(Func1& f1, Func1& f2);
-Func1& newProdFunction(Func1& f1, Func1& f2);
-Func1& newRatioFunction(Func1& f1, Func1& f2);
-Func1& newCompositeFunction(Func1& f1, Func1& f2);
-Func1& newTimesConstFunction(Func1& f1, double c);
-Func1& newPlusConstFunction(Func1& f1, double c);
-
-
 //! Sum of two functions.
 //! @ingroup func1helper
 shared_ptr<Func1> newSumFunction(shared_ptr<Func1> f1, shared_ptr<Func1> f2);
@@ -266,10 +195,10 @@ shared_ptr<Func1> newPlusConstFunction(shared_ptr<Func1> f1, double c);
 
 //! Implements the @c sin() function.
 /*!
- * The functor class with type @c "sin" returns @f$ f(x) = \cos(\omega x) @f$,
+ * The functor class with type @c "sin" returns @f$ f(x) = \sin(\omega x) @f$,
  * where the argument @f$ x @f$ is in radians.
  * @param omega  Frequency @f$ \omega @f$ (default=1.0)
- * @ingroup func1simple
+ * @ingroup func1basic
  */
 class Sin1 : public Func1
 {
@@ -281,24 +210,8 @@ public:
     //! Constructor uses single parameter (frequency)
     Sin1(const vector<double>& params);
 
-    Sin1(const Sin1& b) :
-        Func1(b) {
-    }
-
-    Sin1& operator=(const Sin1& right) {
-        if (&right == this) {
-            return *this;
-        }
-        Func1::operator=(right);
-        return *this;
-    }
-
     string write(const string& arg) const override;
 
-    int ID() const override {
-        return SinFuncType;
-    }
-
     string type() const override {
         return "sin";
     }
@@ -307,9 +220,7 @@ public:
         return sin(m_c*t);
     }
 
-    Func1& duplicate() const override;
-    Func1& derivative() const override;
-    shared_ptr<Func1> derivative3() const override;
+    shared_ptr<Func1> derivative() const override;
 };
 
 
@@ -318,7 +229,7 @@ public:
  * The functor class with type @c "cos" returns @f$ f(x) = \cos(\omega x) @f$,
  * where the argument @f$ x @f$ is in radians.
  * @param omega  Frequency @f$ \omega @f$ (default=1.0)
- * @ingroup func1simple
+ * @ingroup func1basic
  */
 class Cos1 : public Func1
 {
@@ -330,23 +241,8 @@ public:
     //! Constructor uses single parameter (frequency)
     Cos1(const vector<double>& params);
 
-    Cos1(const Cos1& b) :
-        Func1(b) {
-    }
-
-    Cos1& operator=(const Cos1& right) {
-        if (&right == this) {
-            return *this;
-        }
-        Func1::operator=(right);
-        return *this;
-    }
-
-    Func1& duplicate() const override;
     string write(const string& arg) const override;
-    int ID() const override {
-        return CosFuncType;
-    }
+
     string type() const override {
         return "cos";
     }
@@ -354,8 +250,7 @@ public:
     double eval(double t) const override {
         return cos(m_c * t);
     }
-    Func1& derivative() const override;
-    shared_ptr<Func1> derivative3() const override;
+    shared_ptr<Func1> derivative() const override;
 };
 
 
@@ -363,7 +258,7 @@ public:
 /*!
  * The functor class with type @c "exp" returns @f$ f(x) = \exp(a x) @f$.
  * @param a  Factor (default=1.0)
- * @ingroup func1simple
+ * @ingroup func1basic
  */
 class Exp1 : public Func1
 {
@@ -375,20 +270,8 @@ public:
     //! Constructor uses single parameter (exponent factor)
     Exp1(const vector<double>& params);
 
-    Exp1(const Exp1& b) :
-        Func1(b) {
-    }
-    Exp1& operator=(const Exp1& right) {
-        if (&right == this) {
-            return *this;
-        }
-        Func1::operator=(right);
-        return *this;
-    }
     string write(const string& arg) const override;
-    int ID() const override {
-        return ExpFuncType;
-    }
+
     string type() const override {
         return "exp";
     }
@@ -397,9 +280,7 @@ public:
         return exp(m_c*t);
     }
 
-    Func1& duplicate() const override;
-    Func1& derivative() const override;
-    shared_ptr<Func1> derivative3() const override;
+    shared_ptr<Func1> derivative() const override;
 };
 
 
@@ -407,7 +288,7 @@ public:
 /*!
  * The functor class with type @c "log" returns @f$ f(x) = \ln(a x) @f$.
  * @param a  Factor (default=1.0)
- * @ingroup func1simple
+ * @ingroup func1basic
  * @since New in %Cantera 3.0
  */
 class Log1 : public Func1
@@ -428,7 +309,7 @@ public:
         return log(m_c * t);
     }
 
-    shared_ptr<Func1> derivative3() const override;
+    shared_ptr<Func1> derivative() const override;
 
     string write(const string& arg) const override;
 };
@@ -437,7 +318,7 @@ public:
 /*!
  * The functor class with type @c "pow" returns @f$ f(x) = x^n @f$.
  * @param n  Exponent
- * @ingroup func1simple
+ * @ingroup func1basic
  */
 class Pow1 : public Func1
 {
@@ -449,20 +330,8 @@ public:
     //! Constructor uses single parameter (exponent)
     Pow1(const vector<double>& params);
 
-    Pow1(const Pow1& b) :
-        Func1(b) {
-    }
-    Pow1& operator=(const Pow1& right) {
-        if (&right == this) {
-            return *this;
-        }
-        Func1::operator=(right);
-        return *this;
-    }
     string write(const string& arg) const override;
-    int ID() const override {
-        return PowFuncType;
-    }
+
     string type() const override {
         return "pow";
     }
@@ -470,9 +339,7 @@ public:
     double eval(double t) const override {
         return pow(t, m_c);
     }
-    Func1& duplicate() const override;
-    Func1& derivative() const override;
-    shared_ptr<Func1> derivative3() const override;
+    shared_ptr<Func1> derivative() const override;
 };
 
 //! Implements a tabulated function.
@@ -509,10 +376,12 @@ public:
     //! @since New in %Cantera 3.0
     void setMethod(const string& method);
 
-    string write(const string& arg) const override;
-    int ID() const override {
-        return TabulatedFuncType;
+    bool isIdentical(shared_ptr<Func1> other) const override {
+        return false;  // base class check is insufficient
     }
+
+    string write(const string& arg) const override;
+
     string type() const override {
         if (m_isLinear) {
             return "tabulated-linear";
@@ -521,9 +390,7 @@ public:
     }
 
     double eval(double t) const override;
-    Func1& duplicate() const override;
-    Func1& derivative() const override;
-    shared_ptr<Func1> derivative3() const override;
+    shared_ptr<Func1> derivative() const override;
 private:
     vector<double> m_tvec; //!< Vector of time values
     vector<double> m_fvec; //!< Vector of function values
@@ -535,7 +402,7 @@ private:
 /*!
  * The functor class with type @c "constant" returns @f$ f(x) = a @f$.
  * @param a  Constant
- * @ingroup func1simple
+ * @ingroup func1basic
  */
 class Const1 : public Func1
 {
@@ -547,22 +414,8 @@ public:
     //! Constructor uses single parameter (constant)
     Const1(const vector<double>& params);
 
-    Const1(const Const1& b) :
-        Func1(b) {
-    }
-
-    Const1& operator=(const Const1& right) {
-        if (&right == this) {
-            return *this;
-        }
-        Func1::operator=(right);
-        return *this;
-    }
-
     string write(const string& arg) const override;
-    int ID() const override {
-        return ConstFuncType;
-    }
+
     string type() const override {
         return "constant";
     }
@@ -570,9 +423,7 @@ public:
     double eval(double t) const override {
         return m_c;
     }
-    Func1& duplicate() const override;
-    Func1& derivative() const override;
-    shared_ptr<Func1> derivative3() const override {
+    shared_ptr<Func1> derivative() const override {
         return make_shared<Const1>(0.0);
     }
 };
@@ -588,45 +439,8 @@ public:
 class Sum1 : public Func1
 {
 public:
-    Sum1(Func1& f1, Func1& f2) {
-        m_f1 = &f1;
-        m_f2 = &f2;
-        m_f1->setParent(this);
-        m_f2->setParent(this);
-    }
-
     Sum1(shared_ptr<Func1> f1, shared_ptr<Func1> f2) : Func1(f1, f2) {}
 
-    ~Sum1() override {
-        if (!m_f1_shared) {
-            delete m_f1;
-        }
-        if (!m_f2_shared) {
-            delete m_f2;
-        }
-    }
-
-    Sum1(const Sum1& b) :
-        Func1(b) {
-        *this = Sum1::operator=(b);
-    }
-
-    Sum1& operator=(const Sum1& right) {
-        if (&right == this) {
-            return *this;
-        }
-        Func1::operator=(right);
-        m_f1 = &m_f1->duplicate();
-        m_f2 = &m_f2->duplicate();
-        m_f1->setParent(this);
-        m_f2->setParent(this);
-        m_parent = 0;
-        return *this;
-    }
-
-    int ID() const override {
-        return SumFuncType;
-    }
     string type() const override {
         return "sum";
     }
@@ -635,11 +449,8 @@ public:
         return m_f1->eval(t) + m_f2->eval(t);
     }
 
-    Func1& duplicate() const override;
-    Func1& derivative() const override;
-
-    shared_ptr<Func1> derivative3() const override {
-        return newSumFunction(m_f1_shared->derivative3(), m_f2_shared->derivative3());
+    shared_ptr<Func1> derivative() const override {
+        return newSumFunction(m_f1->derivative(), m_f2->derivative());
     }
 
     int order() const override {
@@ -659,46 +470,8 @@ public:
 class Diff1 : public Func1
 {
 public:
-    Diff1(Func1& f1, Func1& f2) {
-        m_f1 = &f1;
-        m_f2 = &f2;
-        m_f1->setParent(this);
-        m_f2->setParent(this);
-    }
-
     Diff1(shared_ptr<Func1> f1, shared_ptr<Func1> f2) : Func1(f1, f2) {}
 
-    ~Diff1() override {
-        if (!m_f1_shared) {
-            delete m_f1;
-        }
-        if (!m_f2_shared) {
-            delete m_f2;
-        }
-    }
-
-    Diff1(const Diff1& b) :
-        Func1(b) {
-        *this = Diff1::operator=(b);
-    }
-
-    Diff1& operator=(const Diff1& right) {
-        if (&right == this) {
-            return *this;
-        }
-        Func1::operator=(right);
-        m_f1 = &m_f1->duplicate();
-        m_f2 = &m_f2->duplicate();
-        m_f1->setParent(this);
-        m_f2->setParent(this);
-        m_parent = 0;
-        return *this;
-    }
-
-    int ID() const override {
-        return DiffFuncType;
-    }
-
     string type() const override {
         return "diff";
     }
@@ -707,11 +480,8 @@ public:
         return m_f1->eval(t) - m_f2->eval(t);
     }
 
-    Func1& duplicate() const override;
-    Func1& derivative() const override;
-
-    shared_ptr<Func1> derivative3() const override {
-        return newDiffFunction(m_f1_shared->derivative3(), m_f2_shared->derivative3());
+    shared_ptr<Func1> derivative() const override {
+        return newDiffFunction(m_f1->derivative(), m_f2->derivative());
     }
 
     int order() const override {
@@ -732,46 +502,8 @@ public:
 class Product1 : public Func1
 {
 public:
-    Product1(Func1& f1, Func1& f2) {
-        m_f1 = &f1;
-        m_f2 = &f2;
-        m_f1->setParent(this);
-        m_f2->setParent(this);
-    }
-
     Product1(shared_ptr<Func1> f1, shared_ptr<Func1> f2) : Func1(f1, f2) {}
 
-    ~Product1() override {
-        if (!m_f1_shared) {
-            delete m_f1;
-        }
-        if (!m_f2_shared) {
-            delete m_f2;
-        }
-    }
-
-    Product1(const Product1& b) :
-        Func1(b) {
-        *this = Product1::operator=(b);
-    }
-
-    Product1& operator=(const Product1& right) {
-        if (&right == this) {
-            return *this;
-        }
-        Func1::operator=(right);
-        m_f1 = &m_f1->duplicate();
-        m_f2 = &m_f2->duplicate();
-        m_f1->setParent(this);
-        m_f2->setParent(this);
-        m_parent = 0;
-        return *this;
-    }
-
-    int ID() const override {
-        return ProdFuncType;
-    }
-
     string type() const override {
         return "product";
     }
@@ -782,10 +514,7 @@ public:
         return m_f1->eval(t) * m_f2->eval(t);
     }
 
-    Func1& duplicate() const override;
-    Func1& derivative() const override;
-
-    shared_ptr<Func1> derivative3() const override;
+    shared_ptr<Func1> derivative() const override;
 
     int order() const override {
         return 1;
@@ -802,44 +531,14 @@ public:
 class TimesConstant1 : public Func1
 {
 public:
-    TimesConstant1(Func1& f1, double a) {
-        m_f1 = &f1;
-        m_c = a;
-        m_f1->setParent(this);
-    }
-
     TimesConstant1(shared_ptr<Func1> f1, double a) : Func1(f1, a) {}
 
-    ~TimesConstant1() override {
-        if (!m_f1_shared) {
-            delete m_f1;
-        }
-    }
-
-    TimesConstant1(const TimesConstant1& b) :
-        Func1(b) {
-        *this = TimesConstant1::operator=(b);
-    }
-
-    TimesConstant1& operator=(const TimesConstant1& right) {
-        if (&right == this) {
-            return *this;
-        }
-        Func1::operator=(right);
-        m_f1 = &m_f1->duplicate();
-        m_f1->setParent(this);
-        m_parent = 0;
-        return *this;
-    }
-    int ID() const override {
-        return TimesConstantFuncType;
-    }
     string type() const override {
         return "times-constant";
     }
 
     double isProportional(TimesConstant1& other) override {
-        if (func1().isIdentical(other.func1())) {
+        if (func1_shared()->isIdentical(*other.func1_shared())) {
             return (other.c()/c());
         } else {
             return 0.0;
@@ -847,7 +546,7 @@ public:
     }
 
     double isProportional(Func1& other) override {
-        if (func1().isIdentical(other)) {
+        if (func1_shared()->isIdentical(other)) {
             return 1.0/c();
         } else {
             return 0.0;
@@ -858,11 +557,8 @@ public:
         return m_f1->eval(t) * m_c;
     }
 
-    Func1& duplicate() const override;
-    Func1& derivative() const override;
-
-    shared_ptr<Func1> derivative3() const override {
-        return newTimesConstFunction(m_f1_shared->derivative3(), m_c);
+    shared_ptr<Func1> derivative() const override {
+        return newTimesConstFunction(m_f1->derivative(), m_c);
     }
 
     string write(const string& arg) const override;
@@ -882,39 +578,8 @@ public:
 class PlusConstant1 : public Func1
 {
 public:
-    PlusConstant1(Func1& f1, double a) {
-        m_f1 = &f1;
-        m_c = a;
-        m_f1->setParent(this);
-    }
-
     PlusConstant1(shared_ptr<Func1> f1, double a) : Func1(f1, a) {}
 
-    ~PlusConstant1() override {
-        if (!m_f1_shared) {
-            delete m_f1;
-        }
-    }
-
-    PlusConstant1(const PlusConstant1& b) :
-        Func1(b) {
-        *this = PlusConstant1::operator=(b);
-    }
-
-    PlusConstant1& operator=(const PlusConstant1& right) {
-        if (&right == this) {
-            return *this;
-        }
-        Func1::operator=(right);
-        m_f1 = &m_f1->duplicate();
-        m_f1->setParent(this);
-        m_parent = 0;
-        return *this;
-    }
-
-    int ID() const override {
-        return PlusConstantFuncType;
-    }
     string type() const override {
         return "plus-constant";
     }
@@ -923,11 +588,8 @@ public:
         return m_f1->eval(t) + m_c;
     }
 
-    Func1& duplicate() const override;
-    Func1& derivative() const override;
-
-    shared_ptr<Func1> derivative3() const override {
-        return m_f1_shared->derivative3();
+    shared_ptr<Func1> derivative() const override {
+        return m_f1->derivative();
     }
 
     string write(const string& arg) const override;
@@ -948,45 +610,8 @@ public:
 class Ratio1 : public Func1
 {
 public:
-    Ratio1(Func1& f1, Func1& f2) {
-        m_f1 = &f1;
-        m_f2 = &f2;
-        m_f1->setParent(this);
-        m_f2->setParent(this);
-    }
-
     Ratio1(shared_ptr<Func1> f1, shared_ptr<Func1> f2) : Func1(f1, f2) {}
 
-    ~Ratio1() override {
-        if (!m_f1_shared) {
-            delete m_f1;
-        }
-        if (!m_f2_shared) {
-            delete m_f2;
-        }
-    }
-
-    Ratio1(const Ratio1& b) :
-        Func1(b) {
-        *this = Ratio1::operator=(b);
-    }
-
-    Ratio1& operator=(const Ratio1& right) {
-        if (&right == this) {
-            return *this;
-        }
-        Func1::operator=(right);
-        m_f1 = &m_f1->duplicate();
-        m_f2 = &m_f2->duplicate();
-        m_f1->setParent(this);
-        m_f2->setParent(this);
-        m_parent = 0;
-        return *this;
-    }
-
-    int ID() const override {
-        return RatioFuncType;
-    }
     string type() const override {
         return "ratio";
     }
@@ -995,10 +620,7 @@ public:
         return m_f1->eval(t) / m_f2->eval(t);
     }
 
-    Func1& duplicate() const override;
-    Func1& derivative() const override;
-
-    shared_ptr<Func1> derivative3() const override;
+    shared_ptr<Func1> derivative() const override;
 
     string write(const string& arg) const override;
 
@@ -1017,45 +639,8 @@ public:
 class Composite1 : public Func1
 {
 public:
-    Composite1(Func1& f1, Func1& f2) {
-        m_f1 = &f1;
-        m_f2 = &f2;
-        m_f1->setParent(this);
-        m_f2->setParent(this);
-    }
-
     Composite1(shared_ptr<Func1> f1, shared_ptr<Func1> f2) : Func1(f1, f2) {}
 
-    ~Composite1() override {
-        if (!m_f1_shared) {
-            delete m_f1;
-        }
-        if (!m_f2_shared) {
-            delete m_f2;
-        }
-    }
-
-    Composite1(const Composite1& b) :
-        Func1(b) {
-        *this = Composite1::operator=(b);
-    }
-
-    Composite1& operator=(const Composite1& right) {
-        if (&right == this) {
-            return *this;
-        }
-        Func1::operator=(right);
-        m_f1 = &m_f1->duplicate();
-        m_f2 = &m_f2->duplicate();
-        m_f1->setParent(this);
-        m_f2->setParent(this);
-        m_parent = 0;
-        return *this;
-    }
-
-    int ID() const override {
-        return CompositeFuncType;
-    }
     string type() const override {
         return "composite";
     }
@@ -1064,10 +649,7 @@ public:
         return m_f1->eval(m_f2->eval(t));
     }
 
-    Func1& duplicate() const override;
-    Func1& derivative() const override;
-
-    shared_ptr<Func1> derivative3() const override;
+    shared_ptr<Func1> derivative() const override;
 
     string write(const string& arg) const override;
 
@@ -1105,27 +687,14 @@ public:
     //! @f$ [A, t_0, \mathrm{fwhm}] @f$
     Gaussian1(const vector<double>& params);
 
-    Gaussian1(const Gaussian1& b) :
-        Func1(b) {
-        *this = Gaussian1::operator=(b);
-    }
-
-    Gaussian1& operator=(const Gaussian1& right) {
-        if (&right == this) {
-            return *this;
-        }
-        Func1::operator=(right);
-        m_A = right.m_A;
-        m_t0 = right.m_t0;
-        m_tau = right.m_tau;
-        m_parent = 0;
-        return *this;
-    }
-
     string type() const override {
         return "Gaussian";
     }
 
+    bool isIdentical(shared_ptr<Func1> other) const override {
+        return false;  // base class check is insufficient
+    }
+
     double eval(double t) const override {
         double x = (t - m_t0)/m_tau;
         return m_A * std::exp(-x*x);
@@ -1136,78 +705,53 @@ protected:
 };
 
 
-/**
- * A Gaussian.
- * @f[
- * f(t) = A e^{-[(t - t_0)/\tau]^2}
- * @f]
- * where @f[ \tau = \frac{fwhm}{2\sqrt{\ln 2}} @f]
- * @param A peak value
- * @param t0 offset
- * @param fwhm full width at half max
- * @ingroup func1advanced
- * @deprecated To be removed after %Cantera 3.0; replaced by Gaussian1.
- */
-class Gaussian : public Gaussian1
-{
-    Gaussian(double A, double t0, double fwhm);
-
-    Gaussian(const Gaussian& b);
-
-    Func1& duplicate() const override;
-};
-
-
 /**
  * Implements a polynomial of degree @e n.
- * The functor class with type @c "polynomial" returns
+ * The functor class with type @c "polynomial3" returns
  * @f[
  * f(x) = a_n x^n + \dots + a_1 x + a_0
  * @f]
+ * with coefficients provided in the order @f$ [a_n, \dots, a_1, a_0] @f$ (consistent
+ * with MATLAB and NumPy conventions). Note that %Cantera 3.1 reversed the coefficient
+ * order with respect to its earlier definition. A deprecation cycle is skipped as the
+ * functor class is not expected to be widely used; the transitional name Poly13 ensures
+ * that changed behavior does not go unnoticed. The class name will revert to @b Poly1
+ * after %Cantera 3.1.
+ * @since Changed in %Cantera 3.1.
+ * @todo Rename to Poly1 after %Cantera 3.1
  * @ingroup func1advanced
  */
-class Poly1 : public Func1
+class Poly13 : public Func1
 {
 public:
-    Poly1(size_t n, const double* c) {
+    Poly13(size_t n, const double* c) {
         m_cpoly.resize(n+1);
         std::copy(c, c+m_cpoly.size(), m_cpoly.begin());
     }
 
     //! Constructor uses @f$ n + 1 @f$ parameters in the following order:
     //! @f$ [a_n, \dots, a_1, a_0] @f$
-    Poly1(const vector<double>& params);
-
-    Poly1(const Poly1& b) :
-        Func1(b) {
-        *this = Poly1::operator=(b);
-    }
-
-    Poly1& operator=(const Poly1& right) {
-        if (&right == this) {
-            return *this;
-        }
-        Func1::operator=(right);
-        m_cpoly = right.m_cpoly;
-        m_parent = 0;
-        return *this;
-    }
+    Poly13(const vector<double>& params);
 
     string type() const override {
-        return "polynomial";
+        return "polynomial3";
     }
 
-    Func1& duplicate() const override;
+    bool isIdentical(shared_ptr<Func1> other) const override {
+        return false;  // base class check is insufficient
+    }
 
     double eval(double t) const override {
-        double r = m_cpoly[m_cpoly.size()-1];
+        double r = m_cpoly[0];
         for (size_t n = 1; n < m_cpoly.size(); n++) {
             r *= t;
-            r += m_cpoly[m_cpoly.size() - n - 1];
+            r += m_cpoly[n];
         }
         return r;
     }
 
+    string write(const string& arg) const override;
+
 protected:
     vector<double> m_cpoly;
 };
@@ -1217,8 +761,7 @@ protected:
  * Implements a Fourier cosine/sine series.
  * The functor class with type @c "Fourier" returns
  * @f[
- * f(t) = \frac{A_0}{2} +
- * \sum_{n=1}^N A_n \cos (n \omega t) + B_n \sin (n \omega t)
+ * f(t) = \frac{a_0}{2} + \sum_{n=1}^N a_n \cos (n \omega t) + b_n \sin (n \omega t)
  * @f]
  * @ingroup func1advanced
  */
@@ -1238,29 +781,13 @@ public:
     //! @f$ [a_0, a_1, \dots, a_n, \omega, b_1, \dots, b_n] @f$
     Fourier1(const vector<double>& params);
 
-    Fourier1(const Fourier1& b) :
-        Func1(b) {
-        *this = Fourier1::operator=(b);
-    }
-
-    Fourier1& operator=(const Fourier1& right) {
-        if (&right == this) {
-            return *this;
-        }
-        Func1::operator=(right);
-        m_omega = right.m_omega;
-        m_a0_2 = right.m_a0_2;
-        m_ccos = right.m_ccos;
-        m_csin = right.m_csin;
-        m_parent = 0;
-        return *this;
-    }
-
     string type() const override {
         return "Fourier";
     }
 
-    Func1& duplicate() const override;
+    bool isIdentical(shared_ptr<Func1> other) const override {
+        return false;  // base class check is insufficient
+    }
 
     double eval(double t) const override {
         size_t n, nn;
@@ -1306,28 +833,13 @@ public:
     //! @f$ [A_1, b_1, E_1, A_2, b_2, E_2, \dots, A_n, b_n, E_n] @f$
     Arrhenius1(const vector<double>& params);
 
-    Arrhenius1(const Arrhenius1& b) :
-        Func1() {
-        *this = Arrhenius1::operator=(b);
-    }
-
-    Arrhenius1& operator=(const Arrhenius1& right) {
-        if (&right == this) {
-            return *this;
-        }
-        Func1::operator=(right);
-        m_A = right.m_A;
-        m_b = right.m_b;
-        m_E = right.m_E;
-        m_parent = 0;
-        return *this;
-    }
-
     string type() const override {
         return "Arrhenius";
     }
 
-    Func1& duplicate() const override;
+    bool isIdentical(shared_ptr<Func1> other) const override {
+        return false;  // base class check is insufficient
+    }
 
     double eval(double t) const override {
         double sum = 0.0;
@@ -1351,38 +863,12 @@ protected:
 class Periodic1 : public Func1
 {
 public:
-    Periodic1(Func1& f, double T) {
-        m_f1 = &f;
-        m_c = T;
-    }
-
-    Periodic1(const Periodic1& b) {
-        *this = Periodic1::operator=(b);
-    }
-
     Periodic1(shared_ptr<Func1> f, double A) : Func1(f, A) {}
 
-    Periodic1& operator=(const Periodic1& right) {
-        if (&right == this) {
-            return *this;
-        }
-        Func1::operator=(right);
-        m_f1 = &right.m_f1->duplicate();
-        return *this;
-    }
-
     string type() const override {
         return "periodic";
     }
 
-    Func1& duplicate() const override;
-
-    ~Periodic1() override {
-        if (!m_f1_shared) {
-            delete m_f1;
-        }
-    }
-
     double eval(double t) const override {
         int np = int(t/m_c);
         double time = t - np*m_c;
