@@ -13,12 +13,15 @@
 #include "Domain1D.h"
 #include "cantera/thermo/SurfPhase.h"
 #include "cantera/kinetics/InterfaceKinetics.h"
-#include "StFlow.h"
+#include "Flow1D.h"
 
 namespace Cantera
 {
 
+//! Unique identifier for the left inlet.
 const int LeftInlet = 1;
+
+//! Unique identifier for the right inlet.
 const int RightInlet = -1;
 
 //! @defgroup bdryGroup Boundaries
@@ -39,13 +42,14 @@ const int RightInlet = -1;
 class Boundary1D : public Domain1D
 {
 public:
+    //! Default constructor
     Boundary1D();
 
     void init() override {
         _init(1);
     }
 
-    string type() const override {
+    string domainType() const override {
         return "boundary";
     }
 
@@ -63,6 +67,7 @@ public:
         return m_temp;
     }
 
+    //! Get the number of species
     virtual size_t nSpecies() {
         return 0;
     }
@@ -82,7 +87,7 @@ public:
         throw NotImplementedError("Boundary1D::massFraction");
     }
 
-    //! Set the total mass flow rate.
+    //! Set the total mass flow rate [kg/m²/s].
     virtual void setMdot(double mdot) {
         m_mdot = mdot;
     }
@@ -107,25 +112,22 @@ public:
     void fromArray(SolutionArray& arr, double* soln) override;
 
 protected:
+    //! Initialize member variables based on the adjacent domains.
+    //! @param n  Number of state variables associated with the boundary object
     void _init(size_t n);
 
-    StFlow* m_flow_left = nullptr;
-    StFlow* m_flow_right = nullptr;
-    size_t m_ilr = 0;
-    size_t m_left_nv = 0;
-    size_t m_right_nv = 0;
-    size_t m_left_loc = 0;
-    size_t m_right_loc = 0;
-    size_t m_left_points = 0;
-    size_t m_left_nsp = 0;
-    size_t m_right_nsp = 0;
-    size_t m_sp_left = 0;
-    size_t m_sp_right = 0;
-    size_t m_start_left = 0;
-    size_t m_start_right = 0;
-    ThermoPhase* m_phase_left = nullptr;
-    ThermoPhase* m_phase_right = nullptr;
+    Flow1D* m_flow_left = nullptr; //!< Flow domain to the left of this boundary
+    Flow1D* m_flow_right = nullptr; //! Flow domain to the right of this boundary
+    size_t m_left_nv = 0; //!< Number of state vector components in left flow domain
+    size_t m_right_nv = 0; //!< Number of state vector components in right flow domain
+    size_t m_left_nsp = 0; //!< Number of species in left flow domain
+    size_t m_right_nsp = 0; //!< Number of species in right flow domain
+    ThermoPhase* m_phase_left = nullptr; //!< Thermo object used by left flow domain
+    ThermoPhase* m_phase_right = nullptr; //!< Thermo object used by right flow domain
+
+    //! Temperature of the boundary.
     double m_temp = 0.0;
+    //! Mass flow rate at the boundary.
     double m_mdot = 0.0;
 };
 
@@ -138,11 +140,15 @@ protected:
 class Inlet1D : public Boundary1D
 {
 public:
+    //! Default constructor
     Inlet1D();
 
+    //! Constructor with contents
+    //! @param solution  Solution representing contents of adjacent flow domain
+    //! @param id  Name used to identify this domain
     Inlet1D(shared_ptr<Solution> solution, const string& id="");
 
-    string type() const override {
+    string domainType() const override {
         return "inlet";
     }
 
@@ -152,6 +158,8 @@ public:
         return m_V0;
     }
 
+    void setTemperature(double T) override;
+
     void show(const double* x) override;
 
     size_t nSpecies() override {
@@ -169,12 +177,16 @@ public:
     void fromArray(SolutionArray& arr, double* soln) override;
 
 protected:
+    //! A marker that indicates whether this is a left inlet or a right inlet.
     int m_ilr;
+
+    //! The spread rate of the inlet [1/s]
     double m_V0 = 0.0;
-    size_t m_nsp = 0;
-    vector<double> m_yin;
-    string m_xstr;
-    StFlow* m_flow = nullptr;
+
+    size_t m_nsp = 0; //!< Number of species in the adjacent flow domain
+    vector<double> m_yin; //!< inlet mass fractions
+    string m_xstr; //!< inlet mass fractions. Parsing deferred to init()
+    Flow1D* m_flow = nullptr; //!< the adjacent flow domain
 };
 
 /**
@@ -183,16 +195,18 @@ protected:
 class Empty1D : public Boundary1D
 {
 public:
-    Empty1D() {
-        m_type = cEmptyType;
-    }
+    //! Default constructor
+    Empty1D() = default;
 
+    //! Constructor with contents
+    //! @param solution  Solution representing contents
+    //! @param id  Name used to identify this domain
     Empty1D(shared_ptr<Solution> solution, const string& id="") : Empty1D() {
-        m_solution = solution;
+        setSolution(solution);
         m_id = id;
     }
 
-    string type() const override {
+    string domainType() const override {
         return "empty";
     }
 
@@ -212,16 +226,18 @@ public:
 class Symm1D : public Boundary1D
 {
 public:
-    Symm1D() {
-        m_type = cSymmType;
-    }
+    //! Default constructor
+    Symm1D() = default;
 
+    //! Constructor with contents
+    //! @param solution  Solution representing contents of adjacent flow domain
+    //! @param id  Name used to identify this domain
     Symm1D(shared_ptr<Solution> solution, const string& id="") : Symm1D() {
-        m_solution = solution;
+        setSolution(solution);
         m_id = id;
     }
 
-    string type() const override {
+    string domainType() const override {
         return "symmetry-plane";
     }
 
@@ -240,16 +256,18 @@ public:
 class Outlet1D : public Boundary1D
 {
 public:
-    Outlet1D() {
-        m_type = cOutletType;
-    }
+    //! Default constructor
+    Outlet1D() = default;
 
+    //! Constructor with contents
+    //! @param solution  Solution representing contents of adjacent flow domain
+    //! @param id  Name used to identify this domain
     Outlet1D(shared_ptr<Solution> solution, const string& id="") : Outlet1D() {
-        m_solution = solution;
+        setSolution(solution);
         m_id = id;
     }
 
-    string type() const override {
+    string domainType() const override {
         return "outlet";
     }
 
@@ -268,11 +286,15 @@ public:
 class OutletRes1D : public Boundary1D
 {
 public:
+    //! Default constructor
     OutletRes1D();
 
+    //! Constructor with contents
+    //! @param solution  Solution representing contents of adjacent flow domain
+    //! @param id  Name used to identify this domain
     OutletRes1D(shared_ptr<Solution> solution, const string& id="");
 
-    string type() const override {
+    string domainType() const override {
         return "outlet-reservoir";
     }
 
@@ -294,10 +316,10 @@ public:
     void fromArray(SolutionArray& arr, double* soln) override;
 
 protected:
-    size_t m_nsp = 0;
-    vector<double> m_yres;
-    string m_xstr;
-    StFlow* m_flow = nullptr;
+    size_t m_nsp = 0; //!< Number of species in the adjacent flow domain
+    vector<double> m_yres; //!< Mass fractions in the reservoir
+    string m_xstr; //!< Mole fractions in the reservoir
+    Flow1D* m_flow = nullptr; //!< The adjacent flow domain
 };
 
 /**
@@ -308,16 +330,18 @@ protected:
 class Surf1D : public Boundary1D
 {
 public:
-    Surf1D() {
-        m_type = cSurfType;
-    }
+    //! Default constructor
+    Surf1D() = default;
 
+    //! Constructor with contents
+    //! @param solution  Solution representing contents of adjacent flow domain
+    //! @param id  Name used to identify this domain
     Surf1D(shared_ptr<Solution> solution, const string& id="") : Surf1D() {
-        m_solution = solution;
+        setSolution(solution);
         m_id = id;
     }
 
-    string type() const override {
+    string domainType() const override {
         return "surface";
     }
 
@@ -328,6 +352,7 @@ public:
     shared_ptr<SolutionArray> asArray(const double* soln) const override;
     void fromArray(SolutionArray& arr, double* soln) override;
 
+    //! @deprecated To be removed after Cantera 3.1.
     void show(std::ostream& s, const double* x) override;
 
     void show(const double* x) override;
@@ -339,22 +364,27 @@ public:
 class ReactingSurf1D : public Boundary1D
 {
 public:
+    //! Default constructor
     ReactingSurf1D();
+
+    //! Constructor with contents
+    //! @param solution  Solution representing contents of adjacent flow domain
+    //! @param id  Name used to identify this domain
     ReactingSurf1D(shared_ptr<Solution> solution, const string& id="");
 
-    string type() const override {
+    string domainType() const override {
         return "reacting-surface";
     }
 
     void setKinetics(shared_ptr<Kinetics> kin) override;
 
-    //! @deprecated To be removed after %Cantera 3.0; replaced by setKinetics()
-    void setKineticsMgr(InterfaceKinetics* kin);
-
+    //! Set whether to solve the equations for the surface species coverages
     void enableCoverageEquations(bool docov) {
         m_enabled = docov;
     }
 
+    //! Indicates whether the equations for the surface species coverages are being
+    //! solved
     bool coverageEnabled() {
         return m_enabled;
     }
@@ -380,12 +410,17 @@ public:
     void show(const double* x) override;
 
 protected:
-    InterfaceKinetics* m_kin = nullptr;
-    SurfPhase* m_sphase = nullptr;
-    size_t m_surfindex = 0;
-    size_t m_nsp = 0;
-    bool m_enabled = false;
+    InterfaceKinetics* m_kin = nullptr; //!< surface kinetics mechanism
+    SurfPhase* m_sphase = nullptr; //!< phase representing the surface species
+    size_t m_nsp = 0; //!< the number of surface phase species
+    bool m_enabled = false; //!< True if coverage equations are being solved
+
+    //! temporary vector used to store coverages and production rates. Size is total
+    //! number of species in the kinetic mechanism
     vector<double> m_work;
+
+    //! Fixed values of the coverages used when coverage equations are not being solved.
+    //! Length is #m_nsp.
     vector<double> m_fixed_cov;
 };
 
