@@ -7,23 +7,11 @@
 #define CT_DOMAIN1D_H
 
 #include "cantera/base/ctexceptions.h"
+#include "cantera/base/global.h"
 
 namespace Cantera
 {
 
-// domain types (deprecated); to be removed after Cantera 3.0
-const int cFlowType = 50;
-const int cFreeFlow = 51;
-const int cAxisymmetricStagnationFlow = 52;
-const int cConnectorType = 100;
-const int cSurfType = 102;
-const int cInletType = 104;
-const int cSymmType = 105;
-const int cOutletType = 106;
-const int cEmptyType = 107;
-const int cOutletResType = 108;
-const int cPorousType = 109;
-
 class MultiJac;
 class OneDim;
 class Refiner;
@@ -53,15 +41,13 @@ public:
     Domain1D& operator=(const Domain1D&) = delete;
 
     //! Domain type flag.
-    //! @deprecated To be changed after %Cantera 3.0; for new behavior, see type.
-    int domainType();
+    //! @since Starting in %Cantera 3.1, the return type is a `string`.
+    virtual string domainType() const { return "domain"; }
 
     //! String indicating the domain implemented.
     //! @since New in %Cantera 3.0.
-    //! @todo Transition back to domainType after %Cantera 3.0
-    virtual string type() const {
-        return "domain";
-    }
+    //! @deprecated Transitional method. Use domainType() instead.
+    string type() const { return domainType(); }
 
     //! The left-to-right location of this domain.
     size_t domainIndex() {
@@ -75,9 +61,7 @@ public:
 
     //! Set the solution manager.
     //! @since New in %Cantera 3.0.
-    void setSolution(shared_ptr<Solution> sol) {
-        m_solution = sol;
-    }
+    void setSolution(shared_ptr<Solution> sol);
 
     //! Set the kinetics manager.
     //! @since New in %Cantera 3.0.
@@ -134,8 +118,15 @@ public:
      */
     virtual void init() {  }
 
-    virtual void setInitialState(double* xlocal = 0) {}
-    virtual void setState(size_t point, const double* state, double* x) {}
+    //! @deprecated Unused. To be removed after Cantera 3.1.
+    virtual void setInitialState(double* xlocal = 0) {
+        warn_deprecated("Domain1D::setInitialState", "To be removed after Cantera 3.1.");
+    }
+
+    //! @deprecated Unused. To be removed after Cantera 3.1.
+    virtual void setState(size_t point, const double* state, double* x) {
+        warn_deprecated("Domain1D::setState", "To be removed after Cantera 3.1.");
+    }
 
     /**
      * When called, this function should reset "bad" values in the state vector
@@ -200,16 +191,24 @@ public:
         }
     }
 
-    //! Name of the nth component. May be overloaded.
+    //! Name of component `n`. May be overloaded.
     virtual string componentName(size_t n) const;
 
+    //! Set the name of the component `n` to `name`.
     void setComponentName(size_t n, const string& name) {
         m_name[n] = name;
     }
 
-    //! index of component with name @e name.
+    //! index of component with name `name`.
     virtual size_t componentIndex(const string& name) const;
 
+    /**
+     * Set the upper and lower bounds for a solution component, n.
+     *
+     * @param n  solution component index
+     * @param lower  lower bound on component n
+     * @param upper  upper bound on component n
+     */
     void setBounds(size_t n, double lower, double upper) {
         m_min[n] = lower;
         m_max[n] = upper;
@@ -217,9 +216,9 @@ public:
 
     //! Set tolerances for time-stepping mode
     /*!
-     * @param rtol Relative tolerance
-     * @param atol Absolute tolerance
-     * @param n    component index these tolerances apply to. If set to -1 (the
+     * @param rtol  Relative tolerance
+     * @param atol  Absolute tolerance
+     * @param n  component index these tolerances apply to. If set to -1 (the
      *      default), these tolerances will be applied to all solution
      *      components.
      */
@@ -227,9 +226,9 @@ public:
 
     //! Set tolerances for steady-state mode
     /*!
-     * @param rtol Relative tolerance
-     * @param atol Absolute tolerance
-     * @param n    component index these tolerances apply to. If set to -1 (the
+     * @param rtol  Relative tolerance
+     * @param atol  Absolute tolerance
+     * @param n  component index these tolerances apply to. If set to -1 (the
      *     default), these tolerances will be applied to all solution
      *     components.
      */
@@ -275,18 +274,22 @@ public:
         return m_min[n];
     }
 
-    //! Prepare to do time stepping with time step dt
-    /*!
-     * Copy the internally-stored solution at the last time step to array x0.
+    /**
+     * Performs the setup required before starting a time-stepping solution.
+     * Stores the solution provided in `x0` to the internal storage, and sets
+     * the reciprocal of the time step to `1/dt`.
+     *
+     * @param[in] dt  Time step
+     * @param[in] x0  Array to store the solution at the last time step
      */
     void initTimeInteg(double dt, const double* x0) {
         std::copy(x0 + loc(), x0 + loc() + size(), m_slast.begin());
         m_rdt = 1.0/dt;
     }
 
-    //! Prepare to solve the steady-state problem
-    /*!
-     * Set the internally-stored reciprocal of the time step to 0.0
+    /**
+     * Set the internally-stored reciprocal of the time step to 0.0, which is
+     * used to indicate that the problem is in steady-state mode.
      */
     void setSteadyMode() {
         m_rdt = 0.0;
@@ -314,38 +317,48 @@ public:
     /*!
      *  This function must be implemented in classes derived from Domain1D.
      *
-     *  @param j  Grid point at which to update the residual
+     *  @param[in] j  Grid point at which to update the residual
      *  @param[in] x  State vector
      *  @param[out] r  residual vector
      *  @param[out] mask  Boolean mask indicating whether each solution
      *      component has a time derivative (1) or not (0).
-     *  @param[in] rdt Reciprocal of the timestep (`rdt=0` implies steady-
-     *  state.)
+     *  @param[in] rdt  Reciprocal of the timestep (`rdt=0` implies steady-state.)
      */
     virtual void eval(size_t j, double* x, double* r, integer* mask, double rdt=0.0) {
         throw NotImplementedError("Domain1D::eval");
     }
 
+    /**
+     * Returns the index of the solution vector, which corresponds to component
+     * n at grid point j.
+     *
+     * @param n  component index
+     * @param j  grid point index
+     */
     size_t index(size_t n, size_t j) const {
         return m_nv*j + n;
     }
+
+    /**
+     * Returns the value of solution component n at grid point j of the solution
+     * vector x.
+     *
+     * @param x  solution vector
+     * @param n  component index
+     * @param j  grid point index
+     */
     double value(const double* x, size_t n, size_t j) const {
         return x[index(n,j)];
     }
 
-    virtual void setJac(MultiJac* jac) {}
-
-    //! Save the state of this domain as an AnyMap
-    /*!
-     * @param soln local solution vector for this domain
-     *
-     * @deprecated To be removed after %Cantera 3.0; superseded by asArray().
-     */
-    AnyMap serialize(const double* soln) const;
+    //! @deprecated To be removed after Cantera 3.1.
+    virtual void setJac(MultiJac* jac) {
+        warn_deprecated("Domain1D::setJac", "To be removed after Cantera 3.1.");
+    }
 
     //! Save the state of this domain as a SolutionArray.
     /*!
-     * @param soln local solution vector for this domain
+     * @param soln  local solution vector for this domain
      * @todo  Despite the method's name, data are copied; the intent is to access data
      *      directly in future revisions, where a non-const version will be implemented.
      *
@@ -359,27 +372,16 @@ public:
     /*!
      * This method serves as an external interface for high-level API's; it does not
      * provide direct access to memory.
-     * @param normalize If true, normalize concentrations (default=false)
+     * @param normalize  If true, normalize concentrations (default=false)
      *
      * @since New in %Cantera 3.0.
      */
     shared_ptr<SolutionArray> toArray(bool normalize=false) const;
 
-    //! Restore the solution for this domain from an AnyMap
-    /*!
-     * @param[in]  state AnyMap defining the state of this domain
-     * @param[out] soln Value of the solution vector, local to this domain
-     * @param[in]  loglevel 0 to suppress all output; 1 to show warnings; 2 for
-     *      verbose output
-     *
-     * @deprecated To be removed after %Cantera 3.0; restore from SolutionArray instead.
-     */
-    void restore(const AnyMap& state, double* soln, int loglevel);
-
     //! Restore the solution for this domain from a SolutionArray
     /*!
-     * @param[in]  arr SolutionArray defining the state of this domain
-     * @param[out] soln Value of the solution vector, local to this domain
+     * @param[in] arr  SolutionArray defining the state of this domain
+     * @param[out] soln  Value of the solution vector, local to this domain
      *
      * @since New in %Cantera 3.0.
      */
@@ -390,7 +392,7 @@ public:
     //! Restore the solution for this domain from a SolutionArray.
     /*!
      * This method serves as an external interface for high-level API's.
-     * @param  arr SolutionArray defining the state of this domain
+     * @param arr  SolutionArray defining the state of this domain
      * @since New in %Cantera 3.0.
      */
     void fromArray(const shared_ptr<SolutionArray>& arr);
@@ -401,6 +403,7 @@ public:
         return m_solution;
     }
 
+    //! Return the size of the solution vector (the product of #m_nv and #m_points).
     size_t size() const {
         return m_nv*m_points;
     }
@@ -411,26 +414,17 @@ public:
      */
     void locate();
 
-    /**
-     * Location of the start of the local solution vector in the global
-     * solution vector,
-     */
+    //! Location of the start of the local solution vector in the global solution vector
     virtual size_t loc(size_t j = 0) const {
         return m_iloc;
     }
 
-    /**
-     * The index of the first (that is, left-most) grid point belonging to this
-     * domain.
-     */
+    //! The index of the first (that is, left-most) grid point belonging to this domain.
     size_t firstPoint() const {
         return m_jstart;
     }
 
-    /**
-     * The index of the last (that is, right-most) grid point belonging to this
-     * domain.
-     */
+    //! The index of the last (that is, right-most) grid point belonging to this domain.
     size_t lastPoint() const {
         return m_jstart + m_points - 1;
     }
@@ -442,7 +436,7 @@ public:
     void linkLeft(Domain1D* left) {
         m_left = left;
         if (!m_solution && left && left->solution()) {
-            m_solution = left->solution();
+            setSolution(left->solution());
         }
         locate();
     }
@@ -451,7 +445,7 @@ public:
     void linkRight(Domain1D* right) {
         m_right = right;
         if (!m_solution && right && right->solution()) {
-            m_solution = right->solution();
+            setSolution(right->solution());
         }
     }
 
@@ -481,6 +475,7 @@ public:
         m_id = s;
     }
 
+    //! Returns the identifying tag for this domain.
     string id() const {
         if (m_id != "") {
             return m_id;
@@ -489,38 +484,52 @@ public:
         }
     }
 
-    //! @deprecated To be removed after %Cantera 3.0; replaced by show()
-    virtual void showSolution_s(std::ostream& s, const double* x);
-
     //! Print the solution.
-    //! @deprecated To be removed after %Cantera 3.0; replaced by show()
-    virtual void showSolution(const double* x);
-
-    //! Print the solution.
-    virtual void show(std::ostream& s, const double* x) {}
+    //! @deprecated Not implemented. To be removed after Cantera 3.1.
+    virtual void show(std::ostream& s, const double* x) {
+        warn_deprecated("Domain1D::show(std::ostream, double*)",
+                        "Not implemented. To be removed after Cantera 3.1.");
+    }
 
     //! Print the solution.
+    //! @param x  Pointer to the local portion of the system state vector
     virtual void show(const double* x);
 
+    //! Get the coordinate [m] of the point with local index `jlocal`
     double z(size_t jlocal) const {
         return m_z[jlocal];
     }
+
+    //! Get the coordinate [m] of the first (leftmost) grid point in this domain
     double zmin() const {
         return m_z[0];
     }
+
+    //! Get the coordinate [m] of the last (rightmost) grid point in this domain
     double zmax() const {
         return m_z[m_points - 1];
     }
 
+    //! Set initial values for a component at each grid point
+    //! @param name  Name of the component
+    //! @param values  Array of length nPoints() containing the initial values
+    //! @param soln  Pointer to the local portion of the system state vector
     void setProfile(const string& name, double* values, double* soln);
 
+    //! Access the array of grid coordinates [m]
     vector<double>& grid() {
         return m_z;
     }
+
+    //! Access the array of grid coordinates [m]
     const vector<double>& grid() const {
         return m_z;
     }
+
+    //! @deprecated To be removed after Cantera 3.1. Use z() instead.
     double grid(size_t point) const {
+        warn_deprecated("Domain1D::grid",
+            "To be removed after Cantera 3.1. Use z() instead.");
         return m_z[point];
     }
 
@@ -573,18 +582,22 @@ protected:
 
     shared_ptr<vector<double>> m_state; //!< data pointer shared from OneDim
 
-    double m_rdt = 0.0;
-    size_t m_nv = 0;
+    double m_rdt = 0.0; //!< Reciprocal of the time step
+    size_t m_nv = 0; //!< Number of solution components
     size_t m_points; //!< Number of grid points
-    vector<double> m_slast;
-    vector<double> m_max;
-    vector<double> m_min;
-    vector<double> m_rtol_ss, m_rtol_ts;
-    vector<double> m_atol_ss, m_atol_ts;
-    vector<double> m_z;
+    vector<double> m_slast; //!< Solution vector at the last time step
+    vector<double> m_max; //!< Upper bounds on solution components
+    vector<double> m_min; //!< Lower bounds on solution components
+    vector<double> m_rtol_ss; //!< Relative tolerances for steady mode
+    vector<double> m_rtol_ts; //!< Relative tolerances for transient mode
+    vector<double> m_atol_ss; //!< Absolute tolerances for steady mode
+    vector<double> m_atol_ts; //!< Absolute tolerances for transient mode
+    vector<double> m_z; //!< 1D spatial grid coordinates
+
+    //! Parent OneDim simulation containing this and adjacent domains
     OneDim* m_container = nullptr;
-    size_t m_index;
-    int m_type = 0; //!< @deprecated To be removed after %Cantera 3.0
+
+    size_t m_index; //!< Left-to-right location of this domain
 
     //! Starting location within the solution vector for unknowns that
     //! correspond to this domain
@@ -593,17 +606,19 @@ protected:
      */
     size_t m_iloc = 0;
 
+    //! Index of the first point in this domain in the global point list.
+    //! @see firstPoint(), lastPoint()
     size_t m_jstart = 0;
 
-    Domain1D* m_left = nullptr;
-    Domain1D* m_right = nullptr;
+    Domain1D* m_left = nullptr; //!< Pointer to the domain to the left
+    Domain1D* m_right = nullptr; //!< Pointer to the domain to the right
 
     //! Identity tag for the domain
     string m_id;
-    unique_ptr<Refiner> m_refiner;
-    vector<string> m_name;
-    int m_bw = -1;
-    bool m_force_full_update = false;
+    unique_ptr<Refiner> m_refiner; //!< Refiner object used for placing grid points
+    vector<string> m_name; //!< Names of solution components
+    int m_bw = -1; //!< See bandwidth()
+    bool m_force_full_update = false; //!< see forceFullUpdate()
 
     //! Composite thermo/kinetics/transport handler
     shared_ptr<Solution> m_solution;
