@@ -6,7 +6,7 @@
 #ifndef CT_IONFLOW_H
 #define CT_IONFLOW_H
 
-#include "cantera/oneD/StFlow.h"
+#include "cantera/oneD/Flow1D.h"
 
 namespace Cantera
 {
@@ -25,19 +25,24 @@ namespace Cantera
  *
  * @ingroup flowGroup
  */
-class IonFlow : public StFlow
+class IonFlow : public Flow1D
 {
 public:
+    //! Create a new IonFlow domain.
+    //! @param ph  Object representing the gas phase. This object will be used
+    //!     to evaluate all thermodynamic, kinetic, and transport properties.
+    //! @param nsp  Number of species.
+    //! @param points  Initial number of grid points
     IonFlow(ThermoPhase* ph = 0, size_t nsp = 1, size_t points = 1);
 
-    //! Create a new flow domain.
+    //! Create a new IonFlow domain.
     //! @param sol  Solution object used to evaluate all thermodynamic, kinetic, and
     //!     transport properties
     //! @param id  name of flow domain
     //! @param points  initial number of grid points
     IonFlow(shared_ptr<Solution> sol, const string& id="", size_t points = 1);
 
-    string type() const override;
+    string domainType() const override;
 
     size_t getSolvingStage() const override {
         return m_stage;
@@ -61,18 +66,50 @@ public:
      * See Bisetti and El Morsli @cite bisetti2012.
      * If in the future the class GasTransport is improved, this method may
      * be discarded. This method specifies this profile.
-    */
+     */
     void setElectronTransport(vector<double>& tfix,
                               vector<double>& diff_e,
                               vector<double>& mobi_e);
 
 protected:
-    /*!
-     * This function overloads the original function. The residual function
-     * of electric field is added.
+
+    /**
+     * Evaluate the electric field equation residual by Gauss's law.
+     *
+     * The function calculates the electric field equation as:
+     * @f[
+     *    \frac{dE}{dz} = \frac{e}{\varepsilon_0} \sum (q_k \cdot n_k)
+     * @f]
+     *
+     * and
+     *
+     * @f[
+     *    E = -\frac{dV}{dz}
+     * @f]
+     *
+     * The electric field equation is based on Gauss's law,
+     * accounting for charge density and permittivity of free space
+     * (@f$ \varepsilon_0 @f$).
+     * The zero electric field is first evaluated and if the solution state is 2,
+     * then the alternative form the electric field equation is evaluated.
+     *
+     * For argument explanation, see evalContinuity() base class.
      */
-    void evalResidual(double* x, double* rsd, int* diag,
-                      double rdt, size_t jmin, size_t jmax) override;
+    void evalElectricField(double* x, double* rsd, int* diag,
+                           double rdt, size_t jmin, size_t jmax) override;
+
+    /**
+     * Evaluate the species equations' residual. This function overloads the
+     * original species function.
+     *
+     * A Neumann boundary for the charged species at the
+     * left boundary is added, and the default boundary condition from the overloaded
+     * method is left the same for the right boundary.
+     *
+     * For argument explanation, see evalContinuity() base class.
+     */
+    void evalSpecies(double* x, double* rsd, int* diag,
+                     double rdt, size_t jmin, size_t jmax) override;
     void updateTransport(double* x, size_t j0, size_t j1) override;
     void updateDiffFluxes(const double* x, size_t j0, size_t j1) override;
     //! Solving phase one: the fluxes of charged species are turned off
@@ -95,8 +132,14 @@ protected:
     //! index of neutral species
     vector<size_t> m_kNeutral;
 
-    //! coefficients of polynomial fitting of fixed electron transport profile
+    //! Coefficients of polynomial fit for electron mobility as a function of
+    //! temperature.
+    //! @see setElectronTransport
     vector<double> m_mobi_e_fix;
+
+    //! Coefficients of polynomial fit for electron diffusivity as a function of
+    //! temperature.
+    //! @see setElectronTransport
     vector<double> m_diff_e_fix;
 
     //! mobility
@@ -108,16 +151,17 @@ protected:
     //! index of electron
     size_t m_kElectron = npos;
 
-    //! electric field
+    //! electric field [V/m]
     double E(const double* x, size_t j) const {
         return x[index(c_offset_E, j)];
     }
 
+    //! Axial gradient of the electric field [V/m²]
     double dEdz(const double* x, size_t j) const {
         return (E(x,j)-E(x,j-1))/(z(j)-z(j-1));
     }
 
-    //! number density
+    //! number density [molecules/m³]
     double ND(const double* x, size_t k, size_t j) const {
         return Avogadro * m_rho[j] * Y(x,k,j) / m_wt[k];
     }
