@@ -30,17 +30,13 @@ public:
 
     /**
      * Standard constructor.
-     * @param domains A vector of shared pointers to the domains to be linked together.
+     * @param domains  A vector of shared pointers to the domains to be linked together.
      *     The domain pointers must be entered in left-to-right order --- that is,
      *     the pointer to the leftmost domain is domain[0], the pointer to the
      *     domain to its right is domain[1], etc.
      */
     Sim1D(vector<shared_ptr<Domain1D>>& domains);
 
-    //! @deprecated To be removed after %Cantera 3.0;
-    //!     superseded by Sim1D() using shared_ptr
-    Sim1D(vector<Domain1D*>& domains);
-
     //! @name Setting initial values
     //!
     //! These methods are used to set the initial values of solution components.
@@ -48,10 +44,10 @@ public:
 
     //! Set initial guess for one component for all domains
     /**
-     * @param component component name
-     * @param locs A vector of relative positions, beginning with 0.0 at the
+     * @param component  component name
+     * @param locs  A vector of relative positions, beginning with 0.0 at the
      *     left of the domain, and ending with 1.0 at the right of the domain.
-     * @param vals A vector of values corresponding to the relative position
+     * @param vals  A vector of values corresponding to the relative position
      *     locations.
      */
     void setInitialGuess(const string& component, vector<double>& locs,
@@ -59,32 +55,37 @@ public:
 
     /**
      * Set a single value in the solution vector.
-     * @param dom domain number, beginning with 0 for the leftmost domain.
-     * @param comp component number
-     * @param localPoint grid point within the domain, beginning with 0 for
+     * @param dom  domain number, beginning with 0 for the leftmost domain.
+     * @param comp  component number
+     * @param localPoint  grid point within the domain, beginning with 0 for
      *     the leftmost grid point in the domain.
-     * @param value the value.
+     * @param value  the value.
      */
     void setValue(size_t dom, size_t comp, size_t localPoint, double value);
 
     /**
      * Get one entry in the solution vector.
-     * @param dom domain number, beginning with 0 for the leftmost domain.
-     * @param comp component number
-     * @param localPoint grid point within the domain, beginning with 0 for
+     * @param dom  domain number, beginning with 0 for the leftmost domain.
+     * @param comp  component number
+     * @param localPoint  grid point within the domain, beginning with 0 for
      *     the leftmost grid point in the domain.
      */
     double value(size_t dom, size_t comp, size_t localPoint) const;
 
+    //! Get an entry in the work vector, which may contain either a new system state
+    //! or the current residual of the system.
+    //! @param dom  domain index
+    //! @param comp  component index
+    //! @param localPoint  grid point within the domain
     double workValue(size_t dom, size_t comp, size_t localPoint) const;
 
     /**
      * Specify a profile for one component of one domain.
-     * @param dom domain number, beginning with 0 for the leftmost domain.
-     * @param comp component number
-     * @param pos A vector of relative positions, beginning with 0.0 at the
+     * @param dom  domain number, beginning with 0 for the leftmost domain.
+     * @param comp  component number
+     * @param pos  A vector of relative positions, beginning with 0.0 at the
      *     left of the domain, and ending with 1.0 at the right of the domain.
-     * @param values A vector of values corresponding to the relative position
+     * @param values  A vector of values corresponding to the relative position
      *     locations.
      *
      * Note that the vector pos and values can have lengths different than the
@@ -104,23 +105,11 @@ public:
     //!
     //! @{
 
-    /**
-     * Output information on current solution for all domains to stream.
-     * @param s  Output stream
-     * @deprecated To be removed after %Cantera 3.0; replaced by show()
-     */
-    void showSolution(std::ostream& s);
-
-    /**
-     * Show logging information on current solution for all domains.
-     * @deprecated To be removed after %Cantera 3.0; replaced by show()
-     */
-    void showSolution();
-
     /**
      * Output information on current solution for all domains to stream.
      * @param s  Output stream
      * @since New in %Cantera 3.0.
+     * @deprecated To be removed after Cantera 3.1.
      */
     void show(std::ostream& s);
 
@@ -130,16 +119,6 @@ public:
      */
     void show();
 
-    /**
-     * Save the current solution to a container file.
-     * @param fname  Name of output container file
-     * @param id  Identifier of solution within the container file
-     * @param desc  Description of the solution
-     * @param loglevel  Level of diagnostic output
-     * @deprecated To be removed after %Cantera 3.0; loglevel is deprecated.
-     */
-    void save(const string& fname, const string& id, const string& desc, int loglevel);
-
     /**
      * Save current simulation data to a container file or CSV format.
      *
@@ -170,17 +149,6 @@ public:
     void save(const string& fname, const string& name, const string& desc,
               bool overwrite=false, int compression=0, const string& basis="");
 
-    /**
-     * Save the residual of the current solution to a container file.
-     * @param fname  Name of output container file
-     * @param id  Identifier of solution within the container file
-     * @param desc  Description of the solution
-     * @param loglevel  Level of diagnostic output
-     * @deprecated To be removed after %Cantera 3.0; loglevel is deprecated.
-     */
-    void saveResidual(const string& fname, const string& id,
-                      const string& desc, int loglevel);
-
     /**
      * Save the residual of the current solution to a container file.
      * @param fname  Name of output container file
@@ -192,16 +160,6 @@ public:
     void saveResidual(const string& fname, const string& name,
                       const string& desc, bool overwrite=false, int compression=0);
 
-    /**
-     * Initialize the solution with a previously-saved solution.
-     * @param fname  Name of container file
-     * @param id  Identifier of solution within the container file
-     * @param loglevel  Level of diagnostic output
-     * @deprecated To be removed after %Cantera 3.0; loglevel is deprecated.
-     * @return  AnyMap containing header information
-     */
-    AnyMap restore(const string& fname, const string& id, int loglevel);
-
     /**
      * Retrieve data and settings from a previously saved simulation.
      *
@@ -216,29 +174,84 @@ public:
      */
     AnyMap restore(const string& fname, const string& name);
 
+    /**
+     * Deletes a `debug_sim1d.yaml` file if it exists. Used to clear the file for
+     * successive calls to the solve() method.
+     */
+    void clearDebugFile();
+
+    /**
+     * Write solver debugging information to a YAML file based on the specified log
+     * level.
+     *
+     * This method writes solver debug information to a specified YAML file
+     * (`debug_sim1d.yaml`). The section headers are formatted according to the provided
+     * `header_suffix` and `attempt_counter` arguments. Depending on the log level, the
+     * method will save either the solution information or the residual information
+     * for each attempted solution.
+     *
+     * @param header_suffix  Header used to construct a unique section in the YAML file
+     *                       where the information will be written to.
+     * @param message  A string that is written to the `description` tag in the YAML
+     *                 file.
+     * @param loglevel  Controls the type of output that will be written. A `loglevel`
+     *                  greater than 6 saves the solution, and a `loglevel` greater
+     *                  than 7 saves the residual additionally.
+     * @param attempt_counter  An integer counter used to uniquely identify the attempt
+     *                         which is included in the file header to differentiate
+     *                         between multiple solution attempts.
+     */
+     void writeDebugInfo(const string& header_suffix, const string& message, int loglevel,
+                         int attempt_counter);
+
+
     //! @}
 
-    //! @deprecated To be removed after %Cantera 3.0 (unused)
-    const double* solution() {
-        warn_deprecated("Sim1D::solution",
-            "This method is unused and will be removed after Cantera 3.0.");
-        return m_state->data();
-    }
-
+    //! Set the number of time steps to try when the steady Newton solver is
+    //! unsuccessful.
+    //! @param stepsize  Initial time step size [s]
+    //! @param n  Length of `tsteps` array
+    //! @param tsteps  A sequence of time step counts to take after subsequent failures
+    //!     of the steady-state solver. The last value in `tsteps` will be used again
+    //!     after further unsuccessful solution attempts.
     void setTimeStep(double stepsize, size_t n, const int* tsteps);
 
+    /**
+     * Performs the hybrid Newton steady/time-stepping solution.
+     *
+     * The solver attempts to solve the steady-state problem first. If the steady-state
+     * solver fails, the time-stepping solver is used to take multiple time steps to
+     * move the solution closer to the steady-state solution. The steady-state solver is
+     * called again after the timesteps to make further progress towards the steady-state
+     * solution. This process is repeated until the steady-state solver converges or the
+     * maximum number of timesteps is reached.
+     *
+     * At the end of a successful solve, if the `refine_grid` flag is set, the grid will be
+     * analyzed and refined if necessary. If the grid is refined, the solution process
+     * described above is repeated with the new grid. This process is repeated until the
+     * grid no longer needs refinement based on the refine criteria.
+     *
+     * @param loglevel  Controls the amount of diagnostic output.
+     * @param refine_grid  If `true`, the grid will be refined
+     */
     void solve(int loglevel = 0, bool refine_grid = true);
 
     void eval(double rdt=-1.0, int count = 1) {
         OneDim::eval(npos, m_state->data(), m_xnew.data(), rdt, count);
     }
 
-    // Evaluate the governing equations and return the vector of residuals
+    //! Evaluate the governing equations and return the vector of residuals
     void getResidual(double rdt, double* resid) {
         OneDim::eval(npos, m_state->data(), resid, rdt, 0);
     }
 
     //! Refine the grid in all domains.
+    //!
+    //! @returns If positive, the number of new grid points added. If negative, the
+    //!     number of grid points removed. If zero, the grid is unchanged.
+    //!
+    //! @since Changed in %Cantera 3.1. Previously, the return value was zero if points
+    //!     were removed but not added.
     int refine(int loglevel=0);
 
     //! Add node for fixed temperature point of freely propagating flame
@@ -250,6 +263,30 @@ public:
     //! Return location of the point where temperature is fixed
     double fixedTemperatureLocation();
 
+    /**
+     * Set the left control point location using the specified temperature.
+     * This is used when two-point flame control is active.
+     *
+     * The provided temperature will be used to locate the closest grid point to
+     * that temperature, which will serve to locate the left control point's
+     * coordinate. Starting from the left boundary, the first grid point that is
+     * equal to or exceeds the specified temperature will be used to locate the
+     * left control point's coordinate.
+     */
+    void setLeftControlPoint(double temperature);
+
+    /**
+     * Set the right control point location using the specified temperature.
+     * This is used when two-point flame control is active.
+     *
+     * The provided temperature will be used to locate the closest grid point to
+     * that temperature, which will serve to locate the right control point's
+     * coordinate. Starting from the right boundary, the first grid point that is
+     * equal to or exceeds the specified temperature will be used to locate the
+     * right control point's coordinate.
+     */
+    void setRightControlPoint(double temperature);
+
     /**
      * Set grid refinement criteria. If dom >= 0, then the settings
      * apply only to the specified domain.  If dom < 0, the settings
@@ -276,15 +313,15 @@ public:
     /**
      * Get the maximum number of grid points in this domain. @see Refiner::maxPoints
      *
-     * @param dom domain number, beginning with 0 for the leftmost domain.
+     * @param dom  domain number, beginning with 0 for the leftmost domain.
      */
     size_t maxGridPoints(size_t dom);
 
     //! Set the minimum grid spacing in the specified domain(s).
     /*!
-     * @param dom Domain index. If dom == -1, the specified spacing is applied
-     *            to all domains.
-     * @param gridmin The minimum allowable grid spacing [m]
+     * @param dom  Domain index. If dom == -1, the specified spacing is applied
+     *             to all domains.
+     * @param gridmin  The minimum allowable grid spacing [m]
      */
     void setGridMin(int dom, double gridmin);
 
@@ -298,24 +335,13 @@ public:
     //! failure during grid refinement.
     void restoreSteadySolution();
 
+    //! Get the initial value of the system state from each domain in the simulation.
     void getInitialSoln();
 
-    //! @deprecated To be removed after %Cantera 3.0 (unused)
-    void setSolution(const double* soln) {
-        warn_deprecated("Sim1D::setSolution",
-            "This method is unused and will be removed after Cantera 3.0.");
-        std::copy(soln, soln + m_state->size(), m_state->data());
-    }
-
-    //! @deprecated To be removed after %Cantera 3.0 (unused)
-    const double* solution() const {
-        warn_deprecated("Sim1D::solution",
-            "This method is unused and will be removed after Cantera 3.0.");
-        return m_state->data();
-    }
-
+    //! Get the Jacobian element @f$ J_{ij} = \partial f_i / \partial x_j \f$
     double jacobian(int i, int j);
 
+    //! Evaluate the Jacobian in steady-state mode.
     void evalSSJacobian();
 
     //! Solve the equation @f$ J^T \lambda = b @f$.
