@@ -1,8 +1,8 @@
 /**
  *  @file LatticePhase.h Header for a simple thermodynamics model of a bulk
  *      phase derived from ThermoPhase, assuming a lattice of solid atoms (see
- *      \ref thermoprops and class \link Cantera::LatticePhase
- *      LatticePhase\endlink).
+ *      @ref thermoprops and class @link Cantera::LatticePhase
+ *      LatticePhase@endlink).
  */
 
 // This file is part of Cantera. See License.txt in the top-level directory or
@@ -25,7 +25,7 @@ namespace Cantera
  * standard states of the species are assumed to have zero volume expansivity
  * and zero isothermal compressibility.
  *
- * The density of matrix sites is given by the variable \f$ C_o \f$, which has
+ * The density of matrix sites is given by the variable @f$ C_o @f$, which has
  * SI units of kmol m-3.
  *
  * ## Specification of Species Standard State Properties
@@ -39,22 +39,22 @@ namespace Cantera
  * no effect on any quantities, as the molar concentration is a constant.
  *
  * The standard state enthalpy function is given by the following relation,
- * which has a weak dependence on the system pressure, \f$P\f$.
+ * which has a weak dependence on the system pressure, @f$ P @f$.
  *
- * \f[
+ * @f[
  *     h^o_k(T,P) =
  *            h^{ref}_k(T) +  \left( \frac{P - P_{ref}}{C_o} \right)
- * \f]
+ * @f]
  *
  * For an incompressible substance, the molar internal energy is independent of
  * pressure. Since the thermodynamic properties are specified by giving the
- * standard-state enthalpy, the term \f$ \frac{P_{ref}}{C_o} \f$ is subtracted
+ * standard-state enthalpy, the term @f$ \frac{P_{ref}}{C_o} @f$ is subtracted
  * from the specified reference molar enthalpy to compute the standard state
  * molar internal energy:
  *
- * \f[
+ * @f[
  *      u^o_k(T,P) = h^{ref}_k(T) - \frac{P_{ref}}{C_o}
- * \f]
+ * @f]
  *
  * The standard state heat capacity, internal energy, and entropy are
  * independent of pressure. The standard state Gibbs free energy is obtained
@@ -63,56 +63,56 @@ namespace Cantera
  * The standard state molar volume is independent of temperature, pressure, and
  * species identity:
  *
- * \f[
+ * @f[
  *      V^o_k(T,P) = \frac{1.0}{C_o}
- * \f]
+ * @f]
  *
  * ## Specification of Solution Thermodynamic Properties
  *
- * The activity of species \f$ k \f$ defined in the phase, \f$ a_k \f$, is given
+ * The activity of species @f$ k @f$ defined in the phase, @f$ a_k @f$, is given
  * by the ideal solution law:
  *
- * \f[
+ * @f[
  *      a_k = X_k ,
- * \f]
+ * @f]
  *
- * where \f$ X_k \f$ is the mole fraction of species *k*. The chemical potential
+ * where @f$ X_k @f$ is the mole fraction of species *k*. The chemical potential
  * for species *k* is equal to
  *
- * \f[
- *      \mu_k(T,P) = \mu^o_k(T, P) + R T \log(X_k)
- * \f]
+ * @f[
+ *      \mu_k(T,P) = \mu^o_k(T, P) + R T \ln X_k
+ * @f]
  *
  * The partial molar entropy for species *k* is given by the following relation,
  *
- * \f[
- *      \tilde{s}_k(T,P) = s^o_k(T,P) - R \log(X_k) = s^{ref}_k(T) - R \log(X_k)
- * \f]
+ * @f[
+ *      \tilde{s}_k(T,P) = s^o_k(T,P) - R \ln X_k = s^{ref}_k(T) - R \ln X_k
+ * @f]
  *
  * The partial molar enthalpy for species *k* is
  *
- * \f[
+ * @f[
  *      \tilde{h}_k(T,P) = h^o_k(T,P) = h^{ref}_k(T) + \left( \frac{P - P_{ref}}{C_o} \right)
- * \f]
+ * @f]
  *
  * The partial molar Internal Energy for species *k* is
  *
- * \f[
+ * @f[
  *      \tilde{u}_k(T,P) = u^o_k(T,P) = u^{ref}_k(T)
- * \f]
+ * @f]
  *
  * The partial molar Heat Capacity for species *k* is
  *
- * \f[
+ * @f[
  *      \tilde{Cp}_k(T,P) = Cp^o_k(T,P) = Cp^{ref}_k(T)
- * \f]
+ * @f]
  *
  * The partial molar volume is independent of temperature, pressure, and species
  * identity:
  *
- * \f[
+ * @f[
  *      \tilde{V}_k(T,P) =  V^o_k(T,P) = \frac{1.0}{C_o}
- * \f]
+ * @f]
  *
  * It is assumed that the reference state thermodynamics may be obtained by a
  * pointer to a populated species thermodynamic property manager class (see
@@ -123,142 +123,83 @@ namespace Cantera
  * only has a weak dependence on the enthalpy, and doesn't effect the molar
  * concentration.
  *
- * ## %Application within Kinetics Managers
+ * ## Application within Kinetics Managers
  *
- * \f$ C^a_k\f$ are defined such that \f$ C^a_k = a_k = X_k \f$. \f$ C^s_k \f$,
- * the standard concentration, is defined to be equal to one. \f$ a_k \f$ are
+ * @f$ C^a_k @f$ are defined such that @f$ C^a_k = a_k = X_k @f$. @f$ C^s_k @f$,
+ * the standard concentration, is defined to be equal to one. @f$ a_k @f$ are
  * activities used in the thermodynamic functions.  These activity (or
  * generalized) concentrations are used by kinetics manager classes to compute
  * the forward and reverse rates of elementary reactions. The activity
- * concentration,\f$  C^a_k \f$, is given by the following expression.
+ * concentration,@f$  C^a_k @f$, is given by the following expression.
  *
- * \f[
+ * @f[
  *      C^a_k = C^s_k  X_k  =  X_k
- * \f]
+ * @f]
  *
  * The standard concentration for species *k* is identically one
  *
- * \f[
+ * @f[
  *     C^s_k =  C^s = 1.0
- * \f]
+ * @f]
  *
  * For example, a bulk-phase binary gas reaction between species j and k,
  * producing a new species l would have the following equation for its rate of
- * progress variable, \f$ R^1 \f$, which has units of kmol m-3 s-1.
+ * progress variable, @f$ R^1 @f$, which has units of kmol m-3 s-1.
  *
- * \f[
+ * @f[
  *    R^1 = k^1 C_j^a C_k^a =  k^1  X_j X_k
- * \f]
+ * @f]
  *
  * The reverse rate constant can then be obtained from the law of microscopic
  * reversibility and the equilibrium expression for the system.
  *
- * \f[
+ * @f[
  *     \frac{X_j X_k}{ X_l} = K_a^{o,1} = \exp(\frac{\mu^o_l - \mu^o_j - \mu^o_k}{R T} )
- * \f]
+ * @f]
  *
- * \f$  K_a^{o,1} \f$ is the dimensionless form of the equilibrium constant,
- * associated with the pressure dependent standard states \f$ \mu^o_l(T,P) \f$
+ * @f$  K_a^{o,1} @f$ is the dimensionless form of the equilibrium constant,
+ * associated with the pressure dependent standard states @f$ \mu^o_l(T,P) @f$
  * and their associated activities,
- * \f$ a_l \f$, repeated here:
+ * @f$ a_l @f$, repeated here:
  *
- * \f[
- *      \mu_l(T,P) = \mu^o_l(T, P) + R T \log(a_l)
- * \f]
+ * @f[
+ *      \mu_l(T,P) = \mu^o_l(T, P) + R T \ln a_l
+ * @f]
  *
- * The concentration equilibrium constant, \f$ K_c \f$, may be obtained by
+ * The concentration equilibrium constant, @f$ K_c @f$, may be obtained by
  * changing over to activity concentrations. When this is done:
  *
- * \f[
+ * @f[
  *     \frac{C^a_j C^a_k}{ C^a_l} = C^o K_a^{o,1} = K_c^1 =
  *         \exp(\frac{\mu^{o}_l - \mu^{o}_j - \mu^{o}_k}{R T} )
- * \f]
+ * @f]
  *
- * %Kinetics managers will calculate the concentration equilibrium constant, \f$
- * K_c \f$, using the second and third part of the above expression as a
+ * %Kinetics managers will calculate the concentration equilibrium constant, @f$
+ * K_c @f$, using the second and third part of the above expression as a
  * definition for the concentration equilibrium constant.
  *
- * ## Instantiation of the Class
- *
- * The constructor for this phase is located in the default ThermoFactory for
- * %Cantera. A new LatticePhase object may be created by the following code
- * snippet:
- *
- * @code
- *    XML_Node *xc = get_XML_File("O_lattice_SiO2.xml");
- *    XML_Node * const xs = xc->findNameID("phase", "O_lattice_SiO2");
- *    ThermoPhase *tp = newPhase(*xs);
- *    LatticePhase *o_lattice = dynamic_cast <LatticPhase *>(tp);
- * @endcode
- *
- * or by the following constructor:
- *
- * @code
- *    XML_Node *xc = get_XML_File("O_lattice_SiO2.xml");
- *    XML_Node * const xs = xc->findNameID("phase", "O_lattice_SiO2");
- *    LatticePhase *o_lattice = new LatticePhase(*xs);
- * @endcode
- *
- * The XML file used in this example is listed in the next section
- *
- * ## XML Example
- *
- * An example of an XML Element named phase setting up a LatticePhase object
- * named "O_lattice_SiO2" is given below.
- *
- * @code
- * <!--     phase O_lattice_SiO2      -->
- *   <phase dim="3" id="O_lattice_SiO2">
- *     <elementArray datasrc="elements.xml"> Si  H  He </elementArray>
- *     <speciesArray datasrc="#species_data">
- *       O_O  Vac_O
- *     </speciesArray>
- *     <reactionArray datasrc="#reaction_data"/>
- *     <thermo model="Lattice">
- *       <site_density> 73.159 </site_density>
- *     </thermo>
- *     <kinetics model="BulkKinetics"/>
- *     <transport model="None"/>
- *  </phase>
- *  @endcode
- *
- * The model attribute "Lattice" of the thermo XML element identifies the phase
- * as being of the type handled by the LatticePhase object.
- *
  * @ingroup thermoprops
  */
 class LatticePhase : public ThermoPhase
 {
 public:
-    //! Base Empty constructor
-    LatticePhase();
-
     //! Full constructor for a lattice phase
     /*!
-     * @param inputFile String name of the input file
+     * @param inputFile String name of the input file. If blank,
+     *                  an empty phase will be created.
      * @param id        string id of the phase name
      */
-    LatticePhase(const std::string& inputFile, const std::string& id = "");
+    explicit LatticePhase(const string& inputFile="", const string& id="");
 
-    //! Full constructor for a water phase
-    /*!
-     * @param phaseRef  XML node referencing the lattice phase.
-     * @param id        string id of the phase name
-     *
-     * @deprecated The XML input format is deprecated and will be removed in
-     *     Cantera 3.0.
-     */
-    LatticePhase(XML_Node& phaseRef, const std::string& id = "");
-
-    virtual std::string type() const {
-        return "Lattice";
+    string type() const override {
+        return "lattice";
     }
 
-    virtual bool isCompressible() const {
+    bool isCompressible() const override {
         return false;
     }
 
-    std::map<std::string, size_t> nativeState() const {
+    map<string, size_t> nativeState() const override {
         return { {"T", 0}, {"P", 1}, {"X", 2} };
     }
 
@@ -269,26 +210,26 @@ public:
     /*!
      * For an ideal solution,
      *
-     *   \f[
+     *   @f[
      *    \hat h(T,P) = \sum_k X_k \hat h^0_k(T,P),
-     *   \f]
+     *   @f]
      *
-     * The standard-state pure-species Enthalpies \f$ \hat h^0_k(T,P) \f$ are
+     * The standard-state pure-species Enthalpies @f$ \hat h^0_k(T,P) @f$ are
      * computed first by the species reference state thermodynamic property
      * manager and then a small pressure dependent term is added in.
      *
      * \see MultiSpeciesThermo
      */
-    virtual doublereal enthalpy_mole() const;
+    double enthalpy_mole() const override;
 
     //! Molar entropy of the solution. Units: J/kmol/K
     /*!
      * For an ideal, constant partial molar volume solution mixture with
      * pure species phases which exhibit zero volume expansivity:
-     *   \f[
-     *       \hat s(T, P, X_k) = \sum_k X_k \hat s^0_k(T)  - \hat R  \sum_k X_k log(X_k)
-     *   \f]
-     * The reference-state pure-species entropies \f$ \hat s^0_k(T,p_{ref}) \f$
+     *   @f[
+     *      \hat s(T, P, X_k) = \sum_k X_k \hat s^0_k(T)  - \hat R  \sum_k X_k \ln(X_k)
+     *   @f]
+     * The reference-state pure-species entropies @f$ \hat s^0_k(T,p_{ref}) @f$
      * are computed by the species thermodynamic property manager. The pure
      * species entropies are independent of pressure since the volume
      * expansivities are equal to zero.
@@ -297,54 +238,53 @@ public:
      *
      * @see MultiSpeciesThermo
      */
-    virtual doublereal entropy_mole() const;
+    double entropy_mole() const override;
 
     //! Molar heat capacity at constant pressure of the solution.
     //! Units: J/kmol/K.
     /*!
      * For an ideal, constant partial molar volume solution mixture with
      * pure species phases which exhibit zero volume expansivity:
-     *   \f[
+     *   @f[
      *    \hat c_p(T,P) = \sum_k X_k \hat c^0_{p,k}(T) .
-     *   \f]
+     *   @f]
      * The heat capacity is independent of pressure. The reference-state pure-
-     * species heat capacities \f$ \hat c^0_{p,k}(T) \f$ are computed by the
+     * species heat capacities @f$ \hat c^0_{p,k}(T) @f$ are computed by the
      * species thermodynamic property manager.
      *
      * @see MultiSpeciesThermo
      */
-    virtual doublereal cp_mole() const;
+    double cp_mole() const override;
 
     //! Molar heat capacity at constant volume of the solution.
     //! Units: J/kmol/K.
     /*!
      * For an ideal, constant partial molar volume solution mixture with
      * pure species phases which exhibit zero volume expansivity:
-     *  \f[
+     *  @f[
      *     \hat c_v(T,P) = \hat c_p(T,P)
-     *  \f]
+     *  @f]
      *
      * The two heat capacities are equal.
      */
-    virtual doublereal cv_mole() const;
+    double cv_mole() const override;
 
-    //@}
-    /// @name Mechanical Equation of State Properties
-    /**
-     * In this equation of state implementation, the density is a function only
-     * of the mole fractions. Therefore, it can't be an independent variable.
-     * Instead, the pressure is used as the independent variable. Functions
-     * which try to set the thermodynamic state by calling setDensity() may
-     * cause an exception to be thrown.
-     */
-    //@{
+    //! @}
+    //! @name Mechanical Equation of State Properties
+    //!
+    //! In this equation of state implementation, the density is a function only
+    //! of the mole fractions. Therefore, it can't be an independent variable.
+    //! Instead, the pressure is used as the independent variable. Functions
+    //! which try to set the thermodynamic state by calling setDensity() may
+    //! cause an exception to be thrown.
+    //! @{
 
     //! Pressure. Units: Pa.
     /*!
      * For this incompressible system, we return the internally stored
      * independent value of the pressure.
      */
-    virtual doublereal pressure() const {
+    double pressure() const override {
         return m_Pcurrent;
     }
 
@@ -356,45 +296,44 @@ public:
      *
      * @param p   Input Pressure (Pa)
      */
-    virtual void setPressure(doublereal p);
+    void setPressure(double p) override;
 
     //! Calculate the density of the mixture using the partial molar volumes and
     //! mole fractions as input
     /*!
      * The formula for this is
      *
-     * \f[
+     * @f[
      *      \rho = \frac{\sum_k{X_k W_k}}{\sum_k{X_k V_k}}
-     * \f]
+     * @f]
      *
-     * where \f$X_k\f$ are the mole fractions, \f$W_k\f$ are the molecular
-     * weights, and \f$V_k\f$ are the pure species molar volumes.
+     * where @f$ X_k @f$ are the mole fractions, @f$ W_k @f$ are the molecular
+     * weights, and @f$ V_k @f$ are the pure species molar volumes.
      *
      * Note, the basis behind this formula is that in an ideal solution the
      * partial molar volumes are equal to the pure species molar volumes. We
      * have additionally specified in this class that the pure species molar
      * volumes are independent of temperature and pressure.
      */
-    doublereal calcDensity();
+    double calcDensity();
 
-    //@}
-    /// @name Activities, Standard States, and Activity Concentrations
-    /**
-     * The activity \f$a_k\f$ of a species in solution is related to the
-     * chemical potential by \f[ \mu_k = \mu_k^0(T) + \hat R T \log a_k. \f] The
-     * quantity \f$\mu_k^0(T,P)\f$ is the chemical potential at unit activity,
-     * which depends only on temperature and the pressure. Activity is assumed
-     * to be molality-based here.
-     */
-    //@{
+    //! @}
+    //! @name Activities, Standard States, and Activity Concentrations
+    //!
+    //! The activity @f$ a_k @f$ of a species in solution is related to the
+    //! chemical potential by @f[ \mu_k = \mu_k^0(T) + \hat R T \ln a_k. @f] The
+    //! quantity @f$ \mu_k^0(T,P) @f$ is the chemical potential at unit activity,
+    //! which depends only on temperature and the pressure. Activity is assumed
+    //! to be molality-based here.
+    //! @{
 
-    virtual Units standardConcentrationUnits() const;
-    virtual void getActivityConcentrations(doublereal* c) const;
+    Units standardConcentrationUnits() const override;
+    void getActivityConcentrations(double* c) const override;
 
     //! Return the standard concentration for the kth species
     /*!
-     * The standard concentration \f$ C^0_k \f$ used to normalize
-     * the activity (i.e., generalized) concentration for use
+     * The standard concentration @f$ C^0_k @f$ used to normalize
+     * the activity (that is, generalized) concentration for use
      *
      * For the time being, we will use the concentration of pure solvent for the
      * the standard concentration of all species. This has the effect of making
@@ -404,11 +343,9 @@ public:
      * @param k Optional parameter indicating the species. The default is to
      *         assume this refers to species 0.
      * @returns the standard Concentration in units of m^3/kmol.
-     *
-     * @param k Species index
      */
-    virtual doublereal standardConcentration(size_t k=0) const;
-    virtual doublereal logStandardConc(size_t k=0) const;
+    double standardConcentration(size_t k=0) const override;
+    double logStandardConc(size_t k=0) const override;
 
     //! Get the array of non-dimensional activity coefficients at
     //! the current solution temperature, pressure, and solution concentration.
@@ -417,11 +354,11 @@ public:
      *
      * @param ac Output vector of activity coefficients. Length: m_kk.
      */
-    virtual void getActivityCoefficients(doublereal* ac) const;
+    void getActivityCoefficients(double* ac) const override;
 
-    //@}
-    /// @name  Partial Molar Properties of the Solution
-    //@{
+    //! @}
+    //! @name  Partial Molar Properties of the Solution
+    //! @{
 
     //! Get the species chemical potentials. Units: J/kmol.
     /*!
@@ -432,21 +369,17 @@ public:
      * @param mu  Output vector of species chemical
      *            potentials. Length: m_kk. Units: J/kmol
      */
-    virtual void getChemPotentials(doublereal* mu) const;
-
-    //@}
-    /// @name  Partial Molar Properties of the Solution
-    //@{
+    void getChemPotentials(double* mu) const override;
 
     /**
      * Returns an array of partial molar enthalpies for the species in the
      * mixture. Units (J/kmol). For this phase, the partial molar enthalpies are
      * equal to the pure species enthalpies
-     * \f[
+     * @f[
      * \bar h_k(T,P) = \hat h^{ref}_k(T) + (P - P_{ref}) \hat V^0_k
-     * \f]
-     * The reference-state pure-species enthalpies, \f$ \hat h^{ref}_k(T) \f$,
-     * at the reference pressure,\f$ P_{ref} \f$, are computed by the species
+     * @f]
+     * The reference-state pure-species enthalpies, @f$ \hat h^{ref}_k(T) @f$,
+     * at the reference pressure,@f$ P_{ref} @f$, are computed by the species
      * thermodynamic property manager. They are polynomial functions of
      * temperature.
      * @see MultiSpeciesThermo
@@ -454,18 +387,18 @@ public:
      * @param hbar Output vector containing partial molar enthalpies.
      *             Length: m_kk.
      */
-    virtual void getPartialMolarEnthalpies(doublereal* hbar) const;
+    void getPartialMolarEnthalpies(double* hbar) const override;
 
     /**
      * Returns an array of partial molar entropies of the species in the
      * solution. Units: J/kmol/K. For this phase, the partial molar entropies
      * are equal to the pure species entropies plus the ideal solution
      * contribution.
-     * \f[
-     * \bar s_k(T,P) =  \hat s^0_k(T) - R log(X_k)
-     * \f]
-     * The reference-state pure-species entropies,\f$ \hat s^{ref}_k(T) \f$, at
-     * the reference pressure, \f$ P_{ref} \f$, are computed by the species
+     * @f[
+     * \bar s_k(T,P) =  \hat s^0_k(T) - R \ln(X_k)
+     * @f]
+     * The reference-state pure-species entropies,@f$ \hat s^{ref}_k(T) @f$, at
+     * the reference pressure, @f$ P_{ref} @f$, are computed by the species
      * thermodynamic property manager. They are polynomial functions of
      * temperature.
      * @see MultiSpeciesThermo
@@ -473,7 +406,7 @@ public:
      * @param sbar Output vector containing partial molar entropies.
      *             Length: m_kk.
      */
-    virtual void getPartialMolarEntropies(doublereal* sbar) const;
+    void getPartialMolarEntropies(double* sbar) const override;
 
     /**
      * Returns an array of partial molar Heat Capacities at constant pressure of
@@ -482,15 +415,15 @@ public:
      *
      * @param cpbar  Output vector of partial heat capacities. Length: m_kk.
      */
-    virtual void getPartialMolarCp(doublereal* cpbar) const;
+    void getPartialMolarCp(double* cpbar) const override;
 
-    virtual void getPartialMolarVolumes(doublereal* vbar) const;
-    virtual void getStandardChemPotentials(doublereal* mu) const;
-    virtual void getPureGibbs(doublereal* gpure) const;
+    void getPartialMolarVolumes(double* vbar) const override;
+    void getStandardChemPotentials(double* mu) const override;
+    void getPureGibbs(double* gpure) const override;
 
-    //@}
-    /// @name  Properties of the Standard State of the Species in the Solution
-    //@{
+    //! @}
+    //! @name  Properties of the Standard State of the Species in the Solution
+    //! @{
 
     //! Get the nondimensional Enthalpy functions for the species standard
     //! states at their standard states at the current *T* and *P* of the
@@ -499,9 +432,9 @@ public:
      * A small pressure dependent term is added onto the reference state enthalpy
      * to get the pressure dependence of this term.
      *
-     * \f[
+     * @f[
      *    h^o_k(T,P) = h^{ref}_k(T) +  \left( \frac{P - P_{ref}}{C_o} \right)
-     * \f]
+     * @f]
      *
      * The reference state thermodynamics is obtained by a pointer to a
      * populated species thermodynamic property manager class (see
@@ -511,7 +444,7 @@ public:
      * @param hrt      Output vector of nondimensional standard state enthalpies.
      *                 Length: m_kk.
      */
-    virtual void getEnthalpy_RT(doublereal* hrt) const;
+    void getEnthalpy_RT(double* hrt) const override;
 
     //! Get the array of nondimensional Entropy functions for the species
     //! standard states at the current *T* and *P* of the solution.
@@ -519,9 +452,9 @@ public:
      * The entropy of the standard state is defined as independent of
      * pressure here.
      *
-     * \f[
+     * @f[
      *      s^o_k(T,P) = s^{ref}_k(T)
-     * \f]
+     * @f]
      *
      * The reference state thermodynamics is obtained by a pointer to a
      * populated species thermodynamic property manager class (see
@@ -531,7 +464,7 @@ public:
      * @param sr   Output vector of nondimensional standard state entropies.
      *             Length: m_kk.
      */
-    virtual void getEntropy_R(doublereal* sr) const;
+    void getEntropy_R(double* sr) const override;
 
     //! Get the nondimensional Gibbs functions for the species standard states
     //! at the current *T* and *P* of the solution.
@@ -539,23 +472,23 @@ public:
      * The standard Gibbs free energies are obtained from the enthalpy and
      * entropy formulation.
      *
-     * \f[
+     * @f[
      *      g^o_k(T,P) = h^{o}_k(T,P) - T s^{o}_k(T,P)
-     * \f]
+     * @f]
      *
      * @param grt  Output vector of nondimensional standard state Gibbs free
      *             energies. Length: m_kk.
      */
-    virtual void getGibbs_RT(doublereal* grt) const;
+    void getGibbs_RT(double* grt) const override;
 
     //! Get the nondimensional Heat Capacities at constant pressure for the
     //! species standard states at the current *T* and *P* of the solution
     /*!
      * The heat capacity of the standard state is independent of pressure
      *
-     * \f[
+     * @f[
      *      Cp^o_k(T,P) = Cp^{ref}_k(T)
-     * \f]
+     * @f]
      *
      * The reference state thermodynamics is obtained by a pointer to a
      * populated species thermodynamic property manager class (see
@@ -565,23 +498,15 @@ public:
      * @param cpr   Output vector of nondimensional standard state heat
      *              capacities. Length: m_kk.
      */
-    virtual void getCp_R(doublereal* cpr) const;
+    void getCp_R(double* cpr) const override;
 
-    //! Get the molar volumes of the species standard states at the current
-    //! *T* and *P* of the solution.
-    /*!
-     * units = m^3 / kmol
-     *
-     * @param vol     Output vector containing the standard state volumes.
-     *                Length: m_kk.
-     */
-    virtual void getStandardVolumes(doublereal* vol) const;
+    void getStandardVolumes(double* vol) const override;
 
-    //@}
-    /// @name Thermodynamic Values for the Species Reference States
-    //@{
+    //! @}
+    //! @name Thermodynamic Values for the Species Reference States
+    //! @{
 
-    const vector_fp& enthalpy_RT_ref() const;
+    const vector<double>& enthalpy_RT_ref() const;
 
     //! Returns a reference to the dimensionless reference state Gibbs free
     //! energy vector.
@@ -589,17 +514,17 @@ public:
      * This function is part of the layer that checks/recalculates the reference
      * state thermo functions.
      */
-    const vector_fp& gibbs_RT_ref() const;
+    const vector<double>& gibbs_RT_ref() const;
 
-    virtual void getGibbs_RT_ref(doublereal* grt) const;
-    virtual void getGibbs_ref(doublereal* g) const;
+    void getGibbs_RT_ref(double* grt) const override;
+    void getGibbs_ref(double* g) const override;
 
     //! Returns a reference to the dimensionless reference state Entropy vector.
     /*!
      * This function is part of the layer that checks/recalculates the reference
      * state thermo functions.
      */
-    const vector_fp& entropy_R_ref() const;
+    const vector<double>& entropy_R_ref() const;
 
     //! Returns a reference to the dimensionless reference state Heat Capacity
     //! vector.
@@ -607,54 +532,28 @@ public:
      * This function is part of the layer that checks/recalculates the reference
      * state thermo functions.
      */
-    const vector_fp& cp_R_ref() const;
+    const vector<double>& cp_R_ref() const;
 
-    //@}
-    /// @name  Utilities for Initialization of the Object
-    //@{
+    //! @}
+    //! @name  Utilities for Initialization of the Object
+    //! @{
 
-    virtual bool addSpecies(shared_ptr<Species> spec);
+    bool addSpecies(shared_ptr<Species> spec) override;
 
     //! Set the density of lattice sites [kmol/m^3]
     void setSiteDensity(double sitedens);
 
-    virtual void initThermo();
+    void initThermo() override;
+    void getParameters(AnyMap& phaseNode) const override;
+    void getSpeciesParameters(const string& name, AnyMap& speciesNode) const override;
 
-    //! Set equation of state parameter values from XML entries.
-    /*!
-     * This method is called by function importPhase() when processing a phase
-     * definition in an input file. It should be overloaded in subclasses to set
-     * any parameters that are specific to that particular phase
-     * model. Note, this method is called before the phase is
-     * initialized with elements and/or species.
-     *
-     * For this phase, the molar density of the phase is specified in this
-     * block, and is a required parameter.
-     *
-     * @param eosdata An XML_Node object corresponding to
-     *                the "thermo" entry for this phase in the input file.
-     *
-     * eosdata points to the thermo block, and looks like this:
-     *
-     * @code
-     * <phase id="O_lattice_SiO2" >
-     *   <thermo model="Lattice">
-     *     <site_density units="kmol/m^3"> 73.159 </site_density>
-     *   </thermo>
-     * </phase>
-     * @endcode
-     *
-     * @deprecated The XML input format is deprecated and will be removed in
-     *     Cantera 3.0.
-     */
-    virtual void setParametersFromXML(const XML_Node& eosdata);
-    //@}
+    //! @}
 
 protected:
-    virtual void compositionChanged();
+    void compositionChanged() override;
 
     //! Reference state pressure
-    doublereal m_Pref;
+    double m_Pref = OneAtm;
 
     //! The current pressure
     /*!
@@ -663,26 +562,26 @@ protected:
      * variable which is inherited as part of the State class, m_dens, is always
      * kept current whenever T, P, or X[] change.
      */
-    doublereal m_Pcurrent;
+    double m_Pcurrent = OneAtm;
 
     //! Reference state enthalpies / RT
-    mutable vector_fp m_h0_RT;
+    mutable vector<double> m_h0_RT;
 
     //! Temporary storage for the reference state heat capacities
-    mutable vector_fp m_cp0_R;
+    mutable vector<double> m_cp0_R;
 
     //! Temporary storage for the reference state Gibbs energies
-    mutable vector_fp m_g0_RT;
+    mutable vector<double> m_g0_RT;
 
     //! Temporary storage for the reference state entropies at the current
     //! temperature
-    mutable vector_fp m_s0_R;
+    mutable vector<double> m_s0_R;
 
     //! Vector of molar volumes for each species in the solution
     /**
-     * Species molar volumes \f$ m^3 kmol^-1 \f$
+     * Species molar volumes @f$ m^3 kmol^-1 @f$
      */
-    vector_fp m_speciesMolarVolume;
+    vector<double> m_speciesMolarVolume;
 
     //! Site Density of the lattice solid
     /*!
@@ -690,7 +589,7 @@ protected:
      *
      *  units are kmol m-3
      */
-    doublereal m_site_density;
+    double m_site_density = 0.0;
 
 private:
     //! Update the species reference state thermodynamic functions
