@@ -59,23 +59,6 @@ public:
 
     int standardStateConvention() const override;
 
-    //! @}
-    //! @name  Partial Molar Properties of the Solution (VPStandardStateTP)
-    //! @{
-
-    //! Get the array of non-dimensional species chemical potentials.
-    /*!
-     * These are partial molar Gibbs free energies, @f$ \mu_k / \hat R T @f$.
-     *
-     * We close the loop on this function, here, calling getChemPotentials() and
-     * then dividing by RT. No need for child classes to handle.
-     *
-     * @param mu    Output vector of non-dimensional species chemical potentials
-     *              Length: m_kk.
-     * @deprecated To be removed after %Cantera 3.0. Use getChemPotentials() instead.
-     */
-    void getChemPotentials_RT(double* mu) const override;
-
     //! @}
     //! @name  Properties of the Standard State of the Species in the Solution
     //!
