@@ -148,14 +148,16 @@ public:
                                         double* bstar_coeffs,
                                         double* cstar_coeffs, bool actualT) override;
 
-    void init(ThermoPhase* thermo, int mode=0, int log_level=0) override;
+    void init(ThermoPhase* thermo, int mode=0, int log_level=-7) override;
 
     bool CKMode() const override {
         return m_mode == CK_Mode;
     }
 
+    void invalidateCache() override;
+
 protected:
-    GasTransport(ThermoPhase* thermo=0);
+    GasTransport();
 
     virtual void update_T();
     virtual void update_C() = 0;
@@ -541,7 +543,8 @@ protected:
     //! Quadrupole polarizability
     vector<double> m_quad_polar;
 
-    //! Level of verbose printing during initialization
+    //! Level of verbose printing during initialization.
+    //! @deprecated To be removed after %Cantera 3.1.
     int m_log_level = 0;
 };
 
