@@ -26,10 +26,7 @@ class MultiTransport : public GasTransport
 {
 public:
     //! default constructor
-    /*!
-     * @param thermo  Optional parameter for the pointer to the ThermoPhase object
-     */
-    MultiTransport(ThermoPhase* thermo=0);
+    MultiTransport() = default;
 
     string transportModel() const override {
         return (m_mode == CK_Mode) ? "multicomponent-CK" : "multicomponent";
@@ -103,7 +100,9 @@ public:
     void getMassFluxes(const double* state1, const double* state2, double delta,
                        double* fluxes) override;
 
-    void init(ThermoPhase* thermo, int mode=0, int log_level=0) override;
+    void init(ThermoPhase* thermo, int mode=0, int log_level=-7) override;
+
+    void invalidateCache() override;
 
 protected:
     //! Update basic temperature-dependent quantities if the temperature has
