@@ -54,16 +54,22 @@ public:
      *  @param model     String name for the transport manager
      *  @param thermo    ThermoPhase object
      *  @param log_level log level
+     *
+     *  @deprecated The `log_level` parameter is deprecated and will be removed after
+     *      %Cantera 3.1.
      */
-    Transport* newTransport(const string& model, ThermoPhase* thermo, int log_level=0);
+    Transport* newTransport(const string& model, ThermoPhase* thermo, int log_level=-7);
 
     //! Build a new transport manager using the default transport manager
     //! in the phase description and return a base class pointer to it
     /*!
      * @param thermo    ThermoPhase object
      * @param log_level log level
+     *
+     * @deprecated The `log_level` parameter is deprecated and will be removed after
+     *     %Cantera 3.1.
      */
-    Transport* newTransport(ThermoPhase* thermo, int log_level=0);
+    Transport* newTransport(ThermoPhase* thermo, int log_level=-7);
 
 private:
     //! Static instance of the factor -> This is the only instance of this
@@ -86,11 +92,6 @@ private:
     map<string, bool> m_CK_mode;
 };
 
-//! @copydoc TransportFactory::newTransport(const string&, ThermoPhase*, int)
-//! @deprecated To be removed after %Cantera 3.0; superseded by newTransport()
-Transport* newTransportMgr(const string& model="", ThermoPhase* thermo=0,
-                           int log_level=0);
-
 //!  Create a new Transport instance.
 /*!
  *  @param thermo   the ThermoPhase object associated with the phase
@@ -102,20 +103,6 @@ Transport* newTransportMgr(const string& model="", ThermoPhase* thermo=0,
 shared_ptr<Transport> newTransport(shared_ptr<ThermoPhase> thermo,
                                    const string& model="default");
 
-//! @copydoc newTransport(shared_ptr<ThermoPhase>, const string&)
-//! @deprecated To be removed after %Cantera 3.0; superseded by newTransport()
-shared_ptr<Transport> newTransport(ThermoPhase* thermo, const string& model="default");
-
-//!  Create a new transport manager instance.
-/*!
- *  @param thermo     ThermoPhase object associated with the phase
- *  @param loglevel   int containing the Loglevel, defaults to zero
- *  @returns a transport manager for the phase
- * @deprecated To be removed after %Cantera 3.0; superseded by newTransport()
- * @ingroup tranprops
- */
-Transport* newDefaultTransportMgr(ThermoPhase* thermo, int loglevel = 0);
-
 } // End of namespace Cantera
 
 #endif
