@@ -14,25 +14,18 @@ namespace Cantera
 
 //! Factory class to create FlowDevice objects.
 //!
-//! This class is mainly used via the newFlowDevice3() function, for example:
+//! This class is mainly used via the newFlowDevice() function, for example:
 //!
 //! ```cpp
-//!     shared_ptr<FlowDevice> mfc = newFlowDevice3("MassFlowController");
+//!     shared_ptr<FlowDevice> mfc = newFlowDevice("MassFlowController");
 //! ```
-class FlowDeviceFactory : public Factory<FlowDevice>
+class FlowDeviceFactory : public Factory<FlowDevice, const string&>
 {
 public:
     static FlowDeviceFactory* factory();
 
     void deleteFactory() override;
 
-    //! Create a new flow device by type name.
-    /*!
-     * @param flowDeviceType the type to be created.
-     * @deprecated To be removed after %Cantera 3.0; replaceable by newFlowDevice3.
-     */
-    FlowDevice* newFlowDevice(const string& flowDeviceType);
-
 private:
     static FlowDeviceFactory* s_factory;
     static std::mutex flowDevice_mutex;
@@ -41,23 +34,22 @@ private:
 
 //! @defgroup flowDeviceGroup Flow Devices
 //! Flow device objects connect zero-dimensional reactors.
-//! FlowDevice objects should be instantiated via the newFlowDevice3() function, for
+//! FlowDevice objects should be instantiated via the newFlowDevice function, for
 //! example:
 //!
 //! ```cpp
-//!     shared_ptr<FlowDevice> mfc = newFlowDevice3("MassFlowController");
+//!     shared_ptr<FlowDevice> mfc = newFlowDevice("MassFlowController", "my_mfc");
 //! ```
 //! @ingroup zerodGroup
 //! @{
 
 //! Create a FlowDevice object of the specified type
-//! @deprecated To be changed after %Cantera 3.0; for new behavior, see
-//! newFlowDevice3().
-FlowDevice* newFlowDevice(const string& model);
+//! @since Starting in %Cantera 3.1, this method returns a `shared_ptr<FlowDevice>`
+shared_ptr<FlowDevice> newFlowDevice(const string& model, const string& name="(none)");
 
 //! Create a FlowDevice object of the specified type
 //! @since New in %Cantera 3.0.
-//! @todo Transition back to newFlowDevice() after %Cantera 3.0
+//! @deprecated Replaced by newFlowDevice. To be removed after %Cantera 3.1.
 shared_ptr<FlowDevice> newFlowDevice3(const string& model);
 
 //! @}
