@@ -16,7 +16,7 @@ namespace Cantera
 class FlowReactor : public IdealGasReactor
 {
 public:
-    FlowReactor() = default;
+    using IdealGasReactor::IdealGasReactor; // inherit constructors
 
     string type() const override {
         return "FlowReactor";
@@ -30,7 +30,7 @@ public:
         return false;
     }
 
-    //! Not implemented; FlowReactor implements getStateDAE() instead.
+    //! Not implemented; FlowReactor implements getStateDae() instead.
     void getState(double* y) override {
         throw NotImplementedError("FlowReactor::getState");
     }
@@ -62,10 +62,6 @@ public:
         return m_area;
     }
 
-    //! @deprecated To be removed after %Cantera 3.0. Access distance through the
-    //!     ReactorNet object
-    double distance() const;
-
     //! Sets the area of the reactor [m^2]
     void setArea(double area);
 
