@@ -22,14 +22,12 @@ namespace Cantera
 class IdealGasConstPressureReactor : public ConstPressureReactor
 {
 public:
-    IdealGasConstPressureReactor() {}
+    using ConstPressureReactor::ConstPressureReactor; // inherit constructors
 
     string type() const override {
         return "IdealGasConstPressureReactor";
     }
 
-    void setThermoMgr(ThermoPhase& thermo) override;
-
     void getState(double* y) override;
 
     void initialize(double t0=0.0) override;
@@ -45,6 +43,8 @@ public:
     string componentName(size_t k) override;
 
 protected:
+    void setThermo(ThermoPhase& thermo) override;
+
     vector<double> m_hk; //!< Species molar enthalpies
 };
 }
