@@ -20,14 +20,12 @@ namespace Cantera
 class IdealGasReactor : public Reactor
 {
 public:
-    IdealGasReactor() {}
+    using Reactor::Reactor; // inherit constructors
 
     string type() const override {
         return "IdealGasReactor";
     }
 
-    void setThermoMgr(ThermoPhase& thermo) override;
-
     void getState(double* y) override;
 
     void initialize(double t0=0.0) override;
@@ -44,6 +42,8 @@ public:
     string componentName(size_t k) override;
 
 protected:
+    void setThermo(ThermoPhase& thermo) override;
+
     vector<double> m_uk; //!< Species molar internal energies
 };
 
