@@ -38,12 +38,16 @@ class AnyMap;
  *  - surface heat loss rate (W)
  *  - species surface production rates (kmol/s)
  *
+ * See the [Science Reference](../reference/reactors/controlreactor.html) for
+ * the governing equations of class Reactor.
+ *
  * @ingroup reactorGroup
  */
 class Reactor : public ReactorBase
 {
 public:
-    Reactor() = default;
+    Reactor(shared_ptr<Solution> sol, const string& name="(none)");
+    using ReactorBase::ReactorBase; // inherit constructors
 
     string type() const override {
         return "Reactor";
@@ -65,16 +69,16 @@ public:
     /**
      * Insert something into the reactor. The 'something' must belong to a class
      * that is a subclass of both ThermoPhase and Kinetics.
+     * @deprecated Unused; to be removed after %Cantera 3.1.
      */
     template<class G>
     void insert(G& contents) {
-        setThermoMgr(contents);
-        setKineticsMgr(contents);
+        warn_deprecated("Reactor::insert", "Unused; to be removed after Cantera 3.1.");
+        setThermo(contents);
+        setKinetics(contents);
     }
 
-    void insert(shared_ptr<Solution> sol);
-
-    void setKineticsMgr(Kinetics& kin) override;
+    using ReactorBase::insert;
 
     void setChemistry(bool cflag=true) override {
         m_chem = cflag;
@@ -238,6 +242,8 @@ public:
     virtual bool preconditionerSupported() const {return false;};
 
 protected:
+    void setKinetics(Kinetics& kin) override;
+
     //! Return the index in the solution vector for this reactor of the species
     //! named *nm*, in either the homogeneous phase or a surface phase, relative
     //! to the start of the species terms. Used to implement componentIndex for
