@@ -14,11 +14,9 @@ namespace Cantera
 
 //! @defgroup zerodGroup Zero-Dimensional Reactor Networks
 //!
-//! @details See the
-//! [Reactor Science](https://cantera.org/science/reactors/reactors.html)
-//! section of the %Cantera website for a description of the governing equations for
-//! specific reactor types and the methods used for solving networks of interconnected
-//! reactors.
+//! @details See the [Reactor Science](../reference/reactors/index.html) section of the
+//! %Cantera website for a description of the governing equations for specific reactor
+//! types and the methods used for solving networks of interconnected reactors.
 
 class FlowDevice;
 class WallBase;
@@ -26,6 +24,7 @@ class ReactorNet;
 class ReactorSurface;
 class Kinetics;
 class ThermoPhase;
+class Solution;
 
 enum class SensParameterType {
     reaction,
@@ -49,8 +48,13 @@ struct SensitivityParameter
 class ReactorBase
 {
 public:
-    explicit ReactorBase(const string& name = "(none)");
-    virtual ~ReactorBase() = default;
+    explicit ReactorBase(const string& name="(none)");
+    //! Instantiate a ReactorBase object with Solution contents.
+    //! @param sol  Solution object to be set.
+    //! @param name  Name of the reactor.
+    //! @since New in %Cantera 3.1.
+    ReactorBase(shared_ptr<Solution> sol, const string& name="(none)");
+    virtual ~ReactorBase();
     ReactorBase(const ReactorBase&) = delete;
     ReactorBase& operator=(const ReactorBase&) = delete;
 
@@ -70,6 +74,14 @@ public:
         m_name = name;
     }
 
+    //! Set the default name of a reactor. Returns `false` if it was previously set.
+    bool setDefaultName(map<string, int>& counts);
+
+    //! Set the Solution specifying the ReactorBase content.
+    //! @param sol  Solution object to be set.
+    //! @since New in %Cantera 3.1.
+    void setSolution(shared_ptr<Solution> sol);
+
     //! @name Methods to set up a simulation
     //! @{
 
@@ -78,15 +90,17 @@ public:
         m_vol = vol;
     }
 
+    //! @deprecated To be removed after %Cantera 3.1. Superseded by setSolution.
+    void insert(shared_ptr<Solution> sol);
+
     //! Specify the mixture contained in the reactor. Note that a pointer to
     //! this substance is stored, and as the integration proceeds, the state of
     //! the substance is modified.
-    virtual void setThermoMgr(ThermoPhase& thermo);
+    //! @deprecated To be removed after %Cantera 3.1. Superseded by setSolution.
+    void setThermoMgr(ThermoPhase& thermo);
 
-    //! Specify chemical kinetics governing the reactor.
-    virtual void setKineticsMgr(Kinetics& kin) {
-        throw NotImplementedError("ReactorBase::setKineticsMgr");
-    }
+    //! @deprecated To be removed after %Cantera 3.1. Superseded by setSolution.
+    void setKineticsMgr(Kinetics& kin);
 
     //! Enable or disable changes in reactor composition due to chemical reactions.
     virtual void setChemistry(bool cflag = true) {
@@ -202,11 +216,19 @@ public:
 
     //! Returns the current density (kg/m^3) of the reactor's contents.
     double density() const {
+        if (m_state.empty()) {
+            throw CanteraError("ReactorBase::density",
+                               "Reactor state empty and/or contents not defined.");
+        }
         return m_state[1];
     }
 
     //! Returns the current temperature (K) of the reactor's contents.
     double temperature() const {
+        if (m_state.empty()) {
+            throw CanteraError("ReactorBase::temperature",
+                               "Reactor state empty and/or contents not defined.");
+        }
         return m_state[0];
     }
 
@@ -232,11 +254,19 @@ public:
 
     //! Return the vector of species mass fractions.
     const double* massFractions() const {
+        if (m_state.empty()) {
+            throw CanteraError("ReactorBase::massFractions",
+                               "Reactor state empty and/or contents not defined.");
+        }
         return m_state.data() + 2;
     }
 
     //! Return the mass fraction of the *k*-th species.
     double massFraction(size_t k) const {
+        if (m_state.empty()) {
+            throw CanteraError("ReactorBase::massFraction",
+                               "Reactor state empty and/or contents not defined.");
+        }
         return m_state[k+2];
     }
 
@@ -249,6 +279,18 @@ public:
     void setNetwork(ReactorNet* net);
 
 protected:
+    //! Specify the mixture contained in the reactor. Note that a pointer to
+    //! this substance is stored, and as the integration proceeds, the state of
+    //! the substance is modified.
+    //! @since New in %Cantera 3.1.
+    virtual void setThermo(ThermoPhase& thermo);
+
+    //! Specify the kinetics manager for the reactor. Called by setSolution().
+    //! @since New in %Cantera 3.1.
+    virtual void setKinetics(Kinetics& kin) {
+        throw NotImplementedError("ReactorBase::setKinetics");
+    }
+
     //! Number of homogeneous species in the mixture
     size_t m_nsp = 0;
 
@@ -266,10 +308,14 @@ protected:
     //! Vector of length nWalls(), indicating whether this reactor is on the left (0)
     //! or right (1) of each wall.
     vector<int> m_lr;
-    string m_name;
+    string m_name;  //!< Reactor name.
+    bool m_defaultNameSet = false;  //!< `true` if default name has been previously set.
 
     //! The ReactorNet that this reactor is part of
     ReactorNet* m_net = nullptr;
+
+    //! Composite thermo/kinetics/transport handler
+    shared_ptr<Solution> m_solution;
 };
 }
 
