@@ -18,7 +18,7 @@ namespace Cantera
 class Reservoir : public ReactorBase
 {
 public:
-    Reservoir() {}
+    using ReactorBase::ReactorBase; // inherit constructors
 
     string type() const override {
         return "Reservoir";
@@ -26,13 +26,14 @@ public:
 
     void initialize(double t0=0.0) override {}
 
+    //! @deprecated Unused; to be removed after %Cantera 3.1.
     void insert(ThermoPhase& contents) {
-        setThermoMgr(contents);
+        warn_deprecated("Reservoir::insert",
+            "Unused; to be removed after Cantera 3.1.");
+        setThermo(contents);
     }
 
-    void insert(shared_ptr<Solution> sol) {
-        setThermoMgr(*sol->thermo());
-    }
+    using ReactorBase::insert;
 };
 
 }
