@@ -21,7 +21,7 @@ class Func1;
 class WallBase
 {
 public:
-    WallBase() = default;
+    WallBase(const string& name="(none)") : m_name(name) {}
 
     virtual ~WallBase() {}
     WallBase(const WallBase&) = delete;
@@ -33,18 +33,19 @@ public:
         return "WallBase";
     }
 
-    //! Rate of volume change (m^3/s) for the adjacent reactors.
-    /*!
-     * This method is called by Reactor::evalWalls(). Base class method
-     * does nothing (that is, constant volume), but may be overloaded.
-     * @deprecated To be removed after %Cantera 3.0; replaceable by expansionRate.
-     */
-    virtual double vdot(double t) {
-        warn_deprecated("WallBase::vdot",
-            "To be removed after Cantera 3.0; replaceable by 'expansionRate'.");
-        return 0.0;
+    //! Retrieve wall name.
+    string name() const {
+        return m_name;
     }
 
+    //! Set wall name.
+    void setName(const string& name) {
+        m_name = name;
+    }
+
+    //! Set the default name of a wall. Returns `false` if it was previously set.
+    bool setDefaultName(map<string, int>& counts);
+
     //! Rate of volume change (m^3/s) for the adjacent reactors at current reactor
     //! network time.
     /*!
@@ -56,18 +57,6 @@ public:
         return 0.0;
     }
 
-    //! Heat flow rate through the wall (W).
-    /*!
-     * This method is called by Reactor::evalWalls(). Base class method
-     * does nothing (that is, an adiabatic wall), but may be overloaded.
-     * @deprecated To be removed after %Cantera 3.0; replaceable by heatRate.
-     */
-    virtual double Q(double t) {
-        warn_deprecated("WallBase::Q",
-            "To be removed after Cantera 3.0; replaceable by 'heatRate'.");
-        return 0.0;
-    }
-
     //! Heat flow rate through the wall (W) at current reactor network time.
     /*!
      * This method is called by Reactor::evalWalls(). Base class method
@@ -103,7 +92,7 @@ public:
     }
 
     //! Return a reference to the Reactor or Reservoir to the right of the wall.
-    const ReactorBase& right() {
+    ReactorBase& right() {
         return *m_right;
     }
 
@@ -116,6 +105,9 @@ public:
     }
 
 protected:
+    string m_name;  //!< Wall name.
+    bool m_defaultNameSet = false;  //!< `true` if default name has been previously set.
+
     ReactorBase* m_left = nullptr;
     ReactorBase* m_right = nullptr;
 
@@ -134,7 +126,7 @@ protected:
 class Wall : public WallBase
 {
 public:
-    Wall() = default;
+    using WallBase::WallBase;  // inherit constructors
 
     //! String indicating the wall model implemented. Usually
     //! corresponds to the name of the derived class.
@@ -153,21 +145,6 @@ public:
         }
     }
 
-    //! Rate of volume change (m^3/s) for the adjacent reactors.
-    /*!
-     * The volume rate of change is given by
-     * @f[
-     *     \dot V = K A (P_{left} - P_{right}) + F(t)
-     * @f]
-     * where *K* is the specified expansion rate coefficient, *A* is the wall
-     * area, and *F(t)* is a specified function of time. Positive values for
-     * `vdot` correspond to increases in the volume of reactor on left, and
-     * decreases in the volume of the reactor on the right.
-     * @deprecated Still used by traditional MATLAB toolbox; replaceable by
-     *      expansionRate.
-     */
-    double vdot(double t) override;
-
     //! Rate of volume change (m^3/s) for the adjacent reactors.
     /*!
      * The volume rate of change is given by
@@ -191,19 +168,6 @@ public:
         m_qf = q;
     }
 
-    //! Heat flow rate through the wall (W).
-    /*!
-     * The heat flux is given by
-     * @f[
-     *     Q = h A (T_{left} - T_{right}) + A G(t)
-     * @f]
-     * where *h* is the heat transfer coefficient, *A* is the wall area, and
-     * *G(t)* is a specified function of time. Positive values denote a flux
-     * from left to right.
-     * @deprecated Still used by traditional MATLAB toolbox; replaceable by heatRate.
-     */
-    double Q(double t) override;
-
     //! Heat flow rate through the wall (W).
     /*!
      * The heat flux is given by
