@@ -14,25 +14,18 @@ namespace Cantera
 
 //! Factory class to create WallBase objects
 //!
-//! This class is mainly used via the newWall3() function, for example:
+//! This class is mainly used via the newWall() function, for example:
 //!
 //! ```cpp
-//!     shared_ptr<WallBase> piston = newWall3("Wall");
+//!     shared_ptr<WallBase> piston = newWall("Wall");
 //! ```
-class WallFactory : public Factory<WallBase>
+class WallFactory : public Factory<WallBase, const string&>
 {
 public:
     static WallFactory* factory();
 
     void deleteFactory() override;
 
-    //! Create a new wall by type name.
-    /*!
-     * @param wallType the type to be created.
-     * @deprecated To be removed after %Cantera 3.0; replaceable by newWall3.
-     */
-    WallBase* newWall(const string& wallType);
-
 private:
     static WallFactory* s_factory;
     static std::mutex wall_mutex;
@@ -41,22 +34,22 @@ private:
 
 //! @defgroup wallGroup Walls
 //! Zero-dimensional objects adjacent to reactors.
-//! Wall objects should be instantiated via the newWall3() function, for
+//! Wall objects should be instantiated via the newWall function, for
 //! example:
 //!
 //! ```cpp
-//!     shared_ptr<WallBase> piston = newWall3("Wall");
+//!     shared_ptr<WallBase> piston = newWall("Wall", "my_piston");
 //! ```
 //! @ingroup zerodGroup
 //! @{
 
 //! Create a WallBase object of the specified type
-//! @deprecated To be changed after %Cantera 3.0; for new behavior, see newWall3().
-WallBase* newWall(const string& model);
+//! @since Starting in %Cantera 3.1, this method returns a `shared_ptr<WallBase>`
+shared_ptr<WallBase> newWall(const string& model, const string& name="(none)");
 
 //! Create a WallBase object of the specified type
 //! @since New in %Cantera 3.0.
-//! @todo Transition back to newWall() after %Cantera 3.0
+//! @deprecated Replaced by newWall. To be removed after %Cantera 3.1.
 shared_ptr<WallBase> newWall3(const string& model);
 
 //! @}
