@@ -170,7 +170,7 @@ def build_species_text(species: Iterable[ct.Species], max_width=80) -> str:
 
     .. versionadded:: 3.0
     """
-    species_names = {s.name: s.input_data.get("note", "") for s in species}
+    species_names = {s.name: str(s.input_data.get('note', '')) for s in species}
 
     # Notes shorter than 7 characters are probably related to thermo entries
     # and will be included with the thermo entry.
@@ -287,7 +287,7 @@ def build_thermodynamics_text(
         if spec.thermo.max_temp > max_temp:
             max_temp = spec.thermo.max_temp
 
-        note = input_data["thermo"].get("note", "")
+        note = str(input_data['thermo'].get('note', ''))
         if len(note) <= 6:
             comment = ""
             fmt_data["note"] = note
@@ -318,6 +318,7 @@ def build_thermodynamics_text(
         fmt_data["coeff_11_14"] = four_coeff_line.format(*low_coeffs[3:])
         text = fmt.format(**fmt_data)
         if comment:
+            comment = comment.replace("\n", "\n!")
             text = f"!{comment}\n" + text
         thermo_data[spec.name] = text
 
@@ -336,16 +337,20 @@ def build_thermodynamics_text(
     )
 
 
-def build_reactions_text(reactions: Iterable[ct.Reaction]):
+def build_reactions_text(reactions: Iterable[ct.Reaction], species: Iterable[ct.Species]):
     """
     Create the reaction definition section of this file.
 
     :param reactions:
         An iterable of `cantera.Reaction` instances to be included.
+    :param species:
+        An iterable of `cantera.Species` definitions for this file.
 
     .. versionadded:: 3.0
     """
 
+    species_names = {spec.name for spec in species}
+
     # Note: Cantera converts explicit reverse rate coefficients given by the ``REV``
     # keyword into two independent irreversible reactions. Therefore, there's no need to
     # handle the ``REV`` keyword in this function.
@@ -478,6 +483,7 @@ def build_reactions_text(reactions: Iterable[ct.Reaction]):
                 " ".join(
                     f"{spec}/{value:.3E}/"
                     for spec, value in reac.third_body.efficiencies.items()
+                    if spec in species_names
                 )
             )
 
@@ -699,9 +705,9 @@ def convert(
         ]
         thermo_path.write_text("\n".join(thermo_text))
 
-    # TODO: Handle phases without reactions
     all_reactions = solution.reactions()
-    mechanism_text.append(build_reactions_text(all_reactions))
+    if all_reactions:
+        mechanism_text.append(build_reactions_text(all_reactions, all_species))
 
     if transport_path is None and transport_exists:
         mechanism_text.append(build_transport_text(all_species, separate_file=False))
@@ -826,7 +832,7 @@ def main():
             print("Validating mechanism...", end="")
             with tempfile.TemporaryDirectory() as td:
                 out_name = Path(td) / "test_mech.yaml"
-                ck2yaml.convert_mech(
+                ck2yaml.convert(
                     *ck_paths,
                     phase_name="gas",
                     out_name=out_name,
