@@ -1,7 +1,11 @@
 classdef Kinetics < handle
     % Kinetics Class ::
     %
-    %     >> k = Kinetics(varargin)
+    %     >> k = Kinetics(id)
+    %
+    % Retrieve instance of class :mat:class:`Kinetics` associated with a
+    % :mat:class:`Solution` object. The constructor is called whenever a new
+    % :mat:class:`Solution` is instantiated and should not be used directly.
     %
     % Class :mat:class:`Kinetics` represents kinetics managers, which manage
     % reaction mechanisms. The reaction mechanism attributes are specified in a
@@ -11,32 +15,10 @@ classdef Kinetics < handle
     % reaction rates of progress, species production rates, and other
     % quantities pertaining to a reaction mechanism.
     %
-    % :param varargin:
-    %     Variable number of inputs consisting of the following:
-    %       - ph:
-    %           An instance of class :mat:class:`ThermoPhase` representing the
-    %           phase in which reactions occur.
-    %       - src:
-    %           Input string of YAML file name when creating from file OR
-    %           "clib" when called by the class constructors of :mat:class:`Solution`
-    %           or :mat:class:`Interface`.
-    %     Optional:
-    %       - id:
-    %           ID of the phase to import as specified in the input file.
-    %       - neighbor1:
-    %           Instance of class :mat:class:`ThermoPhase` or
-    %           :mat:class:`Solution` representing the 1st neighboring phase.
-    %       - neighbor2:
-    %           Instance of class :mat:class:`ThermoPhase` or
-    %           :mat:class:`Solution` representing the 2nd neighboring phase.
-    %       - neighbor3:
-    %           Instance of class :mat:class:`ThermoPhase` or
-    %           :mat:class:`Solution` representing the 3rd neighboring phase.
-    %       - neighbor4:
-    %           Instance of class :mat:class:`ThermoPhase` or
-    %           :mat:class:`Solution` representing the 4th neighboring phase.
+    % :param id:
+    %     Integer ID of the solution holding the :mat:class:`Kinetics` object.
     % :return:
-    %      Instance of class :mat:class:`Kinetics`.
+    %     Instance of class :mat:class:`Kinetics`.
 
     properties (SetAccess = immutable)
         kinID % ID of the Kinetics object.
@@ -72,10 +54,8 @@ classdef Kinetics < handle
         %     >> k = kin.equilibriumConstants
         %
         % :return:
-        %    A column vector of the equilibrium constants for all
-        %    reactions. The vector has an entry for every reaction,
-        %    whether reversible or not, but non-zero values occur only
-        %    for the reversible reactions.
+        %    A column vector of the equilibrium constants in concentration units for all
+        %    reactions, calculated from the standard Gibbs free energy of reaction.
         equilibriumConstants
 
         forwardRateConstants % Forward reaction rate constants for all reactions.
@@ -114,62 +94,30 @@ classdef Kinetics < handle
     methods
         %% Kinetics Class Constructor
 
-        function kin = Kinetics(varargin)
+        function kin = Kinetics(id)
 
             ctIsLoaded;
 
-            tmp = varargin{1};
-            src = varargin{2};
-
-            if ischar(tmp) & isnumeric(src)
-                if strcmp(tmp, 'clib')
-                    kin.kinID = ctFunc('soln_kinetics', src);
-                    return
-                end
+            if ~isnumeric(id)
+                error('Invalid argument: constructor requires integer solution ID.')
             end
 
-            ph = tmp.tpID;
-
-            if nargin == 2
-                id = '-';
-            elseif nargin > 2
-                id = varargin{3};
-            end
-
-            neighbours = {-1, -1, -1, -1};
-
-            for i = 4:length(varargin)
-                neighbours{i-3} = varargin{i}.tpID;
-            end
-
-            kin.kinID = ctFunc('kin_newFromFile', src, id, ph, neighbours{:});
-        end
-
-        %% Kinetics Class Destructor
-
-        function delete(kin)
-            % Delete the :mat:class:`Sim1D` object.
-
-            if ~isa(kin, 'Solution') && ~isa(kin, 'Interface')
-                ctFunc('kin_del', kin.kinID);
-            end
+            kin.kinID = ctFunc('soln_kinetics', id);
         end
 
         %% Get scalar attributes
 
-        function n = kineticsSpeciesIndex(kin, name, phase)
+        function n = kineticsSpeciesIndex(kin, name)
             % Get the species index of a species of a phase in the Kinetics class. ::
             %
-            %     >> n = kin.kineticsSpeciesIndex(name, phase)
+            %     >> n = kin.kineticsSpeciesIndex(name)
             %
             % :param name:
-            %    String name of the species.
-            % :param phase:
-            %    String name of the phase.
+            %    String name or integer index of the species.
             % :return:
             %    Index of the species.
 
-            n = ctFunc('kin_speciesIndex', kin.kinID, name, phase) + 1;
+            n = ctFunc('kin_speciesIndex', kin.kinID, name) + 1;
         end
 
         function n = multiplier(kin, irxn)
@@ -231,21 +179,23 @@ classdef Kinetics < handle
             %     >> n = kin.reactantStoichCoeffs(species, rxns)
             %
             % :param species:
-            %    Species indices for which reactant stoichiometric
-            %    coefficients should be retrieved. Optional argument; if
-            %    specified, ``rxns`` must be specified as well.
+            %    Species indices or names for which reactant stoichiometric
+            %    coefficients should be retrieved.
+            %    Optional argument; if specified, ``rxns`` must be specified as well.
             % :param rxns:
             %    Reaction indices for which reactant stoichiometric
             %    coefficients should be retrieved. Optional argument; if
             %    specified, ``species`` must be specified as well.
             % :return:
             %    Returns a sparse matrix of all reactant stoichiometric
-            %    coefficients. The matrix elements ``nu(k, i)`` is the
-            %    stoichiometric coefficient of species k as a reactant in
-            %    reaction i. If ``species`` and ``rxns`` are specified, the
-            %    matrix will contain only entries for the specified species
-            %    and reactions. For example, ``stoich_p(a, 3, [1, 3, 5,
-            %    7])`` returns a sparse matrix containing only the
+            %    coefficients if there are more than 1 species or reactions,
+            %    otherwise returns an integer.
+            %    The matrix elements ``nu(k, i)`` is the stoichiometric
+            %    coefficient of species k as a reactant in reaction i.
+            %    If ``species`` and ``rxns`` are specified, the matrix
+            %    will contain only entries for the specified species
+            %    and reactions. For example, ``kin.reactantStoichCoeffs(3,
+            %    [1, 3, 5, 7])`` returns a sparse matrix containing only the
             %    coefficients for species 3 in reactions 1, 3, 5, and 7.
 
             nsp = kin.nTotalSpecies;
@@ -256,7 +206,11 @@ classdef Kinetics < handle
                 krange = 1:nsp;
                 irange = 1:nr;
             elseif nargin == 3
-                krange = species;
+                if ischar(species)
+                    krange = {species};
+                else
+                    krange = species;
+                end
                 irange = rxns;
             else
                 error('stoichReactant requires 1 or 3 arguments.')
@@ -265,17 +219,29 @@ classdef Kinetics < handle
             for k = krange
 
                 for i = irange
-                    t = ctFunc('kin_reactantStoichCoeff', kin.kinID, k - 1, i - 1);
+                    if iscell(k)
+                        kk = kin.kineticsSpeciesIndex(k{:});
+                    elseif ischar(k)
+                        kk = kin.kineticsSpeciesIndex(k);
+                    else
+                        kk = k;
+                    end
+
+                    t = ctFunc('kin_reactantStoichCoeff', kin.kinID, kk - 1, i - 1);
 
                     if t ~= 0.0
-                        temp(k, i) = t;
+                        temp(kk, i) = t;
                     end
 
                 end
 
             end
 
-            n = temp;
+            if length(krange) > 1 || length(irange) > 1
+                n = temp;
+            else
+                n = sum(full(temp), 'all');
+            end
         end
 
         function n = productStoichCoeffs(kin, species, rxns)
@@ -284,16 +250,24 @@ classdef Kinetics < handle
             %     >> n = kin.productStoichCoeffs(species, rxns)
             %
             % :param species:
-            %    Species indices for which product stoichiometric
-            %    coefficients should be retrieved. Optional argument; if
-            %    specified, ``rxns`` must be specified as well.
+            %    Species indices or names for which product stoichiometric
+            %    coefficients should be retrieved.
+            %    Optional argument; if specified, ``rxns`` must be specified as well.
             % :param rxns:
             %    Reaction indices for which product stoichiometric
             %    coefficients should be retrieved. Optional argument; if
             %    specified, ``species`` must be specified as well.
             % :return:
             %    Returns a sparse matrix of all product stoichiometric
-            %    coefficients.
+            %    coefficients if there are more than 1 species or reactions,
+            %    otherwise returns an integer.
+            %    The matrix elements ``nu(k, i)`` is the stoichiometric
+            %    coefficient of species k as a product in reaction i.
+            %    If ``species`` and ``rxns`` are specified, the matrix
+            %    will contain only entries for the specified species
+            %    and reactions. For example, ``kin.productStoichCoeffs(3,
+            %    [1, 3, 5, 7])`` returns a sparse matrix containing only the
+            %    coefficients for species 3 in reactions 1, 3, 5, and 7.
 
             nsp = kin.nTotalSpecies;
             nr = kin.nReactions;
@@ -303,7 +277,11 @@ classdef Kinetics < handle
                 krange = 1:nsp;
                 irange = 1:nr;
             elseif nargin == 3
-                krange = species;
+                if ischar(species)
+                    krange = {species};
+                else
+                    krange = species;
+                end
                 irange = rxns;
             else
                 error('stoichProduct requires 1 or 3 arguments.')
@@ -312,17 +290,28 @@ classdef Kinetics < handle
             for k = krange
 
                 for i = irange
-                    t = ctFunc('kin_productStoichCoeff', kin.kinID, k - 1, i - 1);
+
+                    if iscell(k)
+                        kk = kin.kineticsSpeciesIndex(k{:});
+                    else
+                        kk = k;
+                    end
+
+                    t = ctFunc('kin_productStoichCoeff', kin.kinID, kk - 1, i - 1);
 
                     if t ~= 0.0
-                        temp(k, i) = t;
+                        temp(kk, i) = t;
                     end
 
                 end
 
             end
 
-            n = temp;
+            if length(krange) > 1 || length(irange) > 1
+                n = temp;
+            else
+                n = sum(full(temp), 'all');
+            end
         end
 
         function n = netStoichCoeffs(kin, species, rxns)
@@ -331,21 +320,30 @@ classdef Kinetics < handle
             %     >> n = kin.netStoichCoeffs(species, rxns)
             %
             % :param species:
-            %    Species indices for which net stoichiometric coefficients
-            %    should be retrieved. Optional argument; if specified,
-            %    "rxns" must be specified as well.
+            %    Species indices or names for which net stoichiometric
+            %    coefficients should be retrieved.
+            %    Optional argument; if specified, ``rxns`` must be specified as well.
             % :param rxns:
             %    Reaction indices for which net stoichiometric
             %    coefficients should be retrieved. Optional argument; if
-            %    specified, "species" must be specified as well.
+            %    specified, ``species`` must be specified as well.
             % :return:
-            %    A sparse matrix of all net stoichiometric coefficients.
+            %    Returns a sparse matrix of all net stoichiometric
+            %    coefficients if there are more than 1 species or reactions,
+            %    otherwise returns an integer.
+            %    The matrix elements ``nu(k, i)`` is the stoichiometric
+            %    coefficient of species k as a product in reaction i.
+            %    If ``species`` and ``rxns`` are specified, the matrix
+            %    will contain only entries for the specified species
+            %    and reactions. For example, ``kin.netStoichCoeffs(3,
+            %    [1, 3, 5, 7])`` returns a sparse matrix containing only the
+            %    coefficients for species 3 in reactions 1, 3, 5, and 7.
 
             if nargin == 1
-                n = kin.stoichProduct - kin.stoichReactant;
+                n = kin.productStoichCoeffs - kin.reactantStoichCoeffs;
             elseif nargin == 3
-                n = kin.stoichProduct(species, rxns) - ...
-                    kin.stoichReactant(species, rxns);
+                n = kin.productStoichCoeffs(species, rxns) - ...
+                    kin.reactantStoichCoeffs(species, rxns);
             else
                 error('stoichNet requires 1 or 3 arguments.');
             end
@@ -378,7 +376,7 @@ classdef Kinetics < handle
             % :return:
             %    True if reaction number i is reversible. false if irreversible.
 
-            n = boolean(ctFunc('kin_isReversible', kin.kinID, i));
+            n = ctFunc('kin_isReversible', kin.kinID, i - 1) == 1;
         end
 
         function wdot = get.netProdRates(kin)
@@ -491,7 +489,7 @@ classdef Kinetics < handle
             nr = kin.nReactions;
             xx = zeros(1, nr);
             pt = libpointer('doublePtr', xx);
-            ctFunc('kin_getRevRateConstants', kin.kinID, 1, nr, pt);
+            ctFunc('kin_getRevRateConstants', kin.kinID, 0, nr, pt);
             k = pt.Value;
         end
 
