@@ -1,14 +1,14 @@
 classdef ThermoPhase < handle
     % ThermoPhase Class ::
     %
-    %     >> t = ThermoPhase(src, id)
+    %     >> t = ThermoPhase(id)
+    %
+    % Retrieve instance of class :mat:class:`ThermoPhase` associated with a
+    % :mat:class:`Solution` object. The constructor is called whenever a new
+    % :mat:class:`Solution` is instantiated and should not be used directly.
     %
-    % :param src:
-    %     Input string of YAML file name when creating from file OR
-    %     "clib" when called by the class constructors of :mat:class:`Solution`
-    %     or :mat:class:`Interface`.
     % :param id:
-    %     ID of the phase to import as specified in the input file.
+    %     Integer ID of the solution holding the :mat:class:`ThermoPhase` object.
     % :return:
     %     Instance of class :mat:class:`ThermoPhase`.
 
@@ -34,6 +34,8 @@ classdef ThermoPhase < handle
         %     String. Can be 'mole'/'molar'/'Molar'/'Mole' or 'mass'/'Mass'.
         basis
 
+        name % Name of the phase.
+
         electricPotential % Electric potential. Units: V.
 
     end
@@ -76,7 +78,7 @@ classdef ThermoPhase < handle
 
         P % Pressure. Units: Pa.
 
-        D % Density. Units: kg/m^3.
+        D % Density depending on the basis. Units: kmol/m^3 (molar) kg/m^3 (mass)
 
         H % Enthalpy depending on the basis. Units: J/kmol (molar) J/kg (mass).
 
@@ -88,21 +90,6 @@ classdef ThermoPhase < handle
 
         Q % Vapor fraction of the phase.
 
-        % Chemical potentials of the species ::
-        %
-        %     >> mu = tp.chemPotentials
-        %
-        % The expressions used to compute the chemical potential
-        % depend on the model implemented by the underlying kernel
-        % thermo manager.
-        %
-        % :param tp:
-        %     Instance of class :mat:class:`ThermoPhase` (or another
-        %     object that derives from ThermoPhase).
-        % :return:
-        %     Vector of species chemical potentials. Units: J/kmol.
-        chemicalPotentials
-
         % Basis-dependent specific heat at constant volume.
         % Units: J/kg-K (mass basis) or J/kmol-K (molar basis).
         cv
@@ -111,25 +98,33 @@ classdef ThermoPhase < handle
         % Units: J/kg-K (mass basis) or J/kmol-K (molar basis).
         cp
 
+        % Chemical potentials of the species. Units: J/kmol.
+        chemicalPotentials
+
+        % Electrochemical potentials of the species. Units: J/kmol.
+        electrochemicalPotentials
+
+        % Partial molar enthalpies for the species in the mixture. Units: J/kmol.
+        partialMolarEnthalpies
+
+        % Partial molar entropies for the species in the mixture. Units: J/kmol/K.
+        partialMolarEntropies
+
+        % Partial molar internal energies for the species in the mixture. Units: J/kmol.
+        partialMolarIntEnergies
+
+        % Partial molar heat capacities for the species in the mixture. Units: J/kmol/K.
+        partialMolarCp
+
+        % Partial molar volumes for the species in the mixture. Units: m^3/kmol.
+        partialMolarVolumes
+
         critDensity % Critical density. Units: kg/m^3.
 
         critPressure % Critical pressure. Units: Pa.
 
         critTemperature % Critical temperature. Units: K.
 
-        % Non-dimensional enthalpies ::
-        %
-        %     >> v = tp.enthalpies_RT
-        %
-        % :param tp:
-        %     Instance of class :mat:class:`ThermoPhase` (or another
-        %     object that derives from ThermoPhase).
-        % :return:
-        %     Vector of standard-state species enthalpies constant
-        %     and T is the temperature. For gaseous species, these
-        %     values are ideal gas enthalpies.
-        enthalpies_RT
-
         eosType % Type of equation of state.
 
         isIdealGas % A flag indicating whether the phase is an ideal gas.
@@ -174,6 +169,14 @@ classdef ThermoPhase < handle
 
         refPressure % Reference pressure for standard-state. Units: Pa.
 
+        % Generate a report describing the thermodynamic state of this phase.
+        % To print the report to the terminal, simply call the phase object.
+        % The following two statements are equivalent ::
+        %
+        %     >> phase
+        %     >> disp(phase.report)
+        report
+
         % Saturation pressure at current temperature ::
         %
         %     >> p = tp.satPressure.
@@ -241,7 +244,7 @@ classdef ThermoPhase < handle
 
     properties (Dependent = true)
 
-        V % Get Specific volume. Units: m^3/kg.
+        V % Basis-dependent specific volume. Units: m^3/kmol (molar) m^3/kg (mass).
 
         % Get/Set density [kg/m^3 or kmol/m^3] and pressure [Pa].
         DP
@@ -418,50 +421,22 @@ classdef ThermoPhase < handle
     methods
         %% ThermoPhase Class Constructor
 
-        function tp = ThermoPhase(src, id)
+        function tp = ThermoPhase(id)
             % Create a :mat:class:`ThermoPhase` object.
             ctIsLoaded;
 
-            if strcmp(src, 'clib') & isnumeric(id)
-                tp.tpID = ctFunc('soln_thermo', id);
-                tp.basis = 'molar';
-                return
+            if ~isnumeric(id)
+                error('Invalid argument: constructor requires integer solution ID.')
             end
 
-            if nargin < 2
-                id = '';
-            end
-
-            tp.tpID = ctFunc('thermo_newFromFile', src, id);
+            tp.tpID = ctFunc('soln_thermo', id);
             tp.basis = 'molar';
         end
 
-        %% ThermoPhase class Destructor
-
-        function delete(tp)
-            % Delete the :mat:class:`ThermoPhase` object.
-
-            if ~isa(tp, 'Solution') && ~isa(tp, 'Interface')
-                ctFunc('thermo_del', tp.tpID);
-            end
-        end
-
         %% ThermoPhase Utility Methods
 
         function display(tp)
-            % Display thermo properties
-
-            buflen = 0 - calllib(ctLib, 'thermo_report', tp.tpID, 0, '', 1);
-            aa = char(ones(1, buflen));
-            ptr = libpointer('cstring', aa);
-            [iok, bb] = calllib(ctLib, 'thermo_report', tp.tpID, buflen, ptr, 1);
-
-            if iok < 0
-                error(ctGetErr);
-            else
-                disp(bb);
-            end
-
+            disp(tp.report);
         end
 
         function tp = equilibrate(tp, xy, solver, rtol, maxsteps, maxiter, loglevel)
@@ -476,11 +451,10 @@ classdef ThermoPhase < handle
             %     Not all of the properties to be held constant are available with
             %     all of the solvers.
             % :param solver:
-            %     Specifies the equilibrium solver to use. If solver = 0, a fast
-            %     solver using the element potential method will be used. If
-            %     solver = 1, a slower but more robust Gibbs minimization solver
-            %     will be used. If solver >= 2, a version of the VCS algorithm will
-            %     be used. If solver < 0 or is unspecified, the fast solver
+            %     Specifies the equilibrium solver to use. Choices are
+            %     'element_potential' (fast solver using the element potential method),
+            %     'gibbs' (slower but more robust Gibbs minimization solver), 'vcs'
+            %     (VCS algorithm). For the default 'auto' setting, the fast solver
             %     will be tried first, then if it fails the Gibbs minimization solver
             %     will be tried.
             % :param rtol:
@@ -497,7 +471,7 @@ classdef ThermoPhase < handle
             %     generate more detailed information.
 
             if nargin < 3
-                solver = -1;
+                solver = 'auto';
             end
 
             if nargin < 4
@@ -517,7 +491,7 @@ classdef ThermoPhase < handle
             end
 
             ctFunc('thermo_equilibrate', tp.tpID, xy, solver, rtol, ...
-                    maxsteps, maxiter, loglevel);
+                   maxsteps, maxiter, loglevel);
         end
 
         %% ThermoPhase inquiry methods
@@ -616,7 +590,7 @@ classdef ThermoPhase < handle
             end
 
             if ~ischar(element)
-                error('Element name must be of format character.');
+                error('Wrong type for element name: must be character.');
             end
 
             n = tp.nSpecies;
@@ -873,14 +847,6 @@ classdef ThermoPhase < handle
             e = pt.Value;
         end
 
-        function mu = get.chemicalPotentials(tp)
-            nsp = tp.nSpecies;
-            xx = zeros(1, nsp);
-            pt = libpointer('doublePtr', xx);
-            ctFunc('thermo_chemPotentials', tp.tpID, nsp, pt);
-            mu = pt.Value;
-        end
-
         function c = get.cv(tp)
             if strcmp(tp.basis, 'molar')
                 c = ctFunc('thermo_cv_mole', tp.tpID);
@@ -958,7 +924,7 @@ classdef ThermoPhase < handle
         end
 
         function p = get.refPressure(tp)
-            p = ctFunc('thermo_refPressure', tp.tpID, -1);
+            p = ctFunc('thermo_refPressure', tp.tpID);
         end
 
         function p = get.satPressure(tp)
@@ -990,6 +956,17 @@ classdef ThermoPhase < handle
 
         end
 
+        function s = get.name(tp)
+            s = ctString('thermo_getName', tp.tpID);
+        end
+
+        function str = get.report(tp, threshold)
+            if nargin < 2
+                threshold = 1e-14;
+            end
+            str = ctString('thermo_report', tp.tpID, 1, threshold);
+        end
+
         function n = get.speciesNames(tp)
             n = tp.speciesName(1:tp.nSpecies);
         end
@@ -1011,7 +988,11 @@ classdef ThermoPhase < handle
         end
 
         function density = get.D(tp)
-            density = ctFunc('thermo_density', tp.tpID);
+            if strcmp(tp.basis, 'mass')
+                density = ctFunc('thermo_density', tp.tpID);
+            else
+                density = tp.molarDensity;
+            end
         end
 
         function volume = get.V(tp)
@@ -1042,12 +1023,60 @@ classdef ThermoPhase < handle
             end
         end
 
-        function enthalpy = get.enthalpies_RT(tp)
+        function mu = get.chemicalPotentials(tp)
             nsp = tp.nSpecies;
             xx = zeros(1, nsp);
             pt = libpointer('doublePtr', xx);
-            ctFunc('thermo_getEnthalpies_RT', tp.tpID, nsp, pt);
-            enthalpy = pt.Value;
+            ctFunc('thermo_chemPotentials', tp.tpID, nsp, pt);
+            mu = pt.Value;
+        end
+
+        function emu = get.electrochemicalPotentials(tp)
+            nsp = tp.nSpecies;
+            xx = zeros(1, nsp);
+            pt = libpointer('doublePtr', xx);
+            ctFunc('thermo_electrochemPotentials', tp.tpID, nsp, pt);
+            emu = pt.Value;
+        end
+
+        function enthalpies = get.partialMolarEnthalpies(tp)
+            nsp = tp.nSpecies;
+            xx = zeros(1, nsp);
+            pt = libpointer('doublePtr', xx);
+            ctFunc('thermo_getPartialMolarEnthalpies', tp.tpID, nsp, pt);
+            enthalpies = pt.Value;
+        end
+
+        function entropies = get.partialMolarEntropies(tp)
+            nsp = tp.nSpecies;
+            xx = zeros(1, nsp);
+            pt = libpointer('doublePtr', xx);
+            ctFunc('thermo_getPartialMolarEntropies', tp.tpID, nsp, pt);
+            entropies = pt.Value;
+        end
+
+        function intEnergies = get.partialMolarIntEnergies(tp)
+            nsp = tp.nSpecies;
+            xx = zeros(1, nsp);
+            pt = libpointer('doublePtr', xx);
+            ctFunc('thermo_getPartialMolarIntEnergies', tp.tpID, nsp, pt);
+            intEnergies = pt.Value;
+        end
+
+        function cps = get.partialMolarCp(tp)
+            nsp = tp.nSpecies;
+            xx = zeros(1, nsp);
+            pt = libpointer('doublePtr', xx);
+            ctFunc('thermo_getPartialMolarCp', tp.tpID, nsp, pt);
+            cps = pt.Value;
+        end
+
+        function volumes = get.partialMolarVolumes(tp)
+            nsp = tp.nSpecies;
+            xx = zeros(1, nsp);
+            pt = libpointer('doublePtr', xx);
+            ctFunc('thermo_getPartialMolarVolumes', tp.tpID, nsp, pt);
+            volumes = pt.Value;
         end
 
         function entropy = get.S(tp)
@@ -1286,7 +1315,7 @@ classdef ThermoPhase < handle
             ctFunc('thermo_setElectricPotential', tp.tpID, phi);
         end
 
-        function tp = set.basis(tp, b)
+        function set.basis(tp, b)
 
             if strcmp(b, 'mole') || strcmp(b, 'molar') ...
                 || strcmp(b, 'Mole') || strcmp(b, 'Molar')
@@ -1299,6 +1328,10 @@ classdef ThermoPhase < handle
 
         end
 
+        function set.name(tp, str)
+            ctFunc('thermo_setName', tp.tpID, str);
+        end
+
         function set.X(tp, xx)
             tol = 1e-9;
 
@@ -1308,6 +1341,9 @@ classdef ThermoPhase < handle
 
             if isa(xx, 'double')
                 nsp = tp.nSpecies;
+                if length(xx) ~= nsp
+                    error('Length of array must be equal to number of species.')
+                end
 
                 if length(xx) ~= nsp
                     error('Length of array must be equal to number of species.')
@@ -1362,6 +1398,9 @@ classdef ThermoPhase < handle
         function set.DP(tp, input)
             d = input{1};
             p = input{2};
+            if strcmp(tp.basis, 'molar')
+                d = d*tp.meanMolecularWeight;
+            end
             ctFunc('thermo_set_DP', tp.tpID, [d, p]);
         end
 
@@ -1378,6 +1417,9 @@ classdef ThermoPhase < handle
         function set.HP(tp, input)
             h = input{1};
             p = input{2};
+            if strcmp(tp.basis, 'molar')
+                h = h/tp.meanMolecularWeight;
+            end
             ctFunc('thermo_set_HP', tp.tpID, [h, p]);
         end
 
@@ -1394,6 +1436,9 @@ classdef ThermoPhase < handle
         function set.PV(tp, input)
             p = input{1};
             v = input{2};
+            if strcmp(tp.basis, 'molar')
+                v = v/tp.meanMolecularWeight;
+            end
             ctFunc('thermo_set_PV', tp.tpID, [p, v]);
         end
 
@@ -1407,7 +1452,7 @@ classdef ThermoPhase < handle
             tp.PV = input(1:2);
         end
 
-        function tp = set.PQ(tp, input)
+        function set.PQ(tp, input)
             p = input{1};
             q = input{2};
             ctFunc('thermo_setState_Psat', tp.tpID, p, q);
@@ -1416,6 +1461,10 @@ classdef ThermoPhase < handle
         function set.SH(tp, input)
             s = input{1};
             h = input{2};
+            if strcmp(tp.basis, 'molar')
+                s = s/tp.meanMolecularWeight;
+                h = h/tp.meanMolecularWeight;
+            end
             ctFunc('thermo_set_SH', tp.tpID, [s, h]);
         end
 
@@ -1432,6 +1481,9 @@ classdef ThermoPhase < handle
         function set.SP(tp, input)
             s = input{1};
             p = input{2};
+            if strcmp(tp.basis, 'molar')
+                s = s/tp.meanMolecularWeight;
+            end
             ctFunc('thermo_set_SP', tp.tpID, [s, p]);
         end
 
@@ -1448,6 +1500,9 @@ classdef ThermoPhase < handle
         function set.ST(tp, input)
             s = input{1};
             t = input{2};
+            if strcmp(tp.basis, 'molar')
+                s = s/tp.meanMolecularWeight;
+            end
             ctFunc('thermo_set_ST', tp.tpID, [s, t]);
         end
 
@@ -1464,6 +1519,10 @@ classdef ThermoPhase < handle
         function set.SV(tp, input)
             s = input{1};
             v = input{2};
+            if strcmp(tp.basis, 'molar')
+                s = s/tp.meanMolecularWeight;
+                v = v/tp.meanMolecularWeight;
+            end
             ctFunc('thermo_set_SV', tp.tpID, [s, v]);
         end
 
@@ -1474,12 +1533,15 @@ classdef ThermoPhase < handle
 
         function set.SVY(tp, input)
             tp.Y = input{3};
-            tp.SP = input(1:2);
+            tp.SV = input(1:2);
         end
 
         function set.TD(tp, input)
             t = input{1};
             d = input{2};
+            if strcmp(tp.basis, 'molar')
+                d = d*tp.meanMolecularWeight;
+            end
             ctFunc('thermo_set_TD', tp.tpID, [t, d]);
         end
 
@@ -1496,6 +1558,9 @@ classdef ThermoPhase < handle
         function set.TH(tp, input)
             t = input{1};
             h = input{2};
+            if strcmp(tp.basis, 'molar')
+                h = h/tp.meanMolecularWeight;
+            end
             ctFunc('thermo_set_TH', tp.tpID, [t, h]);
         end
 
@@ -1534,6 +1599,9 @@ classdef ThermoPhase < handle
         function set.TV(tp, input)
             t = input{1};
             v = input{2};
+            if strcmp(tp.basis, 'molar')
+                v = v/tp.meanMolecularWeight;
+            end
             ctFunc('thermo_set_TV', tp.tpID, [t, v]);
         end
 
@@ -1550,6 +1618,9 @@ classdef ThermoPhase < handle
         function set.UP(tp, input)
             u = input{1};
             p = input{2};
+            if strcmp(tp.basis, 'molar')
+                u = u/tp.meanMolecularWeight;
+            end
             ctFunc('thermo_set_UP', tp.tpID, [u, p]);
         end
 
@@ -1566,6 +1637,10 @@ classdef ThermoPhase < handle
         function set.UV(tp, input)
             u = input{1};
             v = input{2};
+            if strcmp(tp.basis, 'molar')
+                u = u/tp.meanMolecularWeight;
+                v = v/tp.meanMolecularWeight;
+            end
             ctFunc('thermo_set_UV', tp.tpID, [u, v]);
         end
 
@@ -1582,6 +1657,10 @@ classdef ThermoPhase < handle
         function set.VH(tp, input)
             v = input{1};
             h = input{2};
+            if strcmp(tp.basis, 'molar')
+                v = v/tp.meanMolecularWeight;
+                h = h/tp.meanMolecularWeight;
+            end
             ctFunc('thermo_set_VH', tp.tpID, [v, h]);
         end
 
