@@ -4,22 +4,16 @@
 from dataclasses import dataclass
 from typing import Dict
 
-from .._helpers import get_preamble, normalize_indent
-
 
 @dataclass(frozen=True)
 class Config:
     """Provides configuration info for the CSharpSourceGenerator class"""
 
 
-    func_prolog = normalize_indent("""
-        [DllImport(LibFile)]
-        public static extern
-    """)
-
     ret_type_crosswalk = {
         "const char*": "string",
         "const double*": "double[]",
+        "const int*": "int[]",
         "size_t": "nuint",
         "char*": "byte*"
     }
@@ -29,17 +23,18 @@ class Config:
         "double*": "double[]"
     }
 
-    preamble = "/*\n" + get_preamble() + "*/"
-
     # These we load from the parsed YAML config file
     class_crosswalk: Dict[str, str]
 
+    class_accessors: Dict[str, str]
+
     derived_handles: Dict[str, str]
 
     wrapper_classes: Dict[str, Dict[str, str]]
 
-    @staticmethod
-    def from_parsed(parsed_config_file: dict):
-        return Config(parsed_config_file["class_crosswalk"],
-                      parsed_config_file["derived_handles"],
-                      parsed_config_file["wrapper_classes"])
+    @classmethod
+    def from_parsed(cls, *,
+                    class_crosswalk=None, class_accessors=None,
+                    derived_handles=None, wrapper_classes=None):
+        return cls(class_crosswalk or {}, class_accessors or {},
+                   derived_handles or {}, wrapper_classes or {})
