@@ -15,3 +15,7 @@ class CsFunc(Func):
 
     is_handle_release_func: bool
     handle_class_name: Union[str, None]
+
+    def unsafe(self):
+        """Identify pointers within argument lists."""
+        return any(p.p_type.endswith("*") for p in self.arglist)
