@@ -1,14 +1,16 @@
-/*!
- * @file flamespeed.cpp
- *
+/*
  * Freely-propagating flame
+ * ========================
  *
  * C++ demo program to compute flame speeds using GRI-Mech.
  *
- * Usage: flamespeed [equivalence_ratio] [refine_grid] [loglevel]
+ * Usage:
  *
- * Requires: cantera >= 3.0
- * Keywords: combustion, 1D flow, premixed flame, flame speed, saving output
+ *     flamespeed [equivalence_ratio] [refine_grid] [loglevel]
+ *
+ * Requires: cantera >= 3.1
+ *
+ * .. tags:: C++, combustion, 1D flow, premixed flame, flame speed, saving output
  */
 
 // This file is part of Cantera. See License.txt in the top-level directory or
@@ -54,7 +56,7 @@ int flamespeed(double phi, bool refine_grid, int loglevel)
 
         //-------- step 1: create the flow -------------
 
-        auto flow = newDomain<StFlow>("gas-flow", sol, "flow");
+        auto flow = newDomain<Flow1D>("gas-flow", sol, "flow");
         flow->setFreeFlow();
 
         // create an initial grid
@@ -171,9 +173,9 @@ int flamespeed(double phi, bool refine_grid, int loglevel)
                                          flow->componentIndex("CO2"),n));
             Uvec.push_back(flame.value(flowdomain,
                                        flow->componentIndex("velocity"),n));
-            zvec.push_back(flow->grid(n));
+            zvec.push_back(flow->z(n));
             print("{:9.6f}\t{:8.3f}\t{:5.3f}\t{:7.5f}\n",
-                  flow->grid(n), Tvec[n], Uvec[n], COvec[n]);
+                  flow->z(n), Tvec[n], Uvec[n], COvec[n]);
         }
 
         print("\nAdiabatic flame temperature from equilibrium is: {}\n", Tad);
@@ -183,7 +185,7 @@ int flamespeed(double phi, bool refine_grid, int loglevel)
         outfile << "  Grid,   Temperature,   Uvec,   CO,    CO2\n";
         for (size_t n = 0; n < flow->nPoints(); n++) {
             print(outfile, " {:11.3e}, {:11.3e}, {:11.3e}, {:11.3e}, {:11.3e}\n",
-                  flow->grid(n), Tvec[n], Uvec[n], COvec[n], CO2vec[n]);
+                  flow->z(n), Tvec[n], Uvec[n], COvec[n], CO2vec[n]);
         }
     } catch (CanteraError& err) {
         std::cerr << err.what() << std::endl;
