@@ -1,12 +1,11 @@
-/*!
- * @file openmp_ignition.cpp
- *
+/*
  * Ignition delay calculation with OpenMP
+ * ======================================
  *
  * This example shows how to use OpenMP to run multiple reactor network
  * calculations in parallel by using separate Cantera objects for each thread.
  *
- * Keywords: combustion, reactor network, ignition delay, parallel computing
+ * .. tags:: C++, combustion, reactor network, ignition delay, parallel computing
  */
 
 // This file is part of Cantera. See License.txt in the top-level directory or
@@ -37,9 +36,8 @@ void run()
     for (int i = 0; i < nThreads; i++) {
         auto sol = newSolution("gri30.yaml", "gri30", "none");
         sols.emplace_back(sol);
-        reactors.emplace_back(new IdealGasConstPressureReactor());
+        reactors.emplace_back(new IdealGasConstPressureReactor(sol));
         nets.emplace_back(new ReactorNet());
-        reactors.back()->insert(sol);
         nets.back()->addReactor(*reactors.back());
     }
 
