@@ -1,9 +1,9 @@
 function dydt = conhp(t, y, gas, mw)
-    % CONHP - ODE system for a constant-pressure, adiabatic reactor.
+    %% ODE system for a constant-pressure, adiabatic reactor
     %
-    % Function CONHP evaluates the system of ordinary differential equations
+    % Function ``CONHP`` evaluates the system of ordinary differential equations
     % for an adiabatic, constant-pressure, zero-dimensional reactor.
-    % It assumes that the 'gas' object represents a reacting ideal gas mixture.
+    % It assumes that the ``gas`` object represents a reacting ideal gas mixture.
 
     % Set the state of the gas, based on the current solution vector.
     gas.Y = y(2:end);
@@ -12,9 +12,9 @@ function dydt = conhp(t, y, gas, mw)
 
     % energy equation
     wdot = gas.netProdRates;
-    H = gas.enthalpies_RT';
+    H = gas.partialMolarEnthalpies';
     gas.basis = 'mass';
-    tdot =- gas.T * GasConstant / (gas.D * gas.cp) .* wdot * H;
+    tdot =- 1 / (gas.D * gas.cp) .* wdot * H;
 
     % set up column vector for dydt
     dydt = [tdot
