@@ -1,21 +1,27 @@
 """
-Viewing a reaction path diagram.
+Viewing a reaction path diagram
+===============================
 
 This script uses Graphviz to generate an image. You must have Graphviz installed
 and the program 'dot' must be on your path for this example to work.
 Graphviz can be obtained from https://www.graphviz.org/ or (possibly) installed
 using your operating system's package manager.
 
-Requires: cantera >= 2.5.0
-Keywords: kinetics, reaction path analysis, pollutant formation
+Requires: cantera >= 2.5.0, graphviz
+
+.. tags:: Python, kinetics, reaction path analysis, pollutant formation
 """
 
 from subprocess import run
-import sys
 from pathlib import Path
+import graphviz
 
 import cantera as ct
 
+# %%
+# Generate a Solution with a state where reactions are occurring
+# --------------------------------------------------------------
+#
 # these lines can be replaced by any commands that generate
 # an object of a class derived from class Kinetics in some state.
 gas = ct.Solution('gri30.yaml')
@@ -27,12 +33,18 @@ while T < 1900:
     net.step()
     T = r.T
 
+# %%
+# Create a reaction path diagram following nitrogen
+# -------------------------------------------------
 element = 'N'
 
 diagram = ct.ReactionPathDiagram(gas, element)
 diagram.title = 'Reaction path diagram following {0}'.format(element)
 diagram.label_threshold = 0.01
 
+# %%
+# Save the reaction path diagram
+# ------------------------------
 dot_file = 'rxnpath.dot'
 img_file = 'rxnpath.png'
 img_path = Path.cwd().joinpath(img_file)
@@ -40,11 +52,12 @@ img_path = Path.cwd().joinpath(img_file)
 diagram.write_dot(dot_file)
 print(diagram.get_data())
 
-print("Wrote graphviz input file to '{0}'.".format(Path.cwd().joinpath(dot_file)))
+print(f"Wrote graphviz input file to '{Path.cwd().joinpath(dot_file)}'.")
 
-run('dot {0} -Tpng -o{1} -Gdpi=200'.format(dot_file, img_file).split())
-print("Wrote graphviz output file to '{0}'.".format(img_path))
+run(f"dot {dot_file} -Tpng -o{img_file} -Gdpi=200".split())
+print(f"Wrote graphviz output file to '{img_path}'.")
 
-if "-view" in sys.argv:
-    import webbrowser
-    webbrowser.open(f"file:///{img_path}")
+# %%
+# View the reaction path diagram
+# ------------------------------
+graphviz.Source(diagram.get_dot())
