@@ -1,11 +1,9 @@
 """
-Short description: reactor cascade model for reactive flows in inert porous media
-based on extensible reactors. Showcases adding a temperature equation for a
-solid-phase and custom heat transfer/radiation models.
+Reactor cascade model for reactive flows in inert porous media
+==============================================================
 
-Code by Thorsten Zirwes and Guillaume Vignat
-Stanford University & Karlsruhe Institute of Technology (KIT)
-2023
+Showcases the use of `ExtensibleReactor` to add a temperature equation for a solid-phase
+and custom heat transfer/radiation models.
 
 This code implements a reactor cascade model for the simulation of reactive
 flows in porous media. The gas mixture with fuel and oxidizer flows through
@@ -23,9 +21,6 @@ so that mass controllers and pressure valves are not required. The code is writt
 a general way to support an arbitrary number of reactors and an arbitrary number of
 burner sections with different physical properties.
 
-The implemented equations make use of Cantera's extensible reactor models.
-Therefore, Cantera version 2.6.0 or higher is required.
-
 The porous media burner considered in this example is a cylindrical tube filled
 three different porous materials: a porous ceramic made from a Yttria-stabilized
 Zirconia Alumina (YZA) section with length of 2 inches and pore density of 40 pores per
@@ -35,14 +30,15 @@ hydrogen dilution in the measurements. Next, a one inch section with a porous ce
 made from silicon carbide (SiC) with 3 PPI is used and finally a 1 inch section of SiC
 with 10 PPI. A flame stabilizes at the interface between the YZA and 3 PPI SiC.
 
+.. code:: none
 
-          |--- two inches --- | --- one inch ---| --- one inch --- |
-          __________________________________________________________
-fuel
- +   =>      YZA 40 PPI       |     SiC 3 PPI   |   SiC 10 PPI       => burnt
-air       __________________________________________________________    gas
+             |--- two inches --- | --- one inch ---| --- one inch --- |
+             __________________________________________________________
+   fuel
+    +   =>      YZA 40 PPI       |     SiC 3 PPI   |   SiC 10 PPI       => burnt
+   air       __________________________________________________________    gas
 
-                inert            flame location   heat recirculation
+                   inert            flame location   heat recirculation
 
 This example simplifies the complex interaction between heat transport in the gas-phase
 and solid-phase by using a reactor cascade. While key trends from the measurements can
@@ -61,9 +57,10 @@ corresponding experiments can be found in
     L. Simitz, D. Trimis, M. Ihme
     Combustion and Flame, 250 (https://doi.org/10.1016/j.combustflame.2023.112642)
 
-Requires: cantera >= 2.6.0, matplotlib >= 2.0
-Keywords: user-defined model, reactor network, combustion, porous media, heat transfer,
-          radiative heat transfer
+Requires: cantera >= 3.1.0, matplotlib >= 2.0
+
+.. tags:: Python, user-defined model, reactor network, combustion, porous media,
+          heat transfer, radiative heat transfer
 """
 
 import matplotlib.pyplot as plt
@@ -130,6 +127,7 @@ class SolidProperties:
 # Temperature-dependent fits from measurements:
 # SiC: Thermal conductivity in hot-pressed silicon carbide, D.-K. Liu, B.-W. Lin,
 #      Ceramics International, 22(5), pp. 407-414 (1996)
+# Note that in this simple model, 0.84 is the porosity of the SiC foams
 def effectiveConductivitySiC(Ts):  # for silicon carbide
     return (1 - 0.84) * 1857.0 * Ts**(-0.5332)
 
@@ -147,21 +145,21 @@ YZA40PPI = SolidProperties(porosity=0.82,
                            pore_diameter=0.00025,
                            heat_conductivity=effectiveConductivityYZA,
                            specific_area=2373.,
-                           solid_phase=ct.Solution("YZA.yaml"),
+                           solid_phase=ct.Solution("example_data/YZA.yaml"),
                            emissivity=0.85)
 
 SiC3PPI = SolidProperties(porosity=0.84,
                           pore_diameter=0.0085,
                           heat_conductivity=effectiveConductivitySiC,
                           specific_area=246.075,
-                          solid_phase=ct.Solution("silicon_carbide.yaml"),
+                          solid_phase=ct.Solution("example_data/silicon_carbide.yaml"),
                           emissivity=0.85)
 
 SiC10PPI = SolidProperties(porosity=0.84,
                            pore_diameter=0.00134,
                            heat_conductivity=effectiveConductivitySiC,
                            specific_area=978.,
-                           solid_phase=ct.Solution("silicon_carbide.yaml"),
+                           solid_phase=ct.Solution("example_data/silicon_carbide.yaml"),
                            emissivity=0.85)
 
 
@@ -313,7 +311,7 @@ class PMReactor(ct.ExtensibleIdealGasConstPressureReactor):
         # convective transport
         RHS[Tindex] += self.A * mdot * (h_in - enthalpy_loss)
         # chemical contribution
-        RHS[Tindex] += hrr * self.V
+        RHS[Tindex] += hrr * self.V * porosity
 
     def before_component_index(self, name):
         if name == "Ts":
