@@ -75,11 +75,7 @@ void Solution::setTransportModel(const string& model) {
         throw CanteraError("Solution::setTransportModel",
             "Unable to set Transport model without valid ThermoPhase object.");
     }
-    if (model == "") {
-        setTransport(newTransport(m_thermo, "default"));
-    } else {
-        setTransport(newTransport(m_thermo, model));
-    }
+    setTransport(newTransport(m_thermo, model));
 }
 
 void Solution::addAdjacent(shared_ptr<Solution> adjacent) {
@@ -198,7 +194,7 @@ shared_ptr<Solution> newSolution(const string &infile,
 
     // load YAML file
     auto rootNode = AnyMap::fromYamlFile(infile);
-    AnyMap& phaseNode = rootNode["phases"].getMapWhere("name", name);
+    const AnyMap& phaseNode = rootNode.at("phases").getMapWhere("name", name);
     auto sol = newSolution(phaseNode, rootNode, transport, adjacent);
     sol->setSource(infile);
     return sol;
@@ -208,12 +204,12 @@ shared_ptr<Solution> newSolution(const string& infile, const string& name,
     const string& transport, const vector<string>& adjacent)
 {
     auto rootNode = AnyMap::fromYamlFile(infile);
-    AnyMap& phaseNode = rootNode["phases"].getMapWhere("name", name);
+    const AnyMap& phaseNode = rootNode.at("phases").getMapWhere("name", name);
 
     vector<shared_ptr<Solution>> adjPhases;
     // Create explicitly-specified adjacent bulk phases
     for (auto& name : adjacent) {
-        auto& adjNode = rootNode["phases"].getMapWhere("name", name);
+        const auto& adjNode = rootNode.at("phases").getMapWhere("name", name);
         adjPhases.push_back(newSolution(adjNode, rootNode));
     }
     return newSolution(phaseNode, rootNode, transport, adjPhases);
@@ -260,7 +256,7 @@ shared_ptr<Solution> newSolution(const AnyMap& phaseNode,
             if (!all_related.count(name)) {
                 // Create a new phase only if there isn't already one with the same name
                 auto adj = newSolution(phases.getMapWhere("name", name), root,
-                                    "", {}, all_related);
+                                       "default", {}, all_related);
                 all_related[name] = adj;
                 for (size_t i = 0; i < adj->nAdjacent(); i++) {
                     all_related[adj->adjacent(i)->name()] = adj->adjacent(i);
@@ -326,9 +322,8 @@ shared_ptr<Solution> newSolution(const AnyMap& phaseNode,
         if (key == "phases") {
             // header ends with "phases" field
             break;
-        } else if (key != "units") {
-            header[key] = value;
         }
+        header[key] = value;
     }
     sol->header() = header;
 
