@@ -14,6 +14,7 @@
 #include "cantera/thermo/SurfPhase.h"
 #include "cantera/base/utilities.h"
 #include <boost/algorithm/string.hpp>
+#include <boost/range/adaptor/reversed.hpp>
 #include <fstream>
 #include <sstream>
 
@@ -44,11 +45,12 @@ SolutionArray::SolutionArray(const shared_ptr<Solution>& sol,
     , m_dataSize(size)
     , m_meta(meta)
 {
-    if (!m_sol) {
+    if (!m_sol || !m_sol->thermo()) {
         throw CanteraError("SolutionArray::SolutionArray",
             "Unable to create SolutionArray from invalid Solution object.");
     }
     m_stride = m_sol->thermo()->stateSize();
+    m_sol->thermo()->addSpeciesLock();
     m_data = make_shared<vector<double>>(m_dataSize * m_stride, 0.);
     m_extra = make_shared<map<string, AnyValue>>();
     m_order = make_shared<map<int, string>>();
@@ -70,8 +72,19 @@ SolutionArray::SolutionArray(const SolutionArray& other,
     , m_extra(other.m_extra)
     , m_order(other.m_order)
     , m_shared(true)
-    , m_active(selected)
 {
+    m_sol->thermo()->addSpeciesLock();
+    if (!other.m_shared) {
+        // direct slicing is possible
+        m_active = selected;
+    } else {
+        // slicing a previously sliced SolutionArray
+        m_active.clear();
+        m_active.reserve(selected.size());
+        for (auto loc : selected) {
+            m_active.push_back(other.m_active.at(loc));
+        }
+    }
     for (auto loc : m_active) {
         if (loc < 0 || loc >= (int)m_dataSize) {
             IndexError("SolutionArray::SolutionArray", "indices", loc, m_dataSize);
@@ -83,6 +96,11 @@ SolutionArray::SolutionArray(const SolutionArray& other,
     }
 }
 
+SolutionArray::~SolutionArray()
+{
+    m_sol->thermo()->removeSpeciesLock();
+}
+
 namespace { // restrict scope of helper functions to local translation unit
 
 template<class T>
@@ -215,17 +233,19 @@ vector<string> doubleColumn(string name, const vector<double>& comp,
     if (csize <= rows) {
         for (const auto& val : comp) {
             data.push_back(val);
-            raw.push_back(boost::trim_copy(fmt::format(notation, val)));
+            raw.push_back(boost::trim_copy(fmt::format(fmt::runtime(notation), val)));
         }
     } else {
         dots = (rows + 1) / 2;
         for (int row = 0; row < dots; row++) {
             data.push_back(comp[row]);
-            raw.push_back(boost::trim_copy(fmt::format(notation, comp[row])));
+            raw.push_back(boost::trim_copy(
+                fmt::format(fmt::runtime(notation), comp[row])));
         }
         for (int row = csize - rows / 2; row < csize; row++) {
             data.push_back(comp[row]);
-            raw.push_back(boost::trim_copy(fmt::format(notation, comp[row])));
+            raw.push_back(boost::trim_copy(
+                fmt::format(fmt::runtime(notation), comp[row])));
         }
     }
 
@@ -275,17 +295,17 @@ vector<string> doubleColumn(string name, const vector<double>& comp,
         // all entries are integers
         notation = fmt::format(" {{:>{}.0f}}", over + maxLen);
     }
-    maxLen = fmt::format(notation, 0.).size();
+    maxLen = fmt::format(fmt::runtime(notation), 0.).size();
 
     // assemble output
     string section = fmt::format("{{:>{}}}", maxLen);
-    vector<string> col = {fmt::format(section, name)};
+    vector<string> col = {fmt::format(fmt::runtime(section), name)};
     int count = 0;
     for (const auto& val : data) {
-        col.push_back(fmt::format(notation, val));
+        col.push_back(fmt::format(fmt::runtime(notation), val));
         count++;
         if (count == dots) {
-            col.push_back(fmt::format(section, "..."));
+            col.push_back(fmt::format(fmt::runtime(section), "..."));
         }
     }
     return col;
@@ -303,7 +323,8 @@ vector<string> integerColumn(string name, const vector<long int>& comp,
     if (csize <= rows) {
         for (const auto& val : comp) {
             data.push_back(val);
-            string formatted = boost::trim_copy(fmt::format(notation, val));
+            string formatted = boost::trim_copy(
+                fmt::format(fmt::runtime(notation), val));
             if (formatted[0] == '-') {
                 formatted = formatted.substr(1);
             }
@@ -313,7 +334,8 @@ vector<string> integerColumn(string name, const vector<long int>& comp,
         dots = (rows + 1) / 2;
         for (int row = 0; row < dots; row++) {
             data.push_back(comp[row]);
-            string formatted = boost::trim_copy(fmt::format(notation, comp[row]));
+            string formatted = boost::trim_copy(
+                fmt::format(fmt::runtime(notation), comp[row]));
             if (formatted[0] == '-') {
                 formatted = formatted.substr(1);
             }
@@ -321,7 +343,8 @@ vector<string> integerColumn(string name, const vector<long int>& comp,
         }
         for (int row = csize - rows / 2; row < csize; row++) {
             data.push_back(comp[row]);
-            string formatted = boost::trim_copy(fmt::format(notation, comp[row]));
+            string formatted = boost::trim_copy(
+                fmt::format(fmt::runtime(notation), comp[row]));
             if (formatted[0] == '-') {
                 formatted = formatted.substr(1);
             }
@@ -339,13 +362,13 @@ vector<string> integerColumn(string name, const vector<long int>& comp,
     }
 
     // assemble output
-    vector<string> col = {fmt::format(notation, name)};
+    vector<string> col = {fmt::format(fmt::runtime(notation), name)};
     int count = 0;
     for (const auto& val : data) {
-        col.push_back(fmt::format(notation, val));
+        col.push_back(fmt::format(fmt::runtime(notation), val));
         count++;
         if (count == dots) {
-            col.push_back(fmt::format(notation, ".."));
+            col.push_back(fmt::format(fmt::runtime(notation), ".."));
         }
     }
     return col;
@@ -364,31 +387,33 @@ vector<string> stringColumn(string name, const vector<string>& comp,
         for (const auto& val : comp) {
             data.push_back(val);
             maxLen = std::max(maxLen,
-                boost::trim_copy(fmt::format(notation, val)).size());
+                boost::trim_copy(fmt::format(fmt::runtime(notation), val)).size());
         }
     } else {
         dots = (rows + 1) / 2;
         for (int row = 0; row < dots; row++) {
             data.push_back(comp[row]);
             maxLen = std::max(maxLen,
-                boost::trim_copy(fmt::format(notation, comp[row])).size());
+                boost::trim_copy(
+                    fmt::format(fmt::runtime(notation), comp[row])).size());
         }
         for (int row = csize - rows / 2; row < csize; row++) {
             data.push_back(comp[row]);
             maxLen = std::max(maxLen,
-                boost::trim_copy(fmt::format(notation, comp[row])).size());
+                boost::trim_copy(
+                    fmt::format(fmt::runtime(notation), comp[row])).size());
         }
     }
 
     // assemble output
     notation = fmt::format("  {{:>{}}}", maxLen);
-    vector<string> col = {fmt::format(notation, name)};
+    vector<string> col = {fmt::format(fmt::runtime(notation), name)};
     int count = 0;
     for (const auto& val : data) {
-        col.push_back(fmt::format(notation, val));
+        col.push_back(fmt::format(fmt::runtime(notation), val));
         count++;
         if (count == dots) {
-            col.push_back(fmt::format(notation, "..."));
+            col.push_back(fmt::format(fmt::runtime(notation), "..."));
         }
     }
     return col;
@@ -426,8 +451,8 @@ vector<string> formatColumn(string name, const AnyValue& comp, int rows, int wid
 
     // assemble output
     string notation = fmt::format("  {{:>{}}}", maxLen);
-    repr = fmt::format(notation, repr);
-    vector<string> col = {fmt::format(notation, name)};
+    repr = fmt::format(fmt::runtime(notation), repr);
+    vector<string> col = {fmt::format(fmt::runtime(notation), name)};
     if (size <= rows) {
         for (int row = 0; row < size; row++) {
             col.push_back(repr);
@@ -437,7 +462,7 @@ vector<string> formatColumn(string name, const AnyValue& comp, int rows, int wid
         for (int row = 0; row < dots; row++) {
             col.push_back(repr);
         }
-        col.push_back(fmt::format(notation, "..."));
+        col.push_back(fmt::format(fmt::runtime(notation), "..."));
         for (int row = size - rows / 2; row < size; row++) {
             col.push_back(repr);
         }
@@ -899,9 +924,7 @@ AnyMap preamble(const string& desc)
     }
     data["generator"] = "Cantera SolutionArray";
     data["cantera-version"] = CANTERA_VERSION;
-    // escape commit to ensure commits are read correctly from YAML
-    // example: prevent '3491027e7' from being converted to an integer
-    data["git-commit"] = "'" + gitCommit() + "'";
+    data["git-commit"] = gitCommit();
 
     // Add a timestamp indicating the current time
     time_t aclock;
@@ -909,15 +932,6 @@ AnyMap preamble(const string& desc)
     struct tm* newtime = localtime(&aclock); // Convert time to struct tm form
     data["date"] = stripnonprint(asctime(newtime));
 
-    // Force metadata fields to the top of the file
-    if (data.hasKey("description")) {
-        data["description"].setLoc(-6, 0);
-    }
-    data["generator"].setLoc(-5, 0);
-    data["cantera-version"].setLoc(-4, 0);
-    data["git-commit"].setLoc(-3, 0);
-    data["date"].setLoc(-2, 0);
-
     return data;
 }
 
@@ -965,9 +979,12 @@ void SolutionArray::writeHeader(AnyMap& root, const string& name,
                                 const string& desc, bool overwrite)
 {
     AnyMap& data = openField(root, name);
-    if (!data.empty() && !overwrite) {
-        throw CanteraError("SolutionArray::writeHeader",
-            "Field name '{}' exists; use 'overwrite' argument to overwrite.", name);
+    if (!data.empty()) {
+        if (!overwrite) {
+            throw CanteraError("SolutionArray::writeHeader",
+                "Field name '{}' exists; use 'overwrite' argument to overwrite.", name);
+        }
+        data.clear();
     }
     data.update(preamble(desc));
 }
@@ -1206,8 +1223,12 @@ void SolutionArray::writeEntry(AnyMap& root, const string& name, const string& s
     }
     data.update(m_meta);
 
-    for (auto& [key, value] : *m_extra) {
-        data[key] = value;
+    if (m_size > 1) {
+        data["components"] = componentNames();
+    }
+
+    for (auto& [_, key] : *m_order) {
+        data[key] = m_extra->at(key);
     }
 
     auto phase = m_sol->thermo();
@@ -1235,18 +1256,23 @@ void SolutionArray::writeEntry(AnyMap& root, const string& name, const string& s
             data["mass-fractions"] = std::move(items);
         }
     } else if (m_size > 1) {
-        const auto& nativeState = phase->nativeState();
-        for (auto& [key, offset] : nativeState) {
-            if (key == "X" || key == "Y") {
+        for (auto& code : phase->nativeMode()) {
+            string name(1, code);
+            if (name == "X" || name == "Y") {
                 for (auto& spc : phase->speciesNames()) {
                     data[spc] = getComponent(spc);
                 }
-                data["basis"] = key == "X" ? "mole" : "mass";
+                data["basis"] = name == "X" ? "mole" : "mass";
             } else {
-                data[key] = getComponent(key);
+                data[name] = getComponent(name);
             }
         }
-        data["components"] = componentNames();
+    }
+
+    static bool reg = AnyMap::addOrderingRules("SolutionArray",
+        {{"head", "type"}, {"head", "size"}, {"head", "basis"}});
+    if (reg) {
+        data["__type__"] = "SolutionArray";
     }
 
     // If this is not replacing an existing solution, put it at the end
