@@ -7,26 +7,29 @@
 #include "application.h"
 #include "cantera/base/global.h"
 
+#define BOOST_STACKTRACE_GNU_SOURCE_NOT_REQUIRED
+#include <boost/stacktrace.hpp>
+
 #include <sstream>
 
 namespace Cantera
 {
 
-// *** Exceptions ***
-
-static const char* stars = ("*****************************************"
-                            "**************************************\n");
+int CanteraError::traceDepth_ = 0;
 
 CanteraError::CanteraError(const string& procedure) :
     procedure_(procedure)
 {
+    if (traceDepth_) {
+        auto trace = boost::stacktrace::stacktrace(0, traceDepth_);
+        traceback_ = boost::stacktrace::to_string(trace);
+    }
 }
 
 const char* CanteraError::what() const throw()
 {
     try {
-        formattedMessage_ = "\n";
-        formattedMessage_ += stars;
+        formattedMessage_ = "\n" + string(79, '*') + "\n";
         formattedMessage_ += getClass();
         if (procedure_.size()) {
             formattedMessage_ += " thrown by " + procedure_;
@@ -35,7 +38,11 @@ const char* CanteraError::what() const throw()
         if (formattedMessage_.compare(formattedMessage_.size()-1, 1, "\n")) {
             formattedMessage_.append("\n");
         }
-        formattedMessage_ += stars;
+        if (traceDepth_) {
+            formattedMessage_ += string(79, '-') + "\n" + traceback_;
+        }
+        formattedMessage_ += string(79, '*') + "\n";
+
     } catch (...) {
         // Something went terribly wrong and we couldn't even format the message.
     }
@@ -52,6 +59,11 @@ string CanteraError::getMethod() const
     return procedure_;
 }
 
+void CanteraError::setStackTraceDepth(int depth)
+{
+    traceDepth_ = depth;
+}
+
 string ArraySizeError::getMessage() const
 {
     return fmt::format("Array size ({}) too small. Must be at least {}.",
