@@ -11,43 +11,44 @@
 #include "cantera/base/ctexceptions.h"
 #include "cantera/base/utilities.h"
 #include <unordered_map>
+#include <boost/range/adaptor/reversed.hpp>
 
 namespace Cantera {
 
 /**
- * Template for classes to hold pointers to objects. The SharedCabinet<M> class
+ * Template for classes to hold pointers to objects. The Cabinet<M> class
  * maintains a list of pointers to objects of class M (or of subclasses of M). These
  * classes are used by the 'clib' interface library functions that provide access to
  * %Cantera C++ objects from outside C++. To refer to an existing object, the library
  * functions take an integer argument that specifies the location in the pointer list
- * maintained by the appropriate SharedCabinet<M> instance. The pointer is retrieved
+ * maintained by the appropriate Cabinet<M> instance. The pointer is retrieved
  * from the list by the interface function, the desired method is invoked, and the
  * result returned to the non-C++ calling procedure. By storing the pointers in a
- * SharedCabinet, there is no need to encode them in a string or integer and pass
+ * Cabinet, there is no need to encode them in a string or integer and pass
  * them out to the non-C++ calling routine, as some other interfacing schemes do.
  *
- * The SharedCabinet<M> class can be used to store pointers to arbitrary objects. In
+ * The Cabinet<M> class can be used to store pointers to arbitrary objects. In
  * most cases, class M is a base class with virtual methods, and the base class versions
  * of the methods throw CanteraError exceptions. The subclasses overload these methods
- * to implement the desired functionality. Class SharedCabinet<M> stores only the
+ * to implement the desired functionality. Class Cabinet<M> stores only the
  * base-class pointers, but since the methods are virtual, the method of the appropriate
  * subclass will be invoked.
  *
- * As the SharedCabinet<M> class uses smart pointers, it is set up to allow deleting
+ * As the Cabinet<M> class uses smart pointers, it is set up to allow deleting
  * objects in an inherently safe manner. Method 'del' does the following. If called
  * with n >= 0, it dereferences the object. The original object is only destroyed if the
  * reference is not shared by other objects. In this way, if it is deleted again
  * inadvertently nothing happens, and if an attempt is made to reference the object by
  * its index number, a standard exception is thrown.
  *
- * The SharedCabinet<M> class is implemented as a singleton. The constructor is never
- * explicitly called; instead, static function SharedCabinet<M>::SharedCabinet() is
+ * The Cabinet<M> class is implemented as a singleton. The constructor is never
+ * explicitly called; instead, static function Cabinet<M>::Cabinet() is
  * called to obtain a pointer to the instance. This function calls the constructor on
  * the first call and stores the pointer to this instance. Subsequent calls simply
  * return the already-created pointer.
  */
 template<class M>
-class SharedCabinet
+class Cabinet
 {
 public:
     typedef vector<shared_ptr<M>>& dataRef;
@@ -56,17 +57,19 @@ public:
     /**
      * Constructor.
      */
-    SharedCabinet() {}
+    Cabinet() {}
 
     /**
      * Add a new object. The index of the object is returned.
      */
-    static int add(shared_ptr<M> obj) {
+    static int add(shared_ptr<M> obj, int parent=-1) {
         dataRef data = getData();
         data.push_back(obj);
+        auto& parents = getParents();
+        parents.push_back(parent);
         int idx = static_cast<int>(data.size()) - 1;
         lookupRef lookup = getLookup();
-        if (index(*obj) >= 0) {
+        if (lookup.count(obj.get())) {
             lookup[obj.get()].insert(idx);
         } else {
             lookup[obj.get()] = {idx};
@@ -97,6 +100,7 @@ public:
      */
     static int reset() {
         getData().clear();
+        getParents().clear();
         getLookup().clear();
         return 0;
     }
@@ -107,9 +111,9 @@ public:
     static int copy(int n) {
         dataRef data = getData();
         try {
-            return add(*data[n]);
+            return add(*data[n]);  // do not copy parent to avoid ambiguous data
         } catch (std::exception& err) {
-            throw CanteraError("SharedCabinet::newCopy", err.what());
+            throw CanteraError("Cabinet::newCopy", err.what());
         }
     }
 
@@ -121,7 +125,7 @@ public:
         if (n >= 0 && n < len(data)) {
             lookupRef lookup = getLookup();
             if (!lookup.count(data[n].get())) {
-                throw CanteraError("SharedCabinet::del",
+                throw CanteraError("Cabinet::del",
                     "Lookup table does not contain reference to object.");
             }
             if (lookup[data[n].get()].size() == 1) {
@@ -133,21 +137,32 @@ public:
             }
             data[n].reset();
         } else {
-            throw CanteraError("SharedCabinet::del",
+            throw CanteraError("Cabinet::del",
                 "Attempt made to delete a non-existing object.");
         }
     }
 
+    /**
+     * Return handle of parent to object n.
+     */
+    static int parent(int n) {
+        auto& parents = getParents();
+        if (n < 0 || n >= len(parents)) {
+            throw CanteraError("Cabinet::parent", "Index {} out of range.", n);
+        }
+        return parents[n];
+    }
+
     /**
      * Return a shared pointer to object n.
      */
     static shared_ptr<M>& at(int n) {
         dataRef data = getData();
         if (n < 0 || n >= len(data)) {
-            throw CanteraError("SharedCabinet::at", "Index {} out of range.", n);
+            throw CanteraError("Cabinet::at", "Index {} out of range.", n);
         }
         if (!data[n]) {
-            throw CanteraError("SharedCabinet::at",
+            throw CanteraError("Cabinet::at",
                 "Object with index {} has been deleted.", n);
         }
         return data[n];
@@ -162,63 +177,62 @@ public:
         if (obj) {
             return obj;
         }
-        throw CanteraError("SharedCabinet::as", "Item is not of the correct type.");
+        throw CanteraError("Cabinet::as", "Item is not of the correct type.");
     }
 
     /**
-     * Return a reference to object n.
-     */
-    static M& item(int n) {
-        return *at(n);
-    }
-
-    /**
-     * Return a reference to object n, cast to a reference of the specified type.
-     */
-    template <class T>
-    static T& get(int n) {
-        auto obj = std::dynamic_pointer_cast<T>(at(n));
-        if (obj) {
-            return *obj;
-        }
-        throw CanteraError("SharedCabinet::get", "Item is not of the correct type.");
-    }
-
-    /**
-     * Return the index in the SharedCabinet to the specified object, or -1 if the
-     * object is not in the SharedCabinet. If multiple indices reference the same
+     * Return the index in the Cabinet to the specified object, or -1 if the
+     * object is not in the Cabinet. If multiple indices reference the same
      * object, the index of the last one added is returned.
      */
-    static int index(const M& obj) {
+    static int index(const M& obj, int parent=-1) {
         lookupRef lookup = getLookup();
         if (!lookup.count(&obj)) {
             return -1;
         }
         set<int>& entry = lookup.at(&obj);
-        return *entry.rbegin();
+        auto& parents = getParents();
+        for (const auto e : boost::adaptors::reverse(entry)) {
+            if (parents[e] == parent) {
+                return e;
+            }
+        }
+        return -2;  // not found
     }
 
 private:
     /**
      * Static function that returns a pointer to the data member of
-     * the singleton SharedCabinet<M> instance. All member functions should
+     * the singleton Cabinet<M> instance. All member functions should
      * access the data through this function.
      */
     static dataRef getData() {
         if (s_storage == nullptr) {
-            s_storage = new SharedCabinet<M>();
+            s_storage = new Cabinet<M>();
         }
         return s_storage->m_table;
     }
 
+    /**
+     * Static function that returns a pointer to the list of parent object handles of
+     * the singleton Cabinet<M> instance. All member functions should
+     * access the data through this function.
+     */
+    static vector<int>& getParents() {
+        if (s_storage == nullptr) {
+            s_storage = new Cabinet<M>();
+        }
+        return s_storage->m_parents;
+    }
+
     /**
      * Static function that returns a pointer to the reverse lookup table of
-     * the singleton SharedCabinet<M> instance. All member functions should
+     * the singleton Cabinet<M> instance. All member functions should
      * access the lookup table through this function.
      */
     static lookupRef getLookup() {
         if (s_storage == nullptr) {
-            s_storage = new SharedCabinet<M>();
+            s_storage = new Cabinet<M>();
         }
         return s_storage->m_lookup;
     }
@@ -226,7 +240,7 @@ private:
     /**
      * Pointer to the single instance of this class.
      */
-    static SharedCabinet<M>* s_storage;
+    static Cabinet<M>* s_storage;
 
     /**
      * Reverse lookup table for the single instance of this class.
@@ -234,7 +248,12 @@ private:
     std::unordered_map<const M*, set<int>> m_lookup;
 
     /**
-     * list to hold pointers to objects.
+     * List to hold handles of parent objects.
+     */
+    vector<int> m_parents;
+
+    /**
+     * List to hold pointers to objects.
      */
     vector<shared_ptr<M>> m_table;
 };
