@@ -25,9 +25,9 @@
 
 using namespace Cantera;
 
-typedef SharedCabinet<ThermoPhase> ThermoCabinet;
-typedef SharedCabinet<Kinetics> KineticsCabinet;
-typedef SharedCabinet<Transport> TransportCabinet;
+typedef Cabinet<ThermoPhase> ThermoCabinet;
+typedef Cabinet<Kinetics> KineticsCabinet;
+typedef Cabinet<Transport> TransportCabinet;
 
 typedef integer status_t;
 
@@ -39,17 +39,17 @@ namespace {
 
 ThermoPhase* _fph(const integer* n)
 {
-    return &ThermoCabinet::item(*n);
+    return ThermoCabinet::at(*n).get();
 }
 
 static Kinetics* _fkin(const integer* n)
 {
-    return &KineticsCabinet::item(*n);
+    return KineticsCabinet::at(*n).get();
 }
 
 ThermoPhase* _fth(const integer* n)
 {
-    return &ThermoCabinet::item(*n);
+    return ThermoCabinet::at(*n).get();
 }
 
 shared_ptr<ThermoPhase> _fthermo(const integer* n)
@@ -59,7 +59,7 @@ shared_ptr<ThermoPhase> _fthermo(const integer* n)
 
 Transport* _ftrans(const integer* n)
 {
-    return &TransportCabinet::item(*n);
+    return TransportCabinet::at(*n).get();
 }
 
 } // unnamed namespace
@@ -696,8 +696,7 @@ extern "C" {
                     }
                 }
             }
-            auto kin = newKinetics(phases, f2string(filename, nlen),
-                                   f2string(phasename, plen));
+            auto kin = newKinetics(phases, f2string(filename, nlen));
             return KineticsCabinet::add(kin);
         } catch (...) {
             return handleAllExceptions(999, ERR);
@@ -727,8 +726,7 @@ extern "C" {
                               ftnlen lennm, ftnlen lenph)
     {
         try {
-            return _fkin(n)->kineticsSpeciesIndex(f2string(nm, lennm),
-                                                  f2string(ph, lenph)) + 1;
+            return _fkin(n)->kineticsSpeciesIndex(f2string(nm, lennm)) + 1;
         } catch (...) {
             return handleAllExceptions(-1, ERR);
         }
@@ -1055,16 +1053,6 @@ extern "C" {
         }
     }
 
-    status_t trans_setparameters_(const integer* n, integer* type, integer* k, double* d)
-    {
-        try {
-            _ftrans(n)->setParameters(*type, *k, d);
-            return 0;
-        } catch (...) {
-            return handleAllExceptions(-1, ERR);
-        }
-    }
-
     //-------------------- Functions ---------------------------
 
     status_t ctphase_report_(const integer* nth,
