@@ -12,13 +12,6 @@ BulkKinetics::BulkKinetics() {
     setDerivativeSettings(AnyMap()); // use default settings
 }
 
-BulkKinetics::BulkKinetics(ThermoPhase* thermo) : BulkKinetics()
-{
-    warn_deprecated("BulkKinetics::BulkKinetics(ThermoPhase*)",
-        "To be removed after Cantera 3.0. Use default constructor instead.");
-    addPhase(*thermo);
-}
-
 bool BulkKinetics::isReversible(size_t i) {
     return std::find(m_revindex.begin(), m_revindex.end(), i) < m_revindex.end();
 }
@@ -498,17 +491,18 @@ void BulkKinetics::updateROP()
 
         // Third-body objects interacting with MultiRate evaluator
         m_multi_concm.update(m_phys_conc, ctot, m_concm.data());
-
-        // loop over MultiRate evaluators for each reaction type
-        for (auto& rates : m_bulk_rates) {
-            bool changed = rates->update(thermo(), *this);
-            if (changed) {
-                rates->getRateConstants(m_kf0.data());
-            }
-        }
         m_ROP_ok = false;
     }
 
+    // loop over MultiRate evaluators for each reaction type
+    for (auto& rates : m_bulk_rates) {
+        bool changed = rates->update(thermo(), *this);
+        if (changed) {
+            rates->getRateConstants(m_kf0.data());
+            m_ROP_ok = false;
+        }
+    }
+
     if (m_ROP_ok) {
         // rates of progress are up-to-date only if both the thermodynamic state
         // and m_perturb are unchanged
