@@ -73,21 +73,16 @@ void Kinetics::checkPhaseArraySize(size_t mm) const
     }
 }
 
-size_t Kinetics::surfacePhaseIndex() const
+size_t Kinetics::reactionPhaseIndex() const
 {
-    warn_deprecated("Kinetics::surfacePhaseIndex",
-                    "To be removed after Cantera 3.0. Use reactionPhaseIndex instead.");
-    return m_surfphase;
+    warn_deprecated("Kinetics::reactionPhaseIndex", "The reacting phase is always "
+        "the first phase. To be removed after Cantera 3.1.");
+    return 0;
 }
 
 shared_ptr<ThermoPhase> Kinetics::reactionPhase() const
 {
-    if (!m_sharedThermo.size()) {
-        // @todo remove after Cantera 3.0
-        throw CanteraError("Kinetics::reactionPhase",
-            "Cannot access phases that were not added using smart pointers.");
-    }
-    return m_sharedThermo[m_rxnphase];
+    return m_thermo[0];
 }
 
 void Kinetics::checkSpeciesIndex(size_t k) const
@@ -104,6 +99,18 @@ void Kinetics::checkSpeciesArraySize(size_t kk) const
     }
 }
 
+void Kinetics::setExplicitThirdBodyDuplicateHandling(const string& flag)
+{
+    if (flag == "warn" || flag == "error" || flag == "mark-duplicate"
+        || flag == "modify-efficiency")
+    {
+        m_explicit_third_body_duplicates = flag;
+    } else {
+        throw CanteraError("Kinetics::setExplicitThirdBodyDuplicateHandling",
+            "Invalid flag '{}'", flag);
+    }
+}
+
 pair<size_t, size_t> Kinetics::checkDuplicates(bool throw_err) const
 {
     //! Map of (key indicating participating species) to reaction numbers
@@ -116,6 +123,7 @@ pair<size_t, size_t> Kinetics::checkDuplicates(bool throw_err) const
         }
     }
 
+    vector<InputFileError> errs;
     for (size_t i = 0; i < m_reactions.size(); i++) {
         // Get data about this reaction
         unsigned long int key = 0;
@@ -169,14 +177,41 @@ pair<size_t, size_t> Kinetics::checkDuplicates(bool throw_err) const
                 }
                 if (thirdBodyOk) {
                     continue; // No overlap in third body efficiencies
+                } else if ((tb1.name() == "M") != (tb2.name() == "M")) {
+                    // Exactly one of the reactions uses M as the third body
+                    if (m_explicit_third_body_duplicates == "mark-duplicate") {
+                        R.duplicate = true;
+                        other.duplicate = true;
+                        continue;
+                    } else if (m_explicit_third_body_duplicates == "modify-efficiency") {
+                        if (tb1.name() == "M") {
+                            tb1.efficiencies[tb2.name()] = 0.0;
+                        } else {
+                            tb2.efficiencies[tb1.name()] = 0.0;
+                        }
+                        continue;
+                    } else if (m_explicit_third_body_duplicates == "warn") {
+                        InputFileError msg("Kinetics::checkDuplicates",
+                            R.input, other.input,
+                            "Undeclared duplicate third body reactions with a common "
+                            "third body detected.\nAdd the field "
+                            "'explicit-third-body-duplicates: mark-duplicate' or\n"
+                            "'explicit-third-body-duplicates: modify-efficiency' to "
+                            "the YAML phase entry\nto choose how these reactions "
+                            "should be handled and suppress this warning.\n"
+                            "Reaction {}: {}\nReaction {}: {}\n",
+                            m+1, R.equation(), i+1, other.equation());
+                        warn_user("Kinetics::checkDuplicates", msg.what());
+                        continue;
+                    } // else m_explicit_third_body_duplicates == "error"
                 }
             }
             if (throw_err) {
-                throw InputFileError("Kinetics::checkDuplicates",
+                errs.emplace_back("Kinetics::checkDuplicates",
                         R.input, other.input,
                         "Undeclared duplicate reactions detected:\n"
                         "Reaction {}: {}\nReaction {}: {}\n",
-                        i+1, other.equation(), m+1, R.equation());
+                        m+1, R.equation(), i+1, other.equation());
             } else {
                 return {i,m};
             }
@@ -186,7 +221,7 @@ pair<size_t, size_t> Kinetics::checkDuplicates(bool throw_err) const
     if (unmatched_duplicates.size()) {
         size_t i = *unmatched_duplicates.begin();
         if (throw_err) {
-            throw InputFileError("Kinetics::checkDuplicates",
+            errs.emplace_back("Kinetics::checkDuplicates",
                 m_reactions[i]->input,
                 "No duplicate found for declared duplicate reaction number {}"
                 " ({})", i, m_reactions[i]->equation());
@@ -194,7 +229,17 @@ pair<size_t, size_t> Kinetics::checkDuplicates(bool throw_err) const
             return {i, i};
         }
     }
-    return {npos, npos};
+    if (errs.empty()) {
+        return {npos, npos};
+    } else if (errs.size() == 1) {
+        throw errs[0];
+    } else {
+        fmt::memory_buffer msg;
+        for (const auto& err : errs) {
+            fmt_append(msg, "\n{}\n", err.getMessage());
+        }
+        throw CanteraError("Kinetics::checkDuplicates", to_string(msg));
+    }
 }
 
 double Kinetics::checkDuplicateStoich(map<int, double>& r1, map<int, double>& r2) const
@@ -240,21 +285,6 @@ double Kinetics::checkDuplicateStoich(map<int, double>& r1, map<int, double>& r2
     return ratio;
 }
 
-void Kinetics::selectPhase(const double* data, const ThermoPhase* phase,
-                           double* phase_data)
-{
-    warn_deprecated("Kinetics::selectPhase", "To be removed after Cantera 3.0");
-    for (size_t n = 0; n < nPhases(); n++) {
-        if (phase == m_thermo[n]) {
-            size_t nsp = phase->nSpecies();
-            copy(data + m_start[n],
-                 data + m_start[n] + nsp, phase_data);
-            return;
-        }
-    }
-    throw CanteraError("Kinetics::selectPhase", "Phase not found.");
-}
-
 string Kinetics::kineticsSpeciesName(size_t k) const
 {
     for (size_t n = m_start.size()-1; n != npos; n--) {
@@ -277,28 +307,6 @@ size_t Kinetics::kineticsSpeciesIndex(const string& nm) const
     return npos;
 }
 
-size_t Kinetics::kineticsSpeciesIndex(const string& nm, const string& ph) const
-{
-    warn_deprecated("Kinetics::kineticsSpeciesIndex(species_name, phase_name)",
-        "To be removed after Cantera 3.0. Use kineticsSpeciesIndex(species_name).\n"
-        "Species names should be unique across all phases linked to a Kinetics object.");
-    if (ph == "<any>") {
-        return kineticsSpeciesIndex(nm);
-    }
-
-    for (size_t n = 0; n < m_thermo.size(); n++) {
-        string id = thermo(n).name();
-        if (ph == id) {
-            size_t k = thermo(n).speciesIndex(nm);
-            if (k == npos) {
-                return npos;
-            }
-            return k + m_start[n];
-        }
-    }
-    return npos;
-}
-
 ThermoPhase& Kinetics::speciesPhase(const string& nm)
 {
     for (size_t n = 0; n < m_thermo.size(); n++) {
@@ -312,7 +320,7 @@ ThermoPhase& Kinetics::speciesPhase(const string& nm)
 
 const ThermoPhase& Kinetics::speciesPhase(const string& nm) const
 {
-    for (const auto thermo : m_thermo) {
+    for (const auto& thermo : m_thermo) {
         if (thermo->speciesIndex(nm) != npos) {
             return *thermo;
         }
@@ -341,36 +349,6 @@ double Kinetics::productStoichCoeff(size_t kSpec, size_t irxn) const
     return m_productStoich.stoichCoeffs().coeff(kSpec, irxn);
 }
 
-string Kinetics::reactionType(size_t i) const {
-    warn_deprecated("Kinetics::reactionType", "To be removed after Cantera 3.0.");
-    return m_reactions[i]->type();
-}
-
-string Kinetics::reactionTypeStr(size_t i) const {
-    warn_deprecated("Kinetics::reactionTypeStr", "To be removed after Cantera 3.0.");
-    return reactionType(i);
-}
-
-string Kinetics::reactionString(size_t i) const
-{
-    warn_deprecated("Kinetics::reactionString", "To be removed after Cantera 3.0.");
-    return m_reactions[i]->equation();
-}
-
-//! Returns a string containing the reactants side of the reaction equation.
-string Kinetics::reactantString(size_t i) const
-{
-    warn_deprecated("Kinetics::reactantString", "To be removed after Cantera 3.0.");
-    return m_reactions[i]->reactantString();
-}
-
-//! Returns a string containing the products side of the reaction equation.
-string Kinetics::productString(size_t i) const
-{
-    warn_deprecated("Kinetics::productString", "To be removed after Cantera 3.0.");
-    return m_reactions[i]->productString();
-}
-
 void Kinetics::getFwdRatesOfProgress(double* fwdROP)
 {
     updateROP();
@@ -595,41 +573,13 @@ void Kinetics::addThermo(shared_ptr<ThermoPhase> thermo)
     // phase/interface at which reactions take place
     if (thermo->nDim() <= m_mindim) {
         if (!m_thermo.empty()) {
-            warn_deprecated("Kinetics::addThermo", "The reacting (lowest dimensional) "
-                "phase should be added first. This warning will become an error after "
-                "Cantera 3.0.");
+            throw CanteraError("Kinetics::addThermo",
+                "The reacting (lowest dimensional) phase must be added first.");
         }
         m_mindim = thermo->nDim();
-        m_rxnphase = nPhases();
     }
 
-    // there should only be one surface phase
-    if (boost::algorithm::contains(thermo->type(), "surface")) {
-        m_surfphase = nPhases();
-    }
-    m_thermo.push_back(thermo.get());
-    m_sharedThermo.push_back(thermo);
-    m_phaseindex[m_thermo.back()->name()] = nPhases();
-    resizeSpecies();
-}
-
-void Kinetics::addPhase(ThermoPhase& thermo)
-{
-    warn_deprecated("Kinetics::addPhase",
-        "To be removed after Cantera 3.0. Replaced by addThermo.");
-
-    // the phase with lowest dimensionality is assumed to be the
-    // phase/interface at which reactions take place
-    if (thermo.nDim() <= m_mindim) {
-        m_mindim = thermo.nDim();
-        m_rxnphase = nPhases();
-    }
-
-    // there should only be one surface phase
-    if (thermo.type() == kineticsType()) {
-        m_surfphase = nPhases();
-    }
-    m_thermo.push_back(&thermo);
+    m_thermo.push_back(thermo);
     m_phaseindex[m_thermo.back()->name()] = nPhases();
     resizeSpecies();
 }
@@ -646,6 +596,12 @@ AnyMap Kinetics::parameters()
         if (m_hasUndeclaredThirdBodies) {
             out["skip-undeclared-third-bodies"] = true;
         }
+        if (m_explicit_third_body_duplicates == "error") {
+            // "warn" is the default, and does not need to be added. "mark-duplicate"
+            // and "modify-efficiency" do not need to be propagated here as their
+            // effects are already applied to the corresponding reactions.
+            out["explicit-third-body-duplicates"] = "error";
+        }
     }
     return out;
 }
@@ -793,23 +749,4 @@ shared_ptr<const Reaction> Kinetics::reaction(size_t i) const
     return m_reactions[i];
 }
 
-double Kinetics::reactionEnthalpy(const Composition& reactants, const Composition& products)
-{
-    warn_deprecated("Kinetics::reactionEnthalpy", "To be removed after Cantera 3.0");
-    vector<double> hk(nTotalSpecies());
-    for (size_t n = 0; n < nPhases(); n++) {
-        thermo(n).getPartialMolarEnthalpies(&hk[m_start[n]]);
-    }
-    double rxn_deltaH = 0;
-    for (const auto& [name, stoich] : products) {
-        size_t k = kineticsSpeciesIndex(name);
-        rxn_deltaH += hk[k] * stoich;
-    }
-    for (const auto& [name, stoich] : reactants) {
-            size_t k = kineticsSpeciesIndex(name);
-            rxn_deltaH -= hk[k] * stoich;
-        }
-    return rxn_deltaH;
-}
-
 }
