@@ -7,16 +7,12 @@
 
 #include "cantera/kinetics/KineticsFactory.h"
 #include "cantera/kinetics/BulkKinetics.h"
-
-#define CT_SKIP_DEPRECATION_WARNINGS
-#include "cantera/kinetics/GasKinetics.h" // @todo Remove after Cantera 3.0
-
 #include "cantera/kinetics/InterfaceKinetics.h"
 #include "cantera/kinetics/EdgeKinetics.h"
+#include "cantera/kinetics/Reaction.h"
 #include "cantera/thermo/ThermoPhase.h"
 #include "cantera/base/stringUtils.h"
 #include "cantera/base/Solution.h"
-
 #include <boost/algorithm/string.hpp>
 
 namespace Cantera
@@ -30,10 +26,9 @@ KineticsFactory::KineticsFactory() {
     addDeprecatedAlias("none", "Kinetics");
     addDeprecatedAlias("none", "None");
     reg("bulk", []() { return new BulkKinetics(); });
-    // @todo After Cantera 3.0, "gas" should be an alias for "bulk"
-    reg("gas", []() { return new GasKinetics(); });
-    addDeprecatedAlias("gas", "gaskinetics");
-    addDeprecatedAlias("gas", "Gas");
+    addAlias("bulk", "gas");
+    addDeprecatedAlias("bulk", "gaskinetics");
+    addDeprecatedAlias("bulk", "Gas");
     reg("surface", []() { return new InterfaceKinetics(); });
     addAlias("surface", "interface");
     addDeprecatedAlias("surface", "Surf");
@@ -61,13 +56,6 @@ Kinetics* KineticsFactory::newKinetics(const string& model)
     return create(toLowerCopy(model));
 }
 
-Kinetics* newKineticsMgr(const string& model)
-{
-    warn_deprecated("newKineticsMgr",
-        "To be removed after Cantera 3.0; superseded by newKinetics.");
-    return KineticsFactory::factory()->newKinetics(model);
-}
-
 shared_ptr<Kinetics> newKinetics(const string& model)
 {
     shared_ptr<Kinetics> kin(KineticsFactory::factory()->newKinetics(model));
@@ -107,68 +95,21 @@ shared_ptr<Kinetics> newKinetics(const vector<shared_ptr<ThermoPhase>>& phases,
     return kin;
 }
 
-unique_ptr<Kinetics> newKinetics(const vector<ThermoPhase*>& phases,
-                                 const AnyMap& phaseNode,
-                                 const AnyMap& rootNode)
-{
-    warn_deprecated("newKinetics(vector<ThermoPhase*>&, AnyMap&, AnyMap&)",
-        "To be removed after Cantera 3.0; superseded by\nnewKinetics"
-        "(const vector<shared_ptr<ThermoPhase>>&, const AnyMap&, const AnyMap&).");
-    string kinType = phaseNode.getString("kinetics", "none");
-    kinType = KineticsFactory::factory()->canonicalize(kinType);
-    if (kinType == "none") {
-        // determine phase with minimum number of dimensions
-        size_t nDim = 3;
-        for (auto& phase : phases) {
-            nDim = std::min(phase->nDim(), nDim);
-        }
-        // change kinetics type as necessary
-        if (nDim == 2) {
-            kinType = "surface";
-        } else if (nDim == 1) {
-            kinType = "edge";
-        }
-    }
-
-    unique_ptr<Kinetics> kin(KineticsFactory::factory()->newKinetics(kinType));
-    for (auto& phase : phases) {
-        kin->addPhase(*phase);
-    }
-    kin->init();
-    addReactions(*kin, phaseNode, rootNode);
-    return kin;
-}
-
 shared_ptr<Kinetics> newKinetics(const vector<shared_ptr<ThermoPhase>>& phases,
-                                 const string& filename,
-                                 const string& phase_name)
+                                 const string& filename)
 {
-    if (phase_name != "") {
-        warn_deprecated("newKinetics", "After Cantera 3.0, the 'phase_name' argument "
-            "will be removed and an exception will be thrown if the reacting phase is "
-            "not the first phase in the 'phases' vector.");
-    }
-    string reaction_phase = (phase_name.empty()) ? phases.at(0)->name() : phase_name;
+    string reaction_phase = phases.at(0)->name();
     AnyMap root = AnyMap::fromYamlFile(filename);
     AnyMap& phaseNode = root["phases"].getMapWhere("name", reaction_phase);
     return newKinetics(phases, phaseNode, root);
 }
 
-unique_ptr<Kinetics> newKinetics(const vector<ThermoPhase*>& phases,
-                                 const string& filename, const string& phase_name)
-{
-    warn_deprecated("newKinetics(vector<ThermoPhase*>&, const string&, const string&)",
-        "To be removed after Cantera 3.0; superseded by\nnewKinetics"
-        "(const vector<shared_ptr<ThermoPhase>>&, const string&, const string&).");
-    AnyMap root = AnyMap::fromYamlFile(filename);
-    AnyMap& phaseNode = root["phases"].getMapWhere("name", phase_name);
-    return newKinetics(phases, phaseNode, root);
-}
-
 void addReactions(Kinetics& kin, const AnyMap& phaseNode, const AnyMap& rootNode)
 {
     kin.skipUndeclaredThirdBodies(
         phaseNode.getBool("skip-undeclared-third-bodies", false));
+    kin.setExplicitThirdBodyDuplicateHandling(
+        phaseNode.getString("explicit-third-body-duplicates", "warn"));
 
     loadExtensions(rootNode);
 
