@@ -8,8 +8,6 @@
 #include "cantera/kinetics/Reaction.h"
 #include "cantera/kinetics/ReactionRateFactory.h"
 #include "cantera/kinetics/Kinetics.h"
-#include "cantera/kinetics/Arrhenius.h" // @todo: remove after Cantera 3.0
-#include "cantera/kinetics/Falloff.h" // @todo: remove after Cantera 3.0
 #include "cantera/thermo/ThermoPhase.h"
 #include "cantera/thermo/SurfPhase.h"
 #include "cantera/base/Array.h"
@@ -66,6 +64,7 @@ Reaction::Reaction(const Composition& reactants_,
             m_third_body->explicit_3rd = true;
         }
     }
+    check();
 }
 
 Reaction::Reaction(const string& equation,
@@ -73,11 +72,12 @@ Reaction::Reaction(const string& equation,
                    shared_ptr<ThirdBody> tbody_)
     : m_third_body(tbody_)
 {
-    setEquation(equation);
     setRate(rate_);
+    setEquation(equation);
     if (m_third_body && m_third_body->name() != "M") {
         m_third_body->explicit_3rd = true;
     }
+    check();
 }
 
 Reaction::Reaction(const AnyMap& node, const Kinetics& kin)
@@ -89,7 +89,7 @@ Reaction::Reaction(const AnyMap& node, const Kinetics& kin)
     }
 
     setParameters(node, kin);
-    size_t nDim = kin.thermo(kin.reactionPhaseIndex()).nDim();
+    size_t nDim = kin.thermo(0).nDim();
     if (!valid()) {
         // If the reaction isn't valid (for example, contains undefined species),
         // setting up the rate constant won't work
@@ -113,7 +113,7 @@ Reaction::Reaction(const AnyMap& node, const Kinetics& kin)
             if (!ba::starts_with(rate_type, "sticking-")) {
                 rateNode["type"] = "sticking-" + rate_type;
             }
-        } else {
+        } else if (rate_type == "Arrhenius") { // no explicitly-specified type
             throw InputFileError("Reaction::Reaction", input,
                 "Unable to infer interface reaction type.");
         }
@@ -151,10 +151,45 @@ void Reaction::check()
             "Reaction orders may only be given for irreversible reactions");
     }
 
+    if (!m_rate) {
+        return;
+    }
+
     // Check reaction rate evaluator to ensure changes introduced after object
     // instantiation are considered.
-    if (m_rate) {
-        m_rate->check(equation());
+    m_rate->check(equation());
+
+    string rate_type = m_rate->type();
+    if (m_third_body) {
+        if (rate_type == "falloff" || rate_type == "chemically-activated") {
+            if (m_third_body->mass_action && !m_from_composition) {
+                throw InputFileError("Reaction::setRate", input,
+                    "Third-body collider does not use '(+{})' notation.",
+                    m_third_body->name());
+            }
+            m_third_body->mass_action = false;
+        } else if (rate_type == "Chebyshev") {
+            if (m_third_body->name() == "M") {
+                warn_deprecated("Chebyshev reaction equation", input, "Specifying 'M' "
+                    "in the reaction equation for Chebyshev reactions is deprecated.");
+                m_third_body.reset();
+            }
+        } else if (rate_type == "pressure-dependent-Arrhenius") {
+            if (m_third_body->name() == "M") {
+                throw InputFileError("Reaction::setRate", input,
+                    "Found superfluous '{}' in pressure-dependent-Arrhenius reaction.",
+                    m_third_body->name());
+            }
+        }
+    } else {
+        if (rate_type == "falloff" || rate_type == "chemically-activated") {
+            if (!m_from_composition) {
+                throw InputFileError("Reaction::setRate", input,
+                    "Reaction equation for falloff reaction '{}'\n does not "
+                    "contain valid pressure-dependent third body", equation());
+            }
+            m_third_body = make_shared<ThirdBody>("(+M)");
+        }
     }
 }
 
@@ -167,8 +202,8 @@ AnyMap Reaction::parameters(bool withInput) const
     }
 
     static bool reg = AnyMap::addOrderingRules("Reaction",
-        {{"head", "type"},
-         {"head", "equation"},
+        {{"head", "equation"},
+         {"head", "type"},
          {"tail", "duplicate"},
          {"tail", "orders"},
          {"tail", "negative-orders"},
@@ -191,15 +226,23 @@ void Reaction::getParameters(AnyMap& reactionNode) const
 
     if (duplicate) {
         reactionNode["duplicate"] = true;
+    } else {
+        reactionNode.exclude("duplicate");
     }
     if (orders.size()) {
         reactionNode["orders"] = orders;
+    } else {
+        reactionNode.exclude("orders");
     }
     if (allow_negative_orders) {
         reactionNode["negative-orders"] = true;
+    } else {
+        reactionNode.exclude("negative-orders");
     }
     if (allow_nonreactant_orders) {
         reactionNode["nonreactant-orders"] = true;
+    } else {
+        reactionNode.exclude("nonreactant-orders");
     }
 
     reactionNode.update(m_rate->parameters());
@@ -216,7 +259,7 @@ void Reaction::getParameters(AnyMap& reactionNode) const
             reactionNode["type"] = "elementary";
         }
     } else if (ba::ends_with(rtype, "Arrhenius")) {
-        reactionNode.erase("type");
+        reactionNode.exclude("type");
     } else if (m_explicit_type) {
         reactionNode["type"] = type();
     } else if (ba::ends_with(rtype, "Blowers-Masel")) {
@@ -273,39 +316,6 @@ void Reaction::setRate(shared_ptr<ReactionRate> rate)
             "Reaction rate for reaction '{}' must not be empty.", equation());
     }
     m_rate = rate;
-
-    string rate_type = m_rate->type();
-    if (m_third_body) {
-        if (rate_type == "falloff" || rate_type == "chemically-activated") {
-            if (m_third_body->mass_action && !m_from_composition) {
-                throw InputFileError("Reaction::setRate", input,
-                    "Third-body collider does not use '(+{})' notation.",
-                    m_third_body->name());
-            }
-            m_third_body->mass_action = false;
-        } else if (rate_type == "Chebyshev") {
-            if (m_third_body->name() == "M") {
-                warn_deprecated("Chebyshev reaction equation", input, "Specifying 'M' "
-                    "in the reaction equation for Chebyshev reactions is deprecated.");
-                m_third_body.reset();
-            }
-        } else if (rate_type == "pressure-dependent-Arrhenius") {
-            if (m_third_body->name() == "M") {
-                throw InputFileError("Reaction::setRate", input,
-                    "Found superfluous '{}' in pressure-dependent-Arrhenius reaction.",
-                    m_third_body->name());
-            }
-        }
-    } else {
-        if (rate_type == "falloff" || rate_type == "chemically-activated") {
-            if (!m_from_composition) {
-                throw InputFileError("Reaction::setRate", input,
-                    "Reaction equation for falloff reaction '{}'\n does not "
-                    "contain valid pressure-dependent third body", equation());
-            }
-            m_third_body = make_shared<ThirdBody>("(+M)");
-        }
-    }
 }
 
 string Reaction::reactantString() const
@@ -356,8 +366,7 @@ string Reaction::equation() const
 void Reaction::setEquation(const string& equation, const Kinetics* kin)
 {
     parseReactionEquation(*this, equation, input, kin);
-
-    string rate_type = input.getString("type", "");
+    string rate_type = (m_rate) ? m_rate->type() : input.getString("type", "");
     if (ba::starts_with(rate_type, "three-body")) {
         // state type when serializing
         m_explicit_type = true;
@@ -365,9 +374,12 @@ void Reaction::setEquation(const string& equation, const Kinetics* kin)
         // user override
         m_explicit_type = true;
         return;
-    } else if (kin && kin->thermo(kin->reactionPhaseIndex()).nDim() != 3) {
+    } else if (kin && kin->thermo(0).nDim() != 3) {
         // interface reactions
         return;
+    } else if (rate_type == "electron-collision-plasma") {
+        // does not support third body
+        return;
     }
 
     string third_body;
@@ -531,8 +543,7 @@ UnitStack Reaction::calculateRateCoeffUnits(const Kinetics& kin)
     }
 
     // Determine the units of the rate coefficient
-    const auto& rxn_phase = kin.thermo(kin.reactionPhaseIndex());
-    UnitStack rate_units(rxn_phase.standardConcentrationUnits());
+    UnitStack rate_units(kin.thermo(0).standardConcentrationUnits());
 
     // Set output units to standardConcentrationUnits per second
     rate_units.join(1.);
@@ -615,14 +626,14 @@ void Reaction::checkBalance(const Kinetics& kin) const
             equation(), msg);
     }
 
-    if (kin.thermo(kin.reactionPhaseIndex()).nDim() == 3) {
+    if (kin.thermo(0).nDim() == 3) {
         return;
     }
 
     // Check that the number of surface sites is balanced
     double reac_sites = 0.0;
     double prod_sites = 0.0;
-    auto& surf = dynamic_cast<const SurfPhase&>(kin.thermo(kin.reactionPhaseIndex()));
+    auto& surf = dynamic_cast<const SurfPhase&>(kin.thermo(0));
     for (const auto& [name, stoich] : reactants) {
         size_t k = surf.speciesIndex(name);
         if (k != npos) {
@@ -718,13 +729,6 @@ bool Reaction::usesElectrochemistry(const Kinetics& kin) const
     return false;
 }
 
-ThirdBody::ThirdBody(double default_eff)
-    : default_efficiency(default_eff)
-{
-    warn_deprecated("ThirdBody",
-        "Instantiation with default efficiency is deprecated and will be removed "
-        "after Cantera 3.0. Instantiate with collider name instead.");
-}
 
 ThirdBody::ThirdBody(const string& third_body)
 {
@@ -764,13 +768,6 @@ ThirdBody::ThirdBody(const AnyMap& node)
     setParameters(node);
 }
 
-void ThirdBody::setEfficiencies(const AnyMap& node)
-{
-    warn_deprecated("ThirdBody::setEfficiencies", node,
-        "To be removed after Cantera 3.0. Renamed to setParameters");
-    setParameters(node);
-}
-
 void ThirdBody::setParameters(const AnyMap& node)
 {
     if (node.hasKey("default-efficiency")) {
@@ -845,69 +842,6 @@ bool ThirdBody::checkSpecies(const Reaction& rxn, const Kinetics& kin) const
     return true;
 }
 
-ThreeBodyReaction::ThreeBodyReaction()
-{
-    warn_deprecated("ThreeBodyReaction",
-        "To be removed after Cantera 3.0. Replaceable with Reaction.");
-    m_third_body = make_shared<ThirdBody>();
-    setRate(newReactionRate(type()));
-}
-
-ThreeBodyReaction::ThreeBodyReaction(const Composition& reactants,
-                                     const Composition& products,
-                                     const ArrheniusRate& rate,
-                                     const ThirdBody& tbody)
-    : Reaction(reactants,
-               products,
-               make_shared<ArrheniusRate>(rate),
-               make_shared<ThirdBody>(tbody))
-{
-    warn_deprecated("ThreeBodyReaction",
-        "To be removed after Cantera 3.0. Replaceable with Reaction.");
-}
-
-ThreeBodyReaction::ThreeBodyReaction(const AnyMap& node, const Kinetics& kin)
-    : Reaction(node, kin)
-{
-    warn_deprecated("ThreeBodyReaction",
-        "To be removed after Cantera 3.0. Replaceable with Reaction.");
-}
-
-FalloffReaction::FalloffReaction()
-{
-    warn_deprecated("FalloffReaction",
-        "To be removed after Cantera 3.0. Replaceable with Reaction.");
-    m_third_body = make_shared<ThirdBody>();
-    setRate(newReactionRate(type()));
-}
-
-FalloffReaction::FalloffReaction(const Composition& reactants_,
-                                 const Composition& products_,
-                                 const FalloffRate& rate_,
-                                 const ThirdBody& tbody_)
-{
-    warn_deprecated("FalloffReaction",
-        "To be removed after Cantera 3.0. Replaceable with Reaction.");
-    // cannot be delegated as make_shared does not work for FalloffRate
-    reactants = reactants_;
-    products = products_;
-    m_third_body = make_shared<ThirdBody>(tbody_);
-    AnyMap node = rate_.parameters();
-    node.applyUnits();
-    string rate_type = node["type"].asString();
-    setRate(newReactionRate(node));
-}
-
-FalloffReaction::FalloffReaction(const AnyMap& node, const Kinetics& kin)
-    : Reaction(node, kin)
-{
-    warn_deprecated("FalloffReaction",
-        "To be removed after Cantera 3.0. Replaceable with Reaction.");
-    if (node.empty()) {
-        m_third_body = make_shared<ThirdBody>();
-        setRate(newReactionRate(type()));
-    }
-}
 
 unique_ptr<Reaction> newReaction(const string& type)
 {
@@ -994,7 +928,6 @@ vector<shared_ptr<Reaction>> getReactions(const AnyValue& items, Kinetics& kinet
     vector<shared_ptr<Reaction>> all_reactions;
     for (const auto& node : items.asVector<AnyMap>()) {
         auto R = make_shared<Reaction>(node, kinetics);
-        R->check();
         R->validate(kinetics);
         if (R->valid() && R->checkSpecies(kinetics)) {
             all_reactions.emplace_back(R);
