@@ -14,7 +14,7 @@ namespace {
 
 N_Vector newNVector(size_t N, Cantera::SundialsContext& context)
 {
-#if CT_SUNDIALS_VERSION >= 60
+#if SUNDIALS_VERSION_MAJOR >= 6
     return N_VNew_Serial(static_cast<sd_size_t>(N), context.get());
 #else
     return N_VNew_Serial(static_cast<sd_size_t>(N));
@@ -33,16 +33,9 @@ extern "C" {
 * IDA allows passing in a void* pointer to access external data. Instead of requiring
 * the user to provide a residual function directly to IDA (which would require using the
 * Sundials data types N_Vector, etc.), we define this function as the single function
-* that IDA always calls. The real evaluation of the residual is done by an instance of a
-* subclass of ResidEval, passed in to this function as a pointer in the parameters.
-*
-* FROM IDA WRITEUP -> What the IDA solver expects as a return flag from its
-* residual routines:
-*
-* A IDAResFn res should return a value of 0 if successful, a positive value if a
-* recoverable error occurred (e.g. yy has an illegal value), or a negative value if a
-* nonrecoverable error occurred. In the latter case, the program halts. If a recoverable
-* error occurred, the integrator will attempt to correct and retry.
+* that IDA always calls. The real evaluation of the residual is done by the
+* FuncEval::evalDae() method of an instance of a subclass of FuncEval that is passed
+* into this function as the `f_data` parameter.
 */
 static int ida_rhs(sunrealtype t, N_Vector y, N_Vector ydot, N_Vector r, void* f_data)
 {
@@ -65,7 +58,7 @@ static void ida_err(int error_code, const char* module,
 //! writing to stdout. Here, save the error message provided by CVodes so
 //! that it can be included in the subsequently raised CanteraError. Used by
 //! SUNDIALS 7.0 and newer.
-#if CT_SUNDIALS_VERSION >= 70
+#if SUNDIALS_VERSION_MAJOR >= 7
     static void sundials_err(int line, const char *func, const char *file,
                             const char *msg, SUNErrCode err_code,
                             void *err_user_data, SUNContext sunctx)
@@ -278,7 +271,7 @@ void IdasIntegrator::initialize(double t0, FuncEval& func)
     }
 
     //! Create the IDA solver
-    #if CT_SUNDIALS_VERSION >= 60
+    #if SUNDIALS_VERSION_MAJOR >= 6
         m_ida_mem = IDACreate(m_sundials_ctx.get());
     #else
         m_ida_mem = IDACreate();
@@ -300,7 +293,7 @@ void IdasIntegrator::initialize(double t0, FuncEval& func)
         }
     }
 
-    #if CT_SUNDIALS_VERSION >= 70
+    #if SUNDIALS_VERSION_MAJOR >= 7
         flag = SUNContext_PushErrHandler(m_sundials_ctx.get(), &sundials_err, this);
     #else
         flag = IDASetErrHandlerFn(m_ida_mem, &ida_err, this);
@@ -352,32 +345,32 @@ void IdasIntegrator::applyOptions()
         sd_size_t N = static_cast<sd_size_t>(m_neq);
         SUNLinSolFree((SUNLinearSolver) m_linsol);
         SUNMatDestroy((SUNMatrix) m_linsol_matrix);
-        #if CT_SUNDIALS_VERSION >= 60
+        #if SUNDIALS_VERSION_MAJOR >= 6
             m_linsol_matrix = SUNDenseMatrix(N, N, m_sundials_ctx.get());
         #else
             m_linsol_matrix = SUNDenseMatrix(N, N);
         #endif
-        #if CT_SUNDIALS_VERSION >= 60
+        #if SUNDIALS_VERSION_MAJOR >= 6
             m_linsol_matrix = SUNDenseMatrix(N, N, m_sundials_ctx.get());
         #else
             m_linsol_matrix = SUNDenseMatrix(N, N);
         #endif
         #if CT_SUNDIALS_USE_LAPACK
-            #if CT_SUNDIALS_VERSION >= 60
+            #if SUNDIALS_VERSION_MAJOR >= 6
                 m_linsol = SUNLinSol_LapackDense(m_y, (SUNMatrix) m_linsol_matrix,
                                                  m_sundials_ctx.get());
             #else
                 m_linsol = SUNLapackDense(m_y, (SUNMatrix) m_linsol_matrix);
             #endif
         #else
-            #if CT_SUNDIALS_VERSION >= 60
+            #if SUNDIALS_VERSION_MAJOR >= 6
                 m_linsol = SUNLinSol_Dense(m_y, (SUNMatrix) m_linsol_matrix,
                                            m_sundials_ctx.get());
             #else
                 m_linsol = SUNLinSol_Dense(m_y, (SUNMatrix) m_linsol_matrix);
             #endif
         #endif
-        #if CT_SUNDIALS_VERSION >= 60
+        #if SUNDIALS_VERSION_MAJOR >= 6
             IDASetLinearSolver(m_ida_mem, (SUNLinearSolver) m_linsol,
                                (SUNMatrix) m_linsol_matrix);
         #else
@@ -385,10 +378,11 @@ void IdasIntegrator::applyOptions()
                                   (SUNMatrix) m_linsol_matrix);
         #endif
     } else if (m_type == "GMRES") {
-        #if CT_SUNDIALS_VERSION >= 60
+        SUNLinSolFree((SUNLinearSolver) m_linsol);
+        #if SUNDIALS_VERSION_MAJOR >= 6
             m_linsol = SUNLinSol_SPGMR(m_y, SUN_PREC_NONE, 0, m_sundials_ctx.get());
             IDASetLinearSolver(m_ida_mem, (SUNLinearSolver) m_linsol, nullptr);
-        #elif CT_SUNDIALS_VERSION >= 40
+        #elif SUNDIALS_VERSION_MAJOR >= 4
             m_linsol = SUNLinSol_SPGMR(m_y, PREC_NONE, 0);
             IDASpilsSetLinearSolver(m_ida_mem, (SUNLinearSolver) m_linsol);
         #else
@@ -434,7 +428,7 @@ void IdasIntegrator::sensInit(double t0, FuncEval& func)
     m_sens_ok = false;
 
     N_Vector y = newNVector(static_cast<sd_size_t>(func.neq()), m_sundials_ctx);
-    #if CT_SUNDIALS_VERSION >= 60
+    #if SUNDIALS_VERSION_MAJOR >= 6
         m_yS = N_VCloneVectorArray(static_cast<int>(m_np), y);
     #else
         m_yS = N_VCloneVectorArray_Serial(static_cast<int>(m_np), y);
@@ -444,7 +438,7 @@ void IdasIntegrator::sensInit(double t0, FuncEval& func)
     }
     N_VDestroy_Serial(y);
     N_Vector ydot = newNVector(static_cast<sd_size_t>(func.neq()), m_sundials_ctx);
-    #if CT_SUNDIALS_VERSION >= 60
+    #if SUNDIALS_VERSION_MAJOR >= 6
         m_ySdot = N_VCloneVectorArray(static_cast<int>(m_np), ydot);
     #else
         m_ySdot = N_VCloneVectorArray_Serial(static_cast<int>(m_np), ydot);
