@@ -6,7 +6,7 @@
 #include "cantera/base/SolutionArray.h"
 #include "cantera/oneD/Boundary1D.h"
 #include "cantera/oneD/OneDim.h"
-#include "cantera/oneD/StFlow.h"
+#include "cantera/oneD/Flow1D.h"
 
 using namespace std;
 
@@ -15,7 +15,6 @@ namespace Cantera
 
 Boundary1D::Boundary1D() : Domain1D(1, 1, 0.0)
 {
-    m_type = cConnectorType;
 }
 
 void Boundary1D::_init(size_t n)
@@ -41,9 +40,7 @@ void Boundary1D::_init(size_t n)
             } else {
                 m_left_nsp = 0;
             }
-            m_left_loc = container().start(m_index-1);
-            m_left_points = r.nPoints();
-            m_flow_left = dynamic_cast<StFlow*>(&r);
+            m_flow_left = dynamic_cast<Flow1D*>(&r);
             if (m_flow_left != nullptr) {
                 m_phase_left = &m_flow_left->phase();
             }
@@ -64,8 +61,7 @@ void Boundary1D::_init(size_t n)
             } else {
                 m_right_nsp = 0;
             }
-            m_right_loc = container().start(m_index+1);
-            m_flow_right = dynamic_cast<StFlow*>(&r);
+            m_flow_right = dynamic_cast<Flow1D*>(&r);
             if (m_flow_right != nullptr) {
                 m_phase_right = &m_flow_right->phase();
             }
@@ -86,13 +82,12 @@ void Boundary1D::fromArray(SolutionArray& arr, double* soln)
 
 Inlet1D::Inlet1D()
 {
-    m_type = cInletType;
 }
 
 Inlet1D::Inlet1D(shared_ptr<Solution> solution, const string& id)
     : Inlet1D()
 {
-    m_solution = solution;
+    setSolution(solution);
     m_id = id;
 }
 
@@ -104,6 +99,14 @@ void Inlet1D::setSpreadRate(double V0)
     needJacUpdate();
 }
 
+void Inlet1D::setTemperature(double T)
+{
+    Boundary1D::setTemperature(T);
+    // Adjust flow domain temperature bounds based on inlet temperature
+    if (m_flow != nullptr && m_flow->lowerBound(c_offset_T) >= m_temp) {
+        m_flow->setBounds(c_offset_T, m_temp - 5.0, m_flow->upperBound(c_offset_T));
+    }
+}
 
 void Inlet1D::show(const double* x)
 {
@@ -170,6 +173,7 @@ void Inlet1D::init()
     } else {
         m_yin[0] = 1.0;
     }
+
 }
 
 void Inlet1D::eval(size_t jg, double* xg, double* rg,
@@ -198,20 +202,28 @@ void Inlet1D::eval(size_t jg, double* xg, double* rg,
 
         if (m_flow->isFree()) {
             // if the flow is a freely-propagating flame, mdot is not specified.
-            // Set mdot equal to rho*u, and also set lambda to zero.
+            // Set mdot equal to rho*u.
             m_mdot = m_flow->density(0) * xb[c_offset_U];
-            rb[c_offset_L] = xb[c_offset_L];
-        } else if (m_flow->isStrained()) {
-            // The flow domain sets this to -rho*u. Add mdot to specify the mass
-            // flow rate
-            rb[c_offset_L] += m_mdot;
+        } else if (m_flow->isStrained()) { // axisymmetric flow
+            if (m_flow->twoPointControlEnabled()) {
+                // When using two-point control, the mass flow rate at the left inlet is
+                // not specified. Instead, the mass flow rate is dictated by the
+                // velocity at the left inlet, which comes from the U variable. The
+                // default boundary condition specified in the Flow1D.cpp file already
+                // handles this case. We only need to update the stored value of m_mdot
+                // so that other equations that use the quantity are consistent.
+                m_mdot = m_flow->density(0)*xb[c_offset_U];
+            } else {
+                // The flow domain sets this to -rho*u. Add mdot to specify the mass
+                // flow rate
+                rb[c_offset_L] += m_mdot;
+            }
 
             // spreading rate. The flow domain sets this to V(0),
             // so for finite spreading rate subtract m_V0.
             rb[c_offset_V] -= m_V0;
-        } else {
+        } else { // unstrained flow
             rb[c_offset_U] = m_flow->density(0) * xb[c_offset_U] - m_mdot;
-            rb[c_offset_L] = xb[c_offset_L];
         }
 
         // add the convective term to the species residual equations
@@ -225,13 +237,25 @@ void Inlet1D::eval(size_t jg, double* xg, double* rg,
         // right inlet (should only be used for counter-flow flames)
         // Array elements corresponding to the last point in the flow domain
         double* rb = rg + loc() - m_flow->nComponents();
+        double* xb = xg + loc() - m_flow->nComponents();
+        size_t last_index = m_flow->nPoints() - 1;
+
         rb[c_offset_V] -= m_V0;
         if (m_flow->doEnergy(m_flow->nPoints() - 1)) {
             rb[c_offset_T] -= m_temp; // T
         } else {
             rb[c_offset_T] -= m_flow->T_fixed(m_flow->nPoints() - 1);
         }
-        rb[c_offset_U] += m_mdot; // u
+
+        if (m_flow->twoPointControlEnabled()) { // For point control adjustments
+            // At the right boundary, the mdot is dictated by the velocity at the right
+            // boundary, which comes from the Uo variable. The variable Uo is the
+            // left-moving velocity and has a negative value, so the mass flow has to be
+            // negated to give a positive value when using Uo.
+            m_mdot = -m_flow->density(last_index) * xb[c_offset_Uo];
+        }
+        rb[c_offset_U] += m_mdot;
+
         for (size_t k = 0; k < m_nsp; k++) {
             if (k != m_flow_left->rightExcessSpecies()) {
                 rb[c_offset_Y+k] += m_mdot * m_yin[k];
@@ -348,13 +372,12 @@ shared_ptr<SolutionArray> Symm1D::asArray(const double* soln) const
 
 OutletRes1D::OutletRes1D()
 {
-    m_type = cOutletResType;
 }
 
 OutletRes1D::OutletRes1D(shared_ptr<Solution> solution, const string& id)
     : OutletRes1D()
 {
-    m_solution = solution;
+    setSolution(solution);
     m_id = id;
 }
 
@@ -577,10 +600,8 @@ void Surf1D::show(const double* x)
 
 ReactingSurf1D::ReactingSurf1D()
     : m_kin(0)
-    , m_surfindex(0)
     , m_nsp(0)
 {
-    m_type = cSurfType;
 }
 
 ReactingSurf1D::ReactingSurf1D(shared_ptr<Solution> solution, const string& id)
@@ -596,40 +617,27 @@ ReactingSurf1D::ReactingSurf1D(shared_ptr<Solution> solution, const string& id)
             "Detected incompatible kinetics type '{}'",
             solution->kinetics()->kineticsType());
     }
-    m_solution = solution;
+    setSolution(solution);
     m_id = id;
     m_kin = kin.get();
     m_sphase = phase.get();
-
-    m_surfindex = m_kin->reactionPhaseIndex();
     m_nsp = m_sphase->nSpecies();
     m_enabled = true;
 }
 
 void ReactingSurf1D::setKinetics(shared_ptr<Kinetics> kin)
 {
-    m_solution = Solution::create();
-    m_solution->setThermo(kin->reactionPhase());
-    m_solution->setKinetics(kin);
-    m_solution->setTransportModel("none");
+    auto sol = Solution::create();
+    sol->setThermo(kin->reactionPhase());
+    sol->setKinetics(kin);
+    sol->setTransportModel("none");
+    setSolution(sol);
     m_kin = dynamic_pointer_cast<InterfaceKinetics>(kin).get();
-    m_surfindex = kin->reactionPhaseIndex();
     m_sphase = dynamic_pointer_cast<SurfPhase>(kin->reactionPhase()).get();
     m_nsp = m_sphase->nSpecies();
     m_enabled = true;
 }
 
-void ReactingSurf1D::setKineticsMgr(InterfaceKinetics* kin)
-{
-    warn_deprecated("ReactingSurf1D::setKineticsMgr",
-        "To be removed after Cantera 3.0. Replaced by Domain1D::setKinetics.");
-    m_kin = kin;
-    m_surfindex = kin->reactionPhaseIndex();
-    m_sphase = (SurfPhase*)&kin->thermo(m_surfindex);
-    m_nsp = m_sphase->nSpecies();
-    m_enabled = true;
-}
-
 string ReactingSurf1D::componentName(size_t n) const
 {
     if (n < m_nsp) {
@@ -698,11 +706,10 @@ void ReactingSurf1D::eval(size_t jg, double* xg, double* rg,
 
     m_kin->getNetProductionRates(m_work.data());
     double rs0 = 1.0/m_sphase->siteDensity();
-    size_t ioffset = m_kin->kineticsSpeciesIndex(0, m_surfindex);
 
     if (m_enabled) {
         for (size_t k = 0; k < m_nsp; k++) {
-            r[k] = m_work[k + ioffset] * m_sphase->size(k) * rs0;
+            r[k] = m_work[k] * m_sphase->size(k) * rs0;
             r[k] -= rdt*(x[k] - prevSoln(k,0));
             diag[k] = 1;
         }
