@@ -9,7 +9,9 @@
 #include "cantera/oneD/MultiJac.h"
 #include "cantera/oneD/refine.h"
 #include "cantera/base/AnyMap.h"
+#include "cantera/base/Solution.h"
 #include "cantera/base/SolutionArray.h"
+#include "cantera/thermo/ThermoPhase.h"
 
 namespace Cantera
 {
@@ -21,13 +23,22 @@ Domain1D::Domain1D(size_t nv, size_t points, double time)
 
 Domain1D::~Domain1D()
 {
+    if (m_solution) {
+        m_solution->thermo()->removeSpeciesLock();
+    }
 }
 
-int Domain1D::domainType()
+void Domain1D::setSolution(shared_ptr<Solution> sol)
 {
-    warn_deprecated("Domain1D::domainType",
-        "To be changed after Cantera 3.0; for new behavior, see 'type'.");
-    return m_type;
+    if (!sol || !(sol->thermo())) {
+        throw CanteraError("Domain1D::setSolution",
+            "Missing or incomplete Solution object.");
+    }
+    if (m_solution) {
+        m_solution->thermo()->removeSpeciesLock();
+    }
+    m_solution = sol;
+    m_solution->thermo()->addSpeciesLock();
 }
 
 void Domain1D::resize(size_t nv, size_t np)
@@ -135,16 +146,6 @@ AnyMap Domain1D::getMeta() const
     return state;
 }
 
-AnyMap Domain1D::serialize(const double* soln) const
-{
-    warn_deprecated("Domain1D::serialize",
-        "To be removed after Cantera 3.0; superseded by asArray.");
-    AnyMap out;
-    auto arr = asArray(soln);
-    arr->writeEntry(out, "", "");
-    return out;
-}
-
 shared_ptr<SolutionArray> Domain1D::toArray(bool normalize) const {
     if (!m_state) {
         throw CanteraError("Domain1D::toArray",
@@ -201,15 +202,6 @@ void Domain1D::setMeta(const AnyMap& meta)
     }
 }
 
-void Domain1D::restore(const AnyMap& state, double* soln, int loglevel)
-{
-    warn_deprecated("Domain1D::restore",
-        "To be removed after Cantera 3.0; restore from SolutionArray instead.");
-    auto arr = SolutionArray::create(solution());
-    arr->readEntry(state, "", "");
-    fromArray(*arr, soln);
-}
-
 void Domain1D::locate()
 {
     if (m_left) {
@@ -240,20 +232,6 @@ void Domain1D::setupGrid(size_t n, const double* z)
     }
 }
 
-void Domain1D::showSolution_s(std::ostream& s, const double* x)
-{
-    warn_deprecated("Domain1D::showSolution_s",
-        "To be removed after Cantera 3.0; replaced by 'show'.");
-    show(s, x);
-}
-
-void Domain1D::showSolution(const double* x)
-{
-    warn_deprecated("Domain1D::showSolution",
-        "To be removed after Cantera 3.0; replaced by 'show'.");
-    show(x);
-}
-
 void Domain1D::show(const double* x)
 {
     size_t nn = m_nv/5;
