@@ -4,7 +4,7 @@
 // at https://cantera.org/license.txt for license and copyright information.
 
 #include "cantera/oneD/IonFlow.h"
-#include "cantera/oneD/StFlow.h"
+#include "cantera/oneD/Flow1D.h"
 #include "cantera/oneD/refine.h"
 #include "cantera/transport/Transport.h"
 #include "cantera/numerics/funcs.h"
@@ -16,7 +16,7 @@ namespace Cantera
 {
 
 IonFlow::IonFlow(ThermoPhase* ph, size_t nsp, size_t points) :
-    StFlow(ph, nsp, points)
+    Flow1D(ph, nsp, points)
 {
     // make a local copy of species charge
     for (size_t k = 0; k < m_nsp; k++) {
@@ -56,17 +56,14 @@ IonFlow::IonFlow(ThermoPhase* ph, size_t nsp, size_t points) :
 IonFlow::IonFlow(shared_ptr<Solution> sol, const string& id, size_t points)
     : IonFlow(sol->thermo().get(), sol->thermo()->nSpecies(), points)
 {
-    m_solution = sol;
+    setSolution(sol);
     m_id = id;
     m_kin = m_solution->kinetics().get();
     m_trans = m_solution->transport().get();
     if (m_trans->transportModel() == "none") {
-        // @deprecated
-        warn_deprecated("IonFlow",
+        throw CanteraError("IonFlow::IonFlow",
             "An appropriate transport model\nshould be set when instantiating the "
-            "Solution ('gas') object.\nImplicit setting of the transport model "
-            "is deprecated and\nwill be removed after Cantera 3.0.");
-        setTransportModel("ionized-gas");
+            "Solution ('gas') object.");
     }
     m_solution->registerChangedCallback(this, [this]() {
         setKinetics(m_solution->kinetics());
@@ -74,7 +71,7 @@ IonFlow::IonFlow(shared_ptr<Solution> sol, const string& id, size_t points)
     });
 }
 
-string IonFlow::type() const {
+string IonFlow::domainType() const {
     if (m_isFree) {
         return "free-ion-flow";
     }
@@ -85,9 +82,8 @@ string IonFlow::type() const {
 }
 
 void IonFlow::resize(size_t components, size_t points){
-    StFlow::resize(components, points);
+    Flow1D::resize(components, points);
     m_mobility.resize(m_nsp*m_points);
-    m_do_species.resize(m_nsp,true);
     m_do_electric_field.resize(m_points,false);
 }
 
@@ -96,13 +92,13 @@ bool IonFlow::componentActive(size_t n) const
     if (n == c_offset_E) {
         return true;
     } else {
-        return StFlow::componentActive(n);
+        return Flow1D::componentActive(n);
     }
 }
 
 void IonFlow::updateTransport(double* x, size_t j0, size_t j1)
 {
-    StFlow::updateTransport(x,j0,j1);
+    Flow1D::updateTransport(x,j0,j1);
     for (size_t j = j0; j < j1; j++) {
         setGasAtMidpoint(x,j);
         m_trans->getMobilities(&m_mobility[j*m_nsp]);
@@ -110,7 +106,9 @@ void IonFlow::updateTransport(double* x, size_t j0, size_t j1)
             size_t k = m_kElectron;
             double tlog = log(m_thermo->temperature());
             m_mobility[k+m_nsp*j] = poly5(tlog, m_mobi_e_fix.data());
-            m_diff[k+m_nsp*j] = poly5(tlog, m_diff_e_fix.data());
+            double rho = m_thermo->density();
+            double wtm = m_thermo->meanMolecularWeight();
+            m_diff[k+m_nsp*j] = m_wt[k]*rho*poly5(tlog, m_diff_e_fix.data())/wtm;
         }
     }
 }
@@ -128,12 +126,10 @@ void IonFlow::updateDiffFluxes(const double* x, size_t j0, size_t j1)
 void IonFlow::frozenIonMethod(const double* x, size_t j0, size_t j1)
 {
     for (size_t j = j0; j < j1; j++) {
-        double wtm = m_wtm[j];
-        double rho = density(j);
         double dz = z(j+1) - z(j);
         double sum = 0.0;
         for (size_t k : m_kNeutral) {
-            m_flux(k,j) = m_wt[k]*(rho*m_diff[k+m_nsp*j]/wtm);
+            m_flux(k,j) = m_diff[k+m_nsp*j];
             m_flux(k,j) *= (X(x,k,j) - X(x,k,j+1))/dz;
             sum -= m_flux(k,j);
         }
@@ -155,13 +151,12 @@ void IonFlow::frozenIonMethod(const double* x, size_t j0, size_t j1)
 void IonFlow::electricFieldMethod(const double* x, size_t j0, size_t j1)
 {
     for (size_t j = j0; j < j1; j++) {
-        double wtm = m_wtm[j];
         double rho = density(j);
         double dz = z(j+1) - z(j);
 
         // mixture-average diffusion
         for (size_t k = 0; k < m_nsp; k++) {
-            m_flux(k,j) = m_wt[k]*(rho*m_diff[k+m_nsp*j]/wtm);
+            m_flux(k,j) = m_diff[k+m_nsp*j];
             m_flux(k,j) *= (X(x,k,j) - X(x,k,j+1))/dz;
         }
 
@@ -202,37 +197,46 @@ void IonFlow::setSolvingStage(const size_t stage)
     }
 }
 
-void IonFlow::evalResidual(double* x, double* rsd, int* diag,
-                           double rdt, size_t jmin, size_t jmax)
+//! Evaluate the electric field equation residual
+void IonFlow::evalElectricField(double* x, double* rsd, int* diag,
+                                double rdt, size_t jmin, size_t jmax)
 {
-    StFlow::evalResidual(x, rsd, diag, rdt, jmin, jmax);
+    Flow1D::evalElectricField(x, rsd, diag, rdt, jmin, jmax);
     if (m_stage != 2) {
         return;
     }
 
-    for (size_t j = jmin; j <= jmax; j++) {
-        if (j == 0) {
-            // enforcing the flux for charged species is difficult
-            // since charged species are also affected by electric
-            // force, so Neumann boundary condition is used.
-            for (size_t k : m_kCharge) {
-                rsd[index(c_offset_Y + k, 0)] = Y(x,k,0) - Y(x,k,1);
-            }
-            rsd[index(c_offset_E, j)] = E(x,0);
-            diag[index(c_offset_E, j)] = 0;
-        } else if (j == m_points - 1) {
-            rsd[index(c_offset_E, j)] = dEdz(x,j) - rho_e(x,j) / epsilon_0;
-            diag[index(c_offset_E, j)] = 0;
-        } else {
-            //-----------------------------------------------
-            //    Electric field by Gauss's law
-            //
-            //    dE/dz = e/eps_0 * sum(q_k*n_k)
-            //
-            //    E = -dV/dz
-            //-----------------------------------------------
-            rsd[index(c_offset_E, j)] = dEdz(x,j) - rho_e(x,j) / epsilon_0;
-            diag[index(c_offset_E, j)] = 0;
+    if (jmin == 0) { // left boundary
+        rsd[index(c_offset_E, jmin)] = E(x,jmin);
+    }
+
+    if (jmax == m_points - 1) { // right boundary
+        rsd[index(c_offset_E, jmax)] = dEdz(x,jmax) - rho_e(x,jmax) / epsilon_0;
+    }
+
+    // j0 and j1 are constrained to only interior points
+    size_t j0 = std::max<size_t>(jmin, 1);
+    size_t j1 = std::min(jmax, m_points - 2);
+    for (size_t j = j0; j <= j1; j++) {
+        rsd[index(c_offset_E, j)] = dEdz(x,j) - rho_e(x,j) / epsilon_0;
+        diag[index(c_offset_E, j)] = 0;
+    }
+}
+
+void IonFlow::evalSpecies(double* x, double* rsd, int* diag,
+                          double rdt, size_t jmin, size_t jmax)
+{
+    Flow1D::evalSpecies(x, rsd, diag, rdt, jmin, jmax);
+    if (m_stage != 2) {
+        return;
+    }
+
+    if (jmin == 0) { // left boundary
+        // enforcing the flux for charged species is difficult
+        // since charged species are also affected by electric
+        // force, so Neumann boundary condition is used.
+        for (size_t k : m_kCharge) {
+            rsd[index(c_offset_Y + k, jmin)] = Y(x,k,jmin) - Y(x,k,jmin + 1);
         }
     }
 }
@@ -306,7 +310,7 @@ void IonFlow::setElectronTransport(vector<double>& tfix, vector<double>& diff_e,
 
 void IonFlow::_finalize(const double* x)
 {
-    StFlow::_finalize(x);
+    Flow1D::_finalize(x);
 
     bool p = m_do_electric_field[0];
     if (p) {
