@@ -39,6 +39,8 @@ double bound_step(const double* x, const double* step, Domain1D& r, int loglevel
     Indx index(nv, np);
     double fbound = 1.0;
     bool wroteTitle = false;
+    string separator = fmt::format("\n     {:=>69}", ""); // equals sign separator
+
     for (size_t m = 0; m < nv; m++) {
         double above = r.upperBound(m);
         double below = r.lowerBound(m);
@@ -61,18 +63,38 @@ double bound_step(const double* x, const double* step, Domain1D& r, int loglevel
             }
 
             if (loglevel > 1 && (newval > above || newval < below)) {
-                if (!wroteTitle) {
-                    writelog("\nNewton step takes solution out of bounds.\n\n");
-                    writelog("  {:>12s}  {:>12s}  {:>4s}  {:>10s}  {:>10s}  {:>10s}  {:>10s}\n",
-                             "domain","component","pt","value","step","min","max");
+                if (!wroteTitle){
+                    string header = fmt::format("     {:=>10}","") +
+                                    "Undamped Newton step takes solution out of bounds" +
+                                    fmt::format("{:=>10}", "");
+                    writelog("\n{}", header);
+                    writelog(separator);
+                    // Split header across 2 lines to shorten the line length
+                    writelog("\n     {:<7s}   {:23s}   {:<9s}   {:<9s}   {:<9s}",
+                             "Domain/", "", "Value", "Min", "Max");
+                    writelog("\n     {:8s}  {:<9s}     {:<9s}   {:6s}      {:5s}       {:5s}",
+                             "Grid Loc", "Component", "Value", "Change", "Bound", "Bound");
+                    writelog(separator);
                     wroteTitle = true;
                 }
-                writelog("          {:4d}  {:>12s}  {:4d}  {:10.3e}  {:10.3e}  {:10.3e}  {:10.3e}\n",
-                         r.domainIndex(), r.componentName(m), j,
-                         val, step[index(m,j)], below, above);
+                // This create a dynamic spacing to allow for a nicely formatted output in the
+                // Domain/Grid Loc column
+                int domainLength = to_string(r.domainIndex()).length(); // For adjusting spacing
+                int gridLength = to_string(j).length(); // For adjusting spacing
+                int padding = 9; // Total spacing for first column
+                string formatString = fmt::format("{{:<{}d}} / {{:<{}d}}{:>{}}",
+                                                  domainLength, gridLength, "",
+                                                  padding-3-domainLength-gridLength);
+                writelog(fmt::format("\n     {}", formatString), r.domainIndex(), j);
+                writelog(" {:<12s} {:>10.3e}  {:>10.3e}  {:>10.3e}  {:>10.3e}",
+                         r.componentName(m), val, step[index(m,j)], below, above);
             }
         }
     }
+
+    if (loglevel > 1 && wroteTitle) { // If a title was written, close up the table
+        writelog(separator);
+    }
     return fbound;
 }
 
@@ -97,6 +119,15 @@ double bound_step(const double* x, const double* step, Domain1D& r, int loglevel
  * and multiplies the average magnitude of solution component n in the domain.
  * The second term, @f$ \epsilon_{a,n} @f$, is the absolute error tolerance for
  * component n.
+ *
+ * The purpose is to measure the "size" of the step vector @f$ s @f$ in a way that
+ * takes into account the relative importance or scale of different solution
+ * components.
+ *
+ * Normalization: Each component of the step vector is normalized by a weight that
+ * depends on both the current magnitude of the solution vector and specified
+ * tolerances. This makes the norm dimensionless and scaled appropriately, avoiding
+ * issues where some components dominate due to differences in their scales.
  */
 double norm_square(const double* x, const double* step, Domain1D& r)
 {
@@ -123,10 +154,6 @@ double norm_square(const double* x, const double* step, Domain1D& r)
 } // end unnamed-namespace
 
 
-// constants
-const double DampFactor = sqrt(2.0);
-const size_t NDAMP = 7;
-
 // ---------------- MultiNewton methods ----------------
 
 MultiNewton::MultiNewton(int sz)
@@ -205,13 +232,11 @@ int MultiNewton::dampStep(const double* x0, const double* step0,
 {
     // write header
     if (loglevel > 0 && writetitle) {
-        writelog("\n\nDamped Newton iteration:\n");
-        writeline('-', 65, false);
-
-        writelog("\n{}  {:>9s}   {:>9s}     {:>9s}   {:>9s}   {:>9s}  {:>5s} {:>5s}\n",
-                "m","F_damp","F_bound","log10(ss)",
-                "log10(s0)","log10(s1)","N_jac","Age");
-        writeline('-', 65);
+        writelog("\n\n  {:-^70}", " Damped Newton iteration ");
+        writelog("\n  {:<4s}  {:<10s}   {:<10s}  {:<7s}  {:<7s}  {:<7s}  {:<5s}  {:<3s}\n",
+                 "Iter", "F_damp", "F_bound", "log(ss)",
+                 "log(s0)", "log(s1)", "N_jac", "Age");
+        writelog("  {:->70}", "");
     }
 
     // compute the weighted norm of the undamped step size step0
@@ -224,58 +249,61 @@ int MultiNewton::dampStep(const double* x0, const double* step0,
     // step0 points out of the allowed domain. In this case, the Newton
     // algorithm fails, so return an error condition.
     if (fbound < 1.e-10) {
-        debuglog("\nAt limits.\n", loglevel);
+        debuglog("\n  No damped step can be taken without violating solution component bounds.", loglevel);
         return -3;
     }
 
     // ---------- Attempt damped step ----------
 
-    // damping coefficient starts at 1.0
-    double damp = 1.0;
+    // damping coefficient starts at 1.0, but must be scaled by the
+    // fbound factor to ensure that the solution remains within bounds.
+    double alpha = fbound*1.0;
     size_t m;
-    for (m = 0; m < NDAMP; m++) {
-        double ff = fbound*damp;
-
+    for (m = 0; m < m_maxDampIter; m++) {
         // step the solution by the damped step size
+        // x_{k+1} = x_k + alpha_k*J(x_k)^-1 F(x_k)
         for (size_t j = 0; j < m_n; j++) {
-            x1[j] = ff*step0[j] + x0[j];
+            x1[j] = x0[j] + alpha*step0[j];
         }
 
         // compute the next undamped step that would result if x1 is accepted
+        // J(x_k)^-1 F(x_k+1)
         step(x1, step1, r, jac, loglevel-1);
 
         // compute the weighted norm of step1
         s1 = norm2(x1, step1, r);
 
-        // write log information
         if (loglevel > 0) {
             double ss = r.ssnorm(x1,step1);
-            writelog("\n{:d}  {:9.5f}   {:9.5f}   {:9.5f}   {:9.5f}   {:9.5f} {:4d}  {:d}/{:d}",
-                     m, damp, fbound, log10(ss+SmallNumber),
+            writelog("\n  {:<4d}  {:<9.3e}   {:<9.3e}   {:>6.3f}   {:>6.3f}   {:>6.3f}    {:<5d}  {:d}/{:d}",
+                     m, alpha, fbound, log10(ss+SmallNumber),
                      log10(s0+SmallNumber), log10(s1+SmallNumber),
                      jac.nEvals(), jac.age(), m_maxAge);
         }
 
-        // if the norm of s1 is less than the norm of s0, then accept this
+        // If the norm of s1 is less than the norm of s0, then accept this
         // damping coefficient. Also accept it if this step would result in a
         // converged solution. Otherwise, decrease the damping coefficient and
         // try again.
         if (s1 < 1.0 || s1 < s0) {
             break;
         }
-        damp /= DampFactor;
+        alpha /= m_dampFactor;
     }
 
     // If a damping coefficient was found, return 1 if the solution after
     // stepping by the damped step would represent a converged solution, and
     // return 0 otherwise. If no damping coefficient could be found, return -2.
-    if (m < NDAMP) {
+    if (m < m_maxDampIter) {
         if (s1 > 1.0) {
+                debuglog("\n  Damping coefficient found (solution has not converged yet)", loglevel);
             return 0;
         } else {
+                debuglog("\n  Damping coefficient found (solution has converged)", loglevel);
             return 1;
         }
     } else {
+            debuglog("\n  No damping coefficient found (max damping iterations reached)", loglevel);
         return -2;
     }
 }
@@ -283,22 +311,20 @@ int MultiNewton::dampStep(const double* x0, const double* step0,
 int MultiNewton::solve(double* x0, double* x1, OneDim& r, MultiJac& jac, int loglevel)
 {
     clock_t t0 = clock();
-    int m = 0;
+    int status = 0;
     bool forceNewJac = false;
+    bool write_header = true;
     double s1=1.e30;
 
     copy(x0, x0 + m_n, &m_x[0]);
 
-    bool frst = true;
     double rdt = r.rdt();
-    int j0 = jac.nEvals();
     int nJacReeval = 0;
-
     while (true) {
         // Check whether the Jacobian should be re-evaluated.
         if (jac.age() > m_maxAge) {
-            if (loglevel > 0) {
-                writelog("\nMaximum Jacobian age reached ({})\n", m_maxAge);
+            if (loglevel > 1) {
+                writelog("\n  Maximum Jacobian age reached ({}), updating it.", m_maxAge);
             }
             forceNewJac = true;
         }
@@ -317,30 +343,19 @@ int MultiNewton::solve(double* x0, double* x1, OneDim& r, MultiJac& jac, int log
         jac.incrementAge();
 
         // damp the Newton step
-        m = dampStep(&m_x[0], &m_stp[0], x1, &m_stp1[0], s1, r, jac, loglevel-1, frst);
-        if (loglevel == 1 && m >= 0) {
-            if (frst) {
-                writelog("\n\n    {:>10s}    {:>10s}   {:>5s}",
-                         "log10(ss)","log10(s1)","N_jac");
-                writelog("\n    ------------------------------------");
-            }
-            double ss = r.ssnorm(&m_x[0], &m_stp[0]);
-            writelog("\n    {:10.4f}    {:10.4f}       {:d}",
-                     log10(ss),log10(s1),jac.nEvals());
-        }
-        frst = false;
+        status = dampStep(&m_x[0], &m_stp[0], x1, &m_stp1[0], s1, r, jac, loglevel-1, write_header);
+        write_header = false;
 
         // Successful step, but not converged yet. Take the damped step, and try
         // again.
-        if (m == 0) {
+        if (status == 0) {
             copy(x1, x1 + m_n, m_x.begin());
-        } else if (m == 1) {
-            // convergence
+        } else if (status == 1) { // convergence
             if (rdt == 0) {
                 jac.setAge(0); // for efficient sensitivity analysis
             }
             break;
-        } else if (m < 0) {
+        } else if (status < 0) {
             // If dampStep fails, first try a new Jacobian if an old one was
             // being used. If it was a new Jacobian, then return -1 to signify
             // failure.
@@ -350,23 +365,25 @@ int MultiNewton::solve(double* x0, double* x1, OneDim& r, MultiJac& jac, int log
                     break;
                 }
                 nJacReeval++;
-                debuglog("\nRe-evaluating Jacobian, since no damping "
-                         "coefficient\ncould be found with this Jacobian.\n",
-                         loglevel);
+                if (loglevel > 1) {
+                    writelog("\n  Re-evaluating Jacobian (damping coefficient not found"
+                            " with this Jacobian)");
+                }
             } else {
                 break;
             }
         }
     }
+    // Close off the damped iteration table that is written by the dampedStep() method
+    if (loglevel > 1) {
+        writelog("\n  {:->70}", "");
+    }
 
-    if (m < 0) {
+    if (status < 0) { // Reset x1 to x0 if the solution failed
         copy(m_x.begin(), m_x.end(), x1);
     }
-    if (m > 0 && jac.nEvals() == j0) {
-        m = 100;
-    }
     m_elapsed += (clock() - t0)/(1.0*CLOCKS_PER_SEC);
-    return m;
+    return status;
 }
 
 } // end namespace Cantera
