@@ -33,22 +33,6 @@ OneDim::OneDim(vector<shared_ptr<Domain1D>>& domains)
     resize();
 }
 
-OneDim::OneDim(vector<Domain1D*> domains)
-{
-    warn_deprecated("OneDim::OneDim(vector<Domain1D*>)",
-        "To be removed after Cantera 3.0; superseded by "
-        "OneDim::OneDim(vector<shared_ptr<Domain1D>>).");
-
-    // create a Newton iterator, and add each domain.
-    m_newt = make_unique<MultiNewton>(1);
-    m_state = make_shared<vector<double>>();
-    for (size_t i = 0; i < domains.size(); i++) {
-        addDomain(domains[i]);
-    }
-    init();
-    resize();
-}
-
 OneDim::~OneDim()
 {
 }
@@ -86,36 +70,6 @@ void OneDim::addDomain(shared_ptr<Domain1D> d)
         m_dom.back()->append(d.get());
     }
 
-    // every other domain is a connector
-    if (n % 2 == 0) {
-        m_sharedConnect.push_back(d);
-        m_connect.push_back(d.get());
-    } else {
-        m_sharedBulk.push_back(d);
-        m_bulk.push_back(d.get());
-    }
-
-    // add it also to the global domain list, and set its container and position
-    m_sharedDom.push_back(d);
-    m_dom.push_back(d.get());
-    d->setData(m_state);
-    d->setContainer(this, m_dom.size()-1);
-    resize();
-}
-
-void OneDim::addDomain(Domain1D* d)
-{
-    warn_deprecated("OneDim::addDomain(Domain1D*)",
-        "To be removed after Cantera 3.0; superseded by "
-        "OneDim::addDomain(shared_ptr<Domain1D>).");
-
-    // if 'd' is not the first domain, link it to the last domain
-    // added (the rightmost one)
-    size_t n = m_dom.size();
-    if (n > 0) {
-        m_dom.back()->append(d);
-    }
-
     // every other domain is a connector
     if (n % 2 == 0) {
         m_connect.push_back(d);
@@ -208,7 +162,7 @@ void OneDim::resize()
     saveStats();
     m_pts = 0;
     for (size_t i = 0; i < nDomains(); i++) {
-        Domain1D* d = m_dom[i];
+        const auto& d = m_dom[i];
 
         size_t np = d->nPoints();
         size_t nv = d->nComponents();
@@ -249,10 +203,6 @@ void OneDim::resize()
     // delete the current Jacobian evaluator and create a new one
     m_jac = make_unique<MultiJac>(*this);
     m_jac_ok = false;
-
-    for (size_t i = 0; i < nDomains(); i++) {
-        m_dom[i]->setJac(m_jac.get());
-    }
 }
 
 int OneDim::solve(double* x, double* xnew, int loglevel)
@@ -263,17 +213,16 @@ int OneDim::solve(double* x, double* xnew, int loglevel)
         m_jac->updateTransient(m_rdt, m_mask.data());
         m_jac_ok = true;
     }
-
     return m_newt->solve(x, xnew, *this, *m_jac, loglevel);
 }
 
-void OneDim::evalSSJacobian(double* x, double* xnew)
+void OneDim::evalSSJacobian(double* x, double* rsd)
 {
     double rdt_save = m_rdt;
     m_jac_ok = false;
     setSteadyMode();
-    eval(npos, x, xnew, 0.0, 0);
-    m_jac->eval(x, xnew, 0.0);
+    eval(npos, x, rsd, 0.0, 0);
+    m_jac->eval(x, rsd, 0.0);
     m_rdt = rdt_save;
 }
 
@@ -384,33 +333,44 @@ double OneDim::timeStep(int nsteps, double dt, double* x, double* r, int logleve
     // set the Jacobian age parameter to the transient value
     newton().setOptions(m_ts_jac_age);
 
-    debuglog("\n\n step    size (s)    log10(ss) \n", loglevel);
-    debuglog("===============================\n", loglevel);
-
     int n = 0;
     int successiveFailures = 0;
 
+    // Only output this if nothing else under this function call will be output
+    if (loglevel == 1) {
+        writelog("\n============================");
+        writelog("\n{:<5s}  {:<11s}   {:<7s}\n", "step", "dt (s)", "log(ss)");
+        writelog("============================");
+    }
     while (n < nsteps) {
-        if (loglevel > 0) {
+        if (loglevel == 1) { // At level 1, output concise information
             double ss = ssnorm(x, r);
-            writelog(" {:>4d}  {:10.4g}  {:10.4g}", n, dt, log10(ss));
+            writelog("\n{:<5d}  {:<6.4e}   {:>7.4f}", n, dt, log10(ss));
+        } else if (loglevel > 1) {
+            double ss = ssnorm(x, r);
+            writelog("\nTimestep ({}) dt= {:<11.4e}  log(ss)= {:<7.4f}", n, dt, log10(ss));
         }
 
         // set up for time stepping with stepsize dt
         initTimeInteg(dt,x);
 
+        int j0 = m_jac->nEvals(); // Store the current number of Jacobian evaluations
+
         // solve the transient problem
-        int m = solve(x, r, loglevel-1);
+        int status = solve(x, r, loglevel);
 
         // successful time step. Copy the new solution in r to
         // the current solution in x.
-        if (m >= 0) {
+        if (status >= 0) {
+            if (loglevel > 1) {
+                writelog("\nTimestep ({}) succeeded", n);
+            }
             successiveFailures = 0;
             m_nsteps++;
             n += 1;
-            debuglog("\n", loglevel);
             copy(r, r + m_size, x);
-            if (m == 100) {
+            // No Jacobian evaluations were performed, so a larger timestep can be used
+            if (m_jac->nEvals() == j0) {
                 dt *= 1.5;
             }
             if (m_time_step_callback) {
@@ -423,24 +383,40 @@ double OneDim::timeStep(int nsteps, double dt, double* x, double* r, int logleve
                     "reaching steady-state solution.", m_nsteps_max);
             }
         } else {
-            successiveFailures++;
             // No solution could be found with this time step.
             // Decrease the stepsize and try again.
-            debuglog("...failure.\n", loglevel);
+            successiveFailures++;
+            if (loglevel == 1) {
+                writelog("\nTimestep failed");
+            } else if (loglevel > 1) {
+                writelog("\nTimestep ({}) failed", n);
+            }
             if (successiveFailures > 2) {
-                //debuglog("Resetting negative species concentrations.\n", loglevel);
+                debuglog("--> Resetting negative species concentrations", loglevel);
                 resetBadValues(x);
                 successiveFailures = 0;
             } else {
+                debuglog("--> Reducing timestep", loglevel);
                 dt *= m_tfactor;
                 if (dt < m_tmin) {
-                    throw CanteraError("OneDim::timeStep",
-                                       "Time integration failed.");
+                    string err_msg = fmt::format(
+                        "Time integration failed. Minimum timestep ({}) reached.", m_tmin);
+                    throw CanteraError("OneDim::timeStep", err_msg);
                 }
             }
         }
     }
 
+    // Write the final step to the log
+    if (loglevel == 1) {
+        double ss = ssnorm(x, r);
+        writelog("\n{:<5d}  {:<6.4e}   {:>7.4f}", n, dt, log10(ss));
+        writelog("\n============================");
+    } else if (loglevel > 1) {
+        double ss = ssnorm(x, r);
+        writelog("\nTimestep ({}) dt= {:<11.4e} log10(ss)= {:<7.4f}\n", n, dt, log10(ss));
+    }
+
     // return the value of the last stepsize, which may be smaller
     // than the initial stepsize
     return dt;
@@ -453,15 +429,4 @@ void OneDim::resetBadValues(double* x)
     }
 }
 
-AnyMap OneDim::serialize(const double* soln) const
-{
-    warn_deprecated("OneDim::serialize",
-        "To be removed after Cantera 3.0; unused.");
-    AnyMap state;
-    for (size_t i = 0; i < m_dom.size(); i++) {
-        state[m_dom[i]->id()] = m_dom[i]->serialize(soln + start(i));
-    }
-    return state;
-}
-
 }
