@@ -7,7 +7,7 @@
 
 #include "cantera/oneD/Sim1D.h"
 #include "cantera/oneD/MultiJac.h"
-#include "cantera/oneD/StFlow.h"
+#include "cantera/oneD/Flow1D.h"
 #include "cantera/oneD/MultiNewton.h"
 #include "cantera/oneD/refine.h"
 #include "cantera/numerics/funcs.h"
@@ -38,26 +38,6 @@ Sim1D::Sim1D(vector<shared_ptr<Domain1D>>& domains) :
     m_steps = { 10 };
 }
 
-Sim1D::Sim1D(vector<Domain1D*>& domains) :
-    OneDim(domains),
-    m_steady_callback(0)
-{
-    warn_deprecated("Sim1D::Sim1D(vector<Domain1D*>&)",
-        "To be removed after Cantera 3.0; superseded by "
-        "Sim1D::Sim1D(vector<shared_ptr<Domain1D>>&).");
-
-    // resize the internal solution vector and the work array, and perform
-    // domain-specific initialization of the solution vector.
-    resize();
-    for (size_t n = 0; n < nDomains(); n++) {
-        domain(n)._getInitialSoln(m_state->data() + start(n));
-    }
-
-    // set some defaults
-    m_tstep = 1.0e-5;
-    m_steps = { 10 };
-}
-
 void Sim1D::setInitialGuess(const string& component, vector<double>& locs,
                             vector<double>& vals)
 {
@@ -115,17 +95,6 @@ void Sim1D::setProfile(size_t dom, size_t comp,
     }
 }
 
-void Sim1D::save(const string& fname, const string& id,
-                 const string& desc, int loglevel)
-{
-    warn_deprecated("Sim1D::save",
-        "To be removed after Cantera 3.0; use version without loglevel instead.");
-    save(fname, id, desc, true); // legacy version overwrites data
-    if (loglevel > 0) {
-        writelog("Solution saved to file '{}' as entry '{}'.\n", fname, id);
-    }
-}
-
 void Sim1D::save(const string& fname, const string& name, const string& desc,
                  bool overwrite, int compression, const string& basis)
 {
@@ -175,17 +144,6 @@ void Sim1D::save(const string& fname, const string& name, const string& desc,
     throw CanteraError("Sim1D::save", "Unsupported file format '{}'.", extension);
 }
 
-void Sim1D::saveResidual(const string& fname, const string& id,
-                         const string& desc, int loglevel)
-{
-    warn_deprecated("Sim1D::saveResidual",
-        "To be removed after Cantera 3.0; use version without loglevel instead.");
-    saveResidual(fname, id, desc, true); // legacy version overwrites data
-    if (loglevel > 0) {
-        writelog("Solution saved to file '{}' as entry '{}'.\n", fname, id);
-    }
-}
-
 void Sim1D::saveResidual(const string& fname, const string& name,
                          const string& desc, bool overwrite, int compression)
 {
@@ -245,7 +203,6 @@ AnyMap legacyH5(shared_ptr<SolutionArray> arr, const AnyMap& header={})
         {"radiation-enabled", "radiation_enabled"},
         {"energy-enabled", "energy_enabled"},
         {"Soret-enabled", "soret_enabled"},
-        {"species-enabled", "species_enabled"},
     };
     for (const auto& [newName, oldName] : header_pairs) {
         if (header.hasKey(oldName)) {
@@ -286,13 +243,6 @@ AnyMap legacyH5(shared_ptr<SolutionArray> arr, const AnyMap& header={})
 
 } // end unnamed namespace
 
-AnyMap Sim1D::restore(const string& fname, const string& id, int loglevel)
-{
-    warn_deprecated("Sim1D::saveResidual",
-        "To be removed after Cantera 3.0; use version without loglevel instead.");
-    return restore(fname, id);
-}
-
 AnyMap Sim1D::restore(const string& fname, const string& name)
 {
     size_t dot = fname.find_last_of(".");
@@ -378,22 +328,9 @@ void Sim1D::setFlatProfile(size_t dom, size_t comp, double v)
     }
 }
 
-void Sim1D::showSolution(ostream& s)
-{
-    warn_deprecated("Sim1D::showSolution",
-        "To be removed after Cantera 3.0; replaced by 'show'.");
-    show(s);
-}
-
-void Sim1D::showSolution()
-{
-    warn_deprecated("Sim1D::showSolution",
-        "To be removed after Cantera 3.0; replaced by 'show'.");
-    show();
-}
-
 void Sim1D::show(ostream& s)
 {
+    warn_deprecated("Sim1D::show(ostream&)", "To be removed after Cantera 3.1.");
     for (size_t n = 0; n < nDomains(); n++) {
         if (domain(n).type() != "empty") {
             domain(n).show(s, m_state->data() + start(n));
@@ -478,6 +415,13 @@ void Sim1D::solve(int loglevel, bool refine_grid)
     m_nsteps = 0;
     finalize();
 
+    // For debugging outputs
+    int attempt_counter = 0;
+    const int max_history = 10; // Store up to 10 previous solutions
+    if (loglevel > 6) {
+        clearDebugFile();
+    }
+
     while (new_points > 0) {
         size_t istep = 0;
         int nsteps = m_steps[istep];
@@ -487,15 +431,18 @@ void Sim1D::solve(int loglevel, bool refine_grid)
             writeline('.', 78, true, true);
         }
         while (!ok) {
+             // Keep the attempt_counter in the range of [1, max_history]
+             attempt_counter = (attempt_counter % max_history) + 1;
+
             // Attempt to solve the steady problem
             setSteadyMode();
             newton().setOptions(m_ss_jac_age);
-            debuglog("Attempt Newton solution of steady-state problem...", loglevel);
-            int status = newtonSolve(loglevel-1);
+            debuglog("\nAttempt Newton solution of steady-state problem.", loglevel);
+            int status = newtonSolve(loglevel);
 
             if (status == 0) {
                 if (loglevel > 0) {
-                    writelog("    success.\n\n");
+                    writelog("\nNewton steady-state solve succeeded.\n\n");
                     writelog("Problem solved on [");
                     for (size_t mm = 1; mm < nDomains(); mm+=2) {
                         writelog("{}", domain(mm).nPoints());
@@ -508,41 +455,27 @@ void Sim1D::solve(int loglevel, bool refine_grid)
                 if (m_steady_callback) {
                     m_steady_callback->eval(0);
                 }
+                writeDebugInfo("NewtonSuccess", "After successful Newton solve",
+                               loglevel, attempt_counter);
 
-                if (loglevel > 6) {
-                    save("debug_sim1d.yaml", "debug",
-                         "After successful Newton solve");
-                }
-                if (loglevel > 7) {
-                    saveResidual("debug_sim1d.yaml", "residual",
-                                 "After successful Newton solve");
-                }
                 ok = true;
             } else {
-                debuglog("    failure. \n", loglevel);
-                if (loglevel > 6) {
-                    save("debug_sim1d.yaml", "debug",
-                         "After unsuccessful Newton solve");
-                }
-                if (loglevel > 7) {
-                    saveResidual("debug_sim1d.yaml", "residual",
-                                 "After unsuccessful Newton solve");
-                }
+                debuglog("\nNewton steady-state solve failed.\n", loglevel);
+                writeDebugInfo("NewtonFail", "After unsuccessful Newton solve",
+                               loglevel, attempt_counter);
+
                 if (loglevel > 0) {
-                    writelog("Take {} timesteps   ", nsteps);
-                }
-                dt = timeStep(nsteps, dt, m_state->data(), m_xnew.data(), loglevel-1);
-                m_xlast_ts = *m_state;
-                if (loglevel > 6) {
-                    save("debug_sim1d.yaml", "debug", "After timestepping");
-                }
-                if (loglevel > 7) {
-                    saveResidual("debug_sim1d.yaml", "residual",
-                                 "After timestepping");
+                    writelog("\nAttempt {} timesteps.", nsteps);
                 }
 
+                dt = timeStep(nsteps, dt, m_state->data(), m_xnew.data(), loglevel-1);
+                m_xlast_ts = *m_state;
+                writeDebugInfo("Timestepping", "After timestepping", loglevel,
+                               attempt_counter);
+
+                // Repeat the last timestep's data for logging purposes
                 if (loglevel == 1) {
-                    writelog(" {:10.4g} {:10.4g}\n", dt,
+                    writelog("\nFinal timestep info: dt= {:<10.4g} log(ss)= {:<10.4g}\n", dt,
                              log10(ssnorm(m_state->data(), m_xnew.data())));
                 }
                 istep++;
@@ -557,7 +490,7 @@ void Sim1D::solve(int loglevel, bool refine_grid)
         if (loglevel > 0) {
             writeline('.', 78, true, true);
         }
-        if (loglevel > 2) {
+        if (loglevel > 3) {
             show();
         }
 
@@ -568,23 +501,27 @@ void Sim1D::solve(int loglevel, bool refine_grid)
                 // to avoid multiple successive failed time steps.
                 dt = m_tstep;
             }
-            if (new_points && loglevel > 6) {
-                save("debug_sim1d.yaml", "debug", "After regridding");
-            }
-            if (new_points && loglevel > 7) {
-                saveResidual("debug_sim1d.yaml", "residual",
-                             "After regridding");
-            }
+            writeDebugInfo("Regridding", "After regridding", loglevel, attempt_counter);
         } else {
             debuglog("grid refinement disabled.\n", loglevel);
             new_points = 0;
         }
     }
+    if (new_points < 0) {
+        // If the solver finished after removing grid points, do one final evaluation
+        // of the governing equations to update internal arrays in each domain that may
+        // be used for data saved in output files.
+        for (auto dom : m_dom) {
+            dom->eval(npos, m_state->data() + dom->loc(), m_xnew.data() + dom->loc(),
+                      m_mask.data());
+        }
+    }
 }
 
 int Sim1D::refine(int loglevel)
 {
-    int ianalyze, np = 0;
+    int added = 0;
+    int discarded = 0;
     vector<double> znew, xnew;
     vector<size_t> dsize;
 
@@ -599,17 +536,13 @@ int Sim1D::refine(int loglevel)
         m_grid_last_ss.push_back(d.grid());
 
         // determine where new points are needed
-        ianalyze = r.analyze(d.grid().size(), d.grid().data(),
-                             m_state->data() + start(n));
-        if (ianalyze < 0) {
-            return ianalyze;
-        }
+        r.analyze(d.grid().size(), d.grid().data(), m_state->data() + start(n));
 
         if (loglevel > 0) {
             r.show();
         }
 
-        np += r.nNewPoints();
+        added += r.nNewPoints();
         size_t comp = d.nComponents();
 
         // loop over points in the current grid
@@ -618,7 +551,7 @@ int Sim1D::refine(int loglevel)
         for (size_t m = 0; m < npnow; m++) {
             if (r.keepPoint(m)) {
                 // add the current grid point to the new grid
-                znew.push_back(d.grid(m));
+                znew.push_back(d.z(m));
 
                 // do the same for the solution at this point
                 for (size_t i = 0; i < comp; i++) {
@@ -630,20 +563,21 @@ int Sim1D::refine(int loglevel)
                 // for this new point
                 if (r.newPointNeeded(m) && m + 1 < npnow) {
                     // add new point at midpoint
-                    double zmid = 0.5*(d.grid(m) + d.grid(m+1));
+                    double zmid = 0.5*(d.z(m) + d.z(m+1));
                     znew.push_back(zmid);
-                    np++;
+                    added++;
 
-                    // for each component, linearly interpolate
-                    // the solution to this point
+                    // for each component, linearly interpolate the solution to this
+                    // point
                     for (size_t i = 0; i < comp; i++) {
                         double xmid = 0.5*(value(n, i, m) + value(n, i, m+1));
                         xnew.push_back(xmid);
                     }
                 }
             } else {
+                discarded++;
                 if (loglevel > 0) {
-                    writelog("refine: discarding point at {}\n", d.grid(m));
+                    writelog("refine: discarding point at {}\n", d.z(m));
                 }
             }
         }
@@ -668,7 +602,26 @@ int Sim1D::refine(int loglevel)
     *m_state = xnew;
     resize();
     finalize();
-    return np;
+    return added || -discarded;
+}
+
+void Sim1D::clearDebugFile()
+{
+    std::filesystem::remove("debug_sim1d.yaml");
+}
+
+void Sim1D::writeDebugInfo(const string& header_suffix, const string& message,
+                           int loglevel, int attempt_counter)
+{
+    string file_header;
+    if (loglevel > 6) {
+        file_header = fmt::format("solution_{}_{}", attempt_counter, header_suffix);
+        save("debug_sim1d.yaml", file_header, message, true);
+    }
+    if (loglevel > 7) {
+        file_header = fmt::format("residual_{}_{}", attempt_counter, header_suffix);
+        saveResidual("debug_sim1d.yaml", file_header, message, true);
+    }
 }
 
 int Sim1D::setFixedTemperature(double t)
@@ -685,7 +638,7 @@ int Sim1D::setFixedTemperature(double t)
         size_t mfixed = npos;
 
         // loop over current grid to determine where new point is needed
-        StFlow* d_free = dynamic_cast<StFlow*>(&domain(n));
+        Flow1D* d_free = dynamic_cast<Flow1D*>(&domain(n));
         size_t npnow = d.nPoints();
         size_t nstart = znew.size();
         if (d_free && d_free->isFree()) {
@@ -695,8 +648,8 @@ int Sim1D::setFixedTemperature(double t)
                 double t2 = value(n, c_offset_T, m + 1);
                 // threshold to avoid adding new point too close to existing point
                 double thresh = min(1., 1.e-1 * (t2 - t1));
-                z1 = d.grid(m);
-                z2 = d.grid(m + 1);
+                z1 = d.z(m);
+                z2 = d.z(m + 1);
                 if (fabs(t - t1) <= thresh) {
                     zfixed = z1;
                     fixedpt = true;
@@ -720,7 +673,7 @@ int Sim1D::setFixedTemperature(double t)
         // copy solution domain and push back values
         for (size_t m = 0; m < npnow; m++) {
             // add the current grid point to the new grid
-            znew.push_back(d.grid(m));
+            znew.push_back(d.z(m));
 
             // do the same for the solution at this point
             for (size_t i = 0; i < comp; i++) {
@@ -765,7 +718,7 @@ double Sim1D::fixedTemperature()
 {
     double t_fixed = std::numeric_limits<double>::quiet_NaN();
     for (size_t n = 0; n < nDomains(); n++) {
-        StFlow* d = dynamic_cast<StFlow*>(&domain(n));
+        Flow1D* d = dynamic_cast<Flow1D*>(&domain(n));
         if (d && d->isFree() && d->m_tfixed > 0) {
             t_fixed = d->m_tfixed;
             break;
@@ -778,7 +731,7 @@ double Sim1D::fixedTemperatureLocation()
 {
     double z_fixed = std::numeric_limits<double>::quiet_NaN();
     for (size_t n = 0; n < nDomains(); n++) {
-        StFlow* d = dynamic_cast<StFlow*>(&domain(n));
+        Flow1D* d = dynamic_cast<Flow1D*>(&domain(n));
         if (d && d->isFree() && d->m_tfixed > 0) {
             z_fixed = d->m_zfixed;
             break;
@@ -787,6 +740,109 @@ double Sim1D::fixedTemperatureLocation()
     return z_fixed;
 }
 
+void Sim1D::setLeftControlPoint(double temperature)
+{
+    bool two_point_domain_found = false;
+    for (size_t n = 0; n < nDomains(); n++) {
+        Domain1D& d = domain(n);
+
+        // Skip if the domain type doesn't match
+        if (d.domainType() != "axisymmetric-flow") {
+            continue;
+        }
+
+        Flow1D& d_axis = dynamic_cast<Flow1D&>(domain(n));
+        size_t np = d_axis.nPoints();
+
+        // Skip if two-point control is not enabled
+        if (!d_axis.twoPointControlEnabled()) {
+            continue;
+        }
+        two_point_domain_found = true;
+
+        double current_val, next_val;
+        for (size_t m = 0; m < np-1; m++) {
+            current_val = value(n,c_offset_T,m);
+            next_val = value(n,c_offset_T,m+1);
+            if ((current_val - temperature) * (next_val - temperature) < 0.0) {
+                // Pick the coordinate of the point with the temperature closest
+                // to the desired temperature
+                size_t index = 0;
+                if (std::abs(current_val - temperature) <
+                    std::abs(next_val - temperature)) {
+                    index = m;
+                } else {
+                    index = m+1;
+                }
+                d_axis.setLeftControlPointCoordinate(d_axis.z(index));
+                d_axis.setLeftControlPointTemperature(value(n,c_offset_T,index));
+                return;
+            }
+        }
+    }
+
+    if (!two_point_domain_found) {
+        throw CanteraError("Sim1D::setLeftControlPoint",
+            "No domain with two-point control enabled was found.");
+    } else {
+        throw CanteraError("Sim1D::setLeftControlPoint",
+            "No control point with temperature {} was able to be found in the"
+            "flame's temperature range.", temperature);
+    }
+}
+
+void Sim1D::setRightControlPoint(double temperature)
+{
+    bool two_point_domain_found = false;
+    for (size_t n = 0; n < nDomains(); n++) {
+        Domain1D& d = domain(n);
+
+        // Skip if the domain type doesn't match
+        if (d.domainType() != "axisymmetric-flow") {
+            continue;
+        }
+
+        Flow1D& d_axis = dynamic_cast<Flow1D&>(domain(n));
+        size_t np = d_axis.nPoints();
+
+        // Skip if two-point control is not enabled
+        if (!d_axis.twoPointControlEnabled()) {
+            continue;
+        }
+        two_point_domain_found = true;
+
+        double current_val, next_val;
+        for (size_t m = np-1; m > 0; m--) {
+            current_val = value(n,c_offset_T,m);
+            next_val = value(n,c_offset_T,m-1);
+            if ((current_val - temperature) * (next_val - temperature) < 0.0) {
+                // Pick the coordinate of the point with the temperature closest
+                // to the desired temperature
+                size_t index = 0;
+                if (std::abs(current_val - temperature) <
+                    std::abs(next_val - temperature)) {
+                    index = m;
+                } else {
+                    index = m-1;
+                }
+                d_axis.setRightControlPointCoordinate(d_axis.z(index));
+                d_axis.setRightControlPointTemperature(value(n,c_offset_T,index));
+                return;
+            }
+        }
+    }
+
+    if (!two_point_domain_found) {
+        throw CanteraError("Sim1D::setRightControlPoint",
+            "No domain with two-point control enabled was found.");
+    } else {
+        throw CanteraError("Sim1D::setRightControlPoint",
+            "No control point with temperature {} was able to be found in the"
+            "flame's temperature range.", temperature);
+    }
+
+}
+
 void Sim1D::setRefineCriteria(int dom, double ratio,
                               double slope, double curve, double prune)
 {
