@@ -1,8 +1,8 @@
 /**
  *  @file IdealMolalSoln.cpp
  *   ThermoPhase object for the ideal molal equation of
- * state (see \ref thermoprops
- * and class \link Cantera::IdealMolalSoln IdealMolalSoln\endlink).
+ * state (see @ref thermoprops
+ * and class @link Cantera::IdealMolalSoln IdealMolalSoln@endlink).
  *
  * Definition file for a derived class of ThermoPhase that handles variable
  * pressure standard state methods for calculating thermodynamic properties that
@@ -17,104 +17,59 @@
 
 #include "cantera/thermo/IdealMolalSoln.h"
 #include "cantera/thermo/ThermoFactory.h"
-#include "cantera/base/ctml.h"
+#include "cantera/thermo/PDSS.h"
 #include "cantera/base/stringUtils.h"
 
 #include <iostream>
 
+namespace {
+double X_o_cutoff_default = 0.20;
+double gamma_o_min_default = 0.00001;
+double gamma_k_min_default = 10.0;
+double slopefCut_default = 0.6;
+double slopegCut_default = 0.0;
+double cCut_default = .05;
+}
+
 namespace Cantera
 {
 
-IdealMolalSoln::IdealMolalSoln() :
-    m_formGC(2),
-    IMS_typeCutoff_(0),
-    IMS_X_o_cutoff_(0.20),
-    IMS_gamma_o_min_(0.00001),
-    IMS_gamma_k_min_(10.0),
-    IMS_slopefCut_(0.6),
-    IMS_slopegCut_(0.0),
-    IMS_cCut_(.05),
-    IMS_dfCut_(0.0),
-    IMS_efCut_(0.0),
-    IMS_afCut_(0.0),
-    IMS_bfCut_(0.0),
-    IMS_dgCut_(0.0),
-    IMS_egCut_(0.0),
-    IMS_agCut_(0.0),
-    IMS_bgCut_(0.0)
-{
-}
-
-IdealMolalSoln::IdealMolalSoln(const std::string& inputFile,
-                               const std::string& id_) :
-    MolalityVPSSTP(),
-    m_formGC(2),
-    IMS_typeCutoff_(0),
-    IMS_X_o_cutoff_(0.2),
-    IMS_gamma_o_min_(0.00001),
-    IMS_gamma_k_min_(10.0),
-    IMS_slopefCut_(0.6),
-    IMS_slopegCut_(0.0),
-    IMS_cCut_(.05),
-    IMS_dfCut_(0.0),
-    IMS_efCut_(0.0),
-    IMS_afCut_(0.0),
-    IMS_bfCut_(0.0),
-    IMS_dgCut_(0.0),
-    IMS_egCut_(0.0),
-    IMS_agCut_(0.0),
-    IMS_bgCut_(0.0)
+IdealMolalSoln::IdealMolalSoln(const string& inputFile, const string& id_) :
+    IMS_X_o_cutoff_(X_o_cutoff_default),
+    IMS_gamma_o_min_(gamma_o_min_default),
+    IMS_gamma_k_min_(gamma_k_min_default),
+    IMS_slopefCut_(slopefCut_default),
+    IMS_slopegCut_(slopegCut_default),
+    IMS_cCut_(cCut_default)
 {
     initThermoFile(inputFile, id_);
 }
 
-IdealMolalSoln::IdealMolalSoln(XML_Node& root, const std::string& id_) :
-    MolalityVPSSTP(),
-    m_formGC(2),
-    IMS_typeCutoff_(0),
-    IMS_X_o_cutoff_(0.2),
-    IMS_gamma_o_min_(0.00001),
-    IMS_gamma_k_min_(10.0),
-    IMS_slopefCut_(0.6),
-    IMS_slopegCut_(0.0),
-    IMS_cCut_(.05),
-    IMS_dfCut_(0.0),
-    IMS_efCut_(0.0),
-    IMS_afCut_(0.0),
-    IMS_bfCut_(0.0),
-    IMS_dgCut_(0.0),
-    IMS_egCut_(0.0),
-    IMS_agCut_(0.0),
-    IMS_bgCut_(0.0)
-{
-    importPhase(root, this);
-}
-
-doublereal IdealMolalSoln::enthalpy_mole() const
+double IdealMolalSoln::enthalpy_mole() const
 {
     getPartialMolarEnthalpies(m_tmpV.data());
     return mean_X(m_tmpV);
 }
 
-doublereal IdealMolalSoln::intEnergy_mole() const
+double IdealMolalSoln::intEnergy_mole() const
 {
-    getPartialMolarEnthalpies(m_tmpV.data());
+    getPartialMolarIntEnergies(m_tmpV.data());
     return mean_X(m_tmpV);
 }
 
-doublereal IdealMolalSoln::entropy_mole() const
+double IdealMolalSoln::entropy_mole() const
 {
     getPartialMolarEntropies(m_tmpV.data());
     return mean_X(m_tmpV);
 }
 
-doublereal IdealMolalSoln::gibbs_mole() const
+double IdealMolalSoln::gibbs_mole() const
 {
     getChemPotentials(m_tmpV.data());
     return mean_X(m_tmpV);
 }
 
-doublereal IdealMolalSoln::cp_mole() const
+double IdealMolalSoln::cp_mole() const
 {
     getPartialMolarCp(m_tmpV.data());
     return mean_X(m_tmpV);
@@ -125,42 +80,20 @@ doublereal IdealMolalSoln::cp_mole() const
 void IdealMolalSoln::calcDensity()
 {
     getPartialMolarVolumes(m_tmpV.data());
-    doublereal dd = meanMolecularWeight() / mean_X(m_tmpV);
+    double dd = meanMolecularWeight() / mean_X(m_tmpV);
     Phase::assignDensity(dd);
 }
 
-doublereal IdealMolalSoln::isothermalCompressibility() const
+double IdealMolalSoln::isothermalCompressibility() const
 {
     return 0.0;
 }
 
-doublereal IdealMolalSoln::thermalExpansionCoeff() const
+double IdealMolalSoln::thermalExpansionCoeff() const
 {
     return 0.0;
 }
 
-void IdealMolalSoln::setDensity(const doublereal rho)
-{
-    warn_deprecated("IdealMolalSoln::setDensity",
-        "Overloaded function to be removed after Cantera 2.5. "
-        "Error will be thrown by Phase::setDensity instead");
-    if (rho != density()) {
-        throw CanteraError("IdealMolalSoln::setDensity",
-                           "Density is not an independent variable");
-    }
-}
-
-void IdealMolalSoln::setMolarDensity(const doublereal conc)
-{
-    warn_deprecated("IdealMolalSoln::setMolarDensity",
-        "Overloaded function to be removed after Cantera 2.5. "
-        "Error will be thrown by Phase::setMolarDensity instead");
-    if (conc != Phase::molarDensity()) {
-        throw CanteraError("IdealMolalSoln::setMolarDensity",
-                           "molarDensity/density is not an independent variable");
-    }
-}
-
 // ------- Activities and Activity Concentrations
 
 Units IdealMolalSoln::standardConcentrationUnits() const
@@ -173,7 +106,7 @@ Units IdealMolalSoln::standardConcentrationUnits() const
     }
 }
 
-void IdealMolalSoln::getActivityConcentrations(doublereal* c) const
+void IdealMolalSoln::getActivityConcentrations(double* c) const
 {
     if (m_formGC != 1) {
         double c_solvent = standardConcentration();
@@ -190,7 +123,7 @@ void IdealMolalSoln::getActivityConcentrations(doublereal* c) const
     }
 }
 
-doublereal IdealMolalSoln::standardConcentration(size_t k) const
+double IdealMolalSoln::standardConcentration(size_t k) const
 {
     switch (m_formGC) {
     case 0:
@@ -206,7 +139,7 @@ doublereal IdealMolalSoln::standardConcentration(size_t k) const
     }
 }
 
-void IdealMolalSoln::getActivities(doublereal* ac) const
+void IdealMolalSoln::getActivities(double* ac) const
 {
     _updateStandardStateThermo();
 
@@ -235,7 +168,7 @@ void IdealMolalSoln::getActivities(doublereal* ac) const
     }
 }
 
-void IdealMolalSoln::getMolalityActivityCoefficients(doublereal* acMolality) const
+void IdealMolalSoln::getMolalityActivityCoefficients(double* acMolality) const
 {
     if (IMS_typeCutoff_ == 0) {
         for (size_t k = 0; k < m_kk; k++) {
@@ -257,7 +190,7 @@ void IdealMolalSoln::getMolalityActivityCoefficients(doublereal* acMolality) con
 
 // ------ Partial Molar Properties of the Solution -----------------
 
-void IdealMolalSoln::getChemPotentials(doublereal* mu) const
+void IdealMolalSoln::getChemPotentials(double* mu) const
 {
     // First get the standard chemical potentials. This requires updates of
     // standard state as a function of T and P These are defined at unit
@@ -295,7 +228,7 @@ void IdealMolalSoln::getChemPotentials(doublereal* mu) const
     }
 }
 
-void IdealMolalSoln::getPartialMolarEnthalpies(doublereal* hbar) const
+void IdealMolalSoln::getPartialMolarEnthalpies(double* hbar) const
 {
     getEnthalpy_RT(hbar);
     for (size_t k = 0; k < m_kk; k++) {
@@ -303,13 +236,21 @@ void IdealMolalSoln::getPartialMolarEnthalpies(doublereal* hbar) const
     }
 }
 
-void IdealMolalSoln::getPartialMolarEntropies(doublereal* sbar) const
+void IdealMolalSoln::getPartialMolarIntEnergies(double* ubar) const
+{
+    getIntEnergy_RT(ubar);
+    for (size_t k = 0; k < m_kk; k++) {
+        ubar[k] *= RT();
+    }
+}
+
+void IdealMolalSoln::getPartialMolarEntropies(double* sbar) const
 {
     getEntropy_R(sbar);
     calcMolalities();
     if (IMS_typeCutoff_ == 0) {
         for (size_t k = 1; k < m_kk; k++) {
-            doublereal mm = std::max(SmallNumber, m_molalities[k]);
+            double mm = std::max(SmallNumber, m_molalities[k]);
             sbar[k] -= GasConstant * log(mm);
         }
         double xmolSolvent = moleFraction(0);
@@ -321,7 +262,7 @@ void IdealMolalSoln::getPartialMolarEntropies(doublereal* sbar) const
 
         // First we will add in the obvious dependence on the T term out front
         // of the log activity term
-        doublereal mm;
+        double mm;
         for (size_t k = 1; k < m_kk; k++) {
             mm = std::max(SmallNumber, m_molalities[k]);
             sbar[k] -= GasConstant * (log(mm) + IMS_lnActCoeffMolal_[k]);
@@ -332,12 +273,12 @@ void IdealMolalSoln::getPartialMolarEntropies(doublereal* sbar) const
     }
 }
 
-void IdealMolalSoln::getPartialMolarVolumes(doublereal* vbar) const
+void IdealMolalSoln::getPartialMolarVolumes(double* vbar) const
 {
     getStandardVolumes(vbar);
 }
 
-void IdealMolalSoln::getPartialMolarCp(doublereal* cpbar) const
+void IdealMolalSoln::getPartialMolarCp(double* cpbar) const
 {
     // Get the nondimensional Gibbs standard state of the species at the T and P
     // of the solution.
@@ -360,65 +301,6 @@ bool IdealMolalSoln::addSpecies(shared_ptr<Species> spec)
     return added;
 }
 
-void IdealMolalSoln::initThermoXML(XML_Node& phaseNode, const std::string& id_)
-{
-    MolalityVPSSTP::initThermoXML(phaseNode, id_);
-
-    if (id_.size() > 0 && phaseNode.id() != id_) {
-        throw CanteraError("IdealMolalSoln::initThermoXML",
-                           "phasenode and Id are incompatible");
-    }
-
-    // Find the Thermo XML node
-    if (!phaseNode.hasChild("thermo")) {
-        throw CanteraError("IdealMolalSoln::initThermoXML",
-                           "no thermo XML node");
-    }
-    XML_Node& thermoNode = phaseNode.child("thermo");
-
-    // Possible change the form of the standard concentrations
-    if (thermoNode.hasChild("standardConc")) {
-        XML_Node& scNode = thermoNode.child("standardConc");
-        setStandardConcentrationModel(scNode["model"]);
-    }
-
-    if (thermoNode.hasChild("activityCoefficients")) {
-        XML_Node& acNode = thermoNode.child("activityCoefficients");
-        std::string modelString = acNode.attrib("model");
-        if (modelString != "IdealMolalSoln") {
-            throw CanteraError("IdealMolalSoln::initThermoXML",
-                               "unknown ActivityCoefficient model: " + modelString);
-        }
-        if (acNode.hasChild("idealMolalSolnCutoff")) {
-            XML_Node& ccNode = acNode.child("idealMolalSolnCutoff");
-            modelString = ccNode.attrib("model");
-            if (modelString != "") {
-                setCutoffModel(modelString);
-                if (ccNode.hasChild("gamma_o_limit")) {
-                    IMS_gamma_o_min_ = getFloat(ccNode, "gamma_o_limit");
-                }
-                if (ccNode.hasChild("gamma_k_limit")) {
-                    IMS_gamma_k_min_ = getFloat(ccNode, "gamma_k_limit");
-                }
-                if (ccNode.hasChild("X_o_cutoff")) {
-                    IMS_X_o_cutoff_ = getFloat(ccNode, "X_o_cutoff");
-                }
-                if (ccNode.hasChild("c_0_param")) {
-                    IMS_cCut_ = getFloat(ccNode, "c_0_param");
-                }
-                if (ccNode.hasChild("slope_f_limit")) {
-                    IMS_slopefCut_ = getFloat(ccNode, "slope_f_limit");
-                }
-                if (ccNode.hasChild("slope_g_limit")) {
-                    IMS_slopegCut_ = getFloat(ccNode, "slope_g_limit");
-                }
-            }
-        } else {
-            setCutoffModel("none");
-        }
-    }
-}
-
 void IdealMolalSoln::initThermo()
 {
     MolalityVPSSTP::initThermo();
@@ -429,24 +311,12 @@ void IdealMolalSoln::initThermo()
     if (m_input.hasKey("cutoff")) {
         auto& cutoff = m_input["cutoff"].as<AnyMap>();
         setCutoffModel(cutoff.getString("model", "none"));
-        if (cutoff.hasKey("gamma_o")) {
-            IMS_gamma_o_min_ = cutoff["gamma_o"].asDouble();
-        }
-        if (cutoff.hasKey("gamma_k")) {
-            IMS_gamma_k_min_ = cutoff["gamma_k"].asDouble();
-        }
-        if (cutoff.hasKey("X_o")) {
-            IMS_X_o_cutoff_ = cutoff["X_o"].asDouble();
-        }
-        if (cutoff.hasKey("c_0")) {
-            IMS_cCut_ = cutoff["c_0"].asDouble();
-        }
-        if (cutoff.hasKey("slope_f")) {
-            IMS_slopefCut_ = cutoff["slope_f"].asDouble();
-        }
-        if (cutoff.hasKey("slope_g")) {
-            IMS_slopegCut_ = cutoff["slope_g"].asDouble();
-        }
+        IMS_gamma_o_min_ = cutoff.getDouble("gamma_o", gamma_o_min_default);
+        IMS_gamma_k_min_ = cutoff.getDouble("gamma_k", gamma_k_min_default);
+        IMS_X_o_cutoff_ = cutoff.getDouble("X_o", X_o_cutoff_default);
+        IMS_cCut_ = cutoff.getDouble("c_0", cCut_default);
+        IMS_slopefCut_ = cutoff.getDouble("slope_f", slopefCut_default);
+        IMS_slopegCut_ = cutoff.getDouble("slope_g", slopegCut_default);
     }
 
     for (size_t k = 0; k < nSpecies(); k++) {
@@ -458,7 +328,49 @@ void IdealMolalSoln::initThermo()
     setMoleFSolventMin(1.0E-5);
 }
 
-void IdealMolalSoln::setStandardConcentrationModel(const std::string& model)
+void IdealMolalSoln::getParameters(AnyMap& phaseNode) const
+{
+    MolalityVPSSTP::getParameters(phaseNode);
+
+    // "solvent-molar-volume" (m_formGC == 2) is the default, and can be omitted
+    if (m_formGC == 0) {
+        phaseNode["standard-concentration-basis"] = "unity";
+    } else if (m_formGC == 1) {
+        phaseNode["standard-concentration-basis"] = "species-molar-volume";
+    }
+
+    AnyMap cutoff;
+    if (IMS_typeCutoff_ == 1) {
+        cutoff["model"] = "poly";
+    } else if (IMS_typeCutoff_ == 2) {
+        cutoff["model"] = "polyexp";
+    }
+
+    if (IMS_gamma_o_min_ != gamma_o_min_default) {
+        cutoff["gamma_o"] = IMS_gamma_o_min_;
+    }
+    if (IMS_gamma_k_min_ != gamma_k_min_default) {
+        cutoff["gamma_k"] = IMS_gamma_k_min_;
+    }
+    if (IMS_X_o_cutoff_ != X_o_cutoff_default) {
+        cutoff["X_o"] = IMS_X_o_cutoff_;
+    }
+    if (IMS_cCut_ != cCut_default) {
+        cutoff["c_0"] = IMS_cCut_;
+    }
+    if (IMS_slopefCut_ != slopefCut_default) {
+        cutoff["slope_f"] = IMS_slopefCut_;
+    }
+    if (IMS_slopegCut_ != slopegCut_default) {
+        cutoff["slope_g"] = IMS_slopegCut_;
+    }
+
+    if (cutoff.size()) {
+        phaseNode["cutoff"] = std::move(cutoff);
+    }
+}
+
+void IdealMolalSoln::setStandardConcentrationModel(const string& model)
 {
     if (caseInsensitiveEquals(model, "unity")) {
         m_formGC = 0;
@@ -474,7 +386,7 @@ void IdealMolalSoln::setStandardConcentrationModel(const std::string& model)
     }
 }
 
-void IdealMolalSoln::setCutoffModel(const std::string& model)
+void IdealMolalSoln::setCutoffModel(const string& model)
 {
     if (caseInsensitiveEquals(model, "none")) {
         IMS_typeCutoff_ = 0;
