@@ -2,8 +2,8 @@
  *  @file MargulesVPSSTP.cpp
  *   Definitions for ThermoPhase object for phases which
  *   employ excess Gibbs free energy formulations related to Margules
- *   expansions (see \ref thermoprops
- *    and class \link Cantera::MargulesVPSSTP MargulesVPSSTP\endlink).
+ *   expansions (see @ref thermoprops
+ *    and class @link Cantera::MargulesVPSSTP MargulesVPSSTP@endlink).
  */
 
 // This file is part of Cantera. See License.txt in the top-level directory or
@@ -12,38 +12,17 @@
 #include "cantera/thermo/MargulesVPSSTP.h"
 #include "cantera/thermo/ThermoFactory.h"
 #include "cantera/base/stringUtils.h"
-#include "cantera/base/ctml.h"
-
-using namespace std;
 
 namespace Cantera
 {
-MargulesVPSSTP::MargulesVPSSTP() :
-    numBinaryInteractions_(0),
-    formMargules_(0),
-    formTempModel_(0)
-{
-}
-
-MargulesVPSSTP::MargulesVPSSTP(const std::string& inputFile, const std::string& id_) :
-    numBinaryInteractions_(0),
-    formMargules_(0),
-    formTempModel_(0)
+MargulesVPSSTP::MargulesVPSSTP(const string& inputFile, const string& id_)
 {
     initThermoFile(inputFile, id_);
 }
 
-MargulesVPSSTP::MargulesVPSSTP(XML_Node& phaseRoot, const std::string& id_) :
-    numBinaryInteractions_(0),
-    formMargules_(0),
-    formTempModel_(0)
-{
-    importPhase(phaseRoot, this);
-}
-
 // -- Activities, Standard States, Activity Concentrations -----------
 
-void MargulesVPSSTP::getLnActivityCoefficients(doublereal* lnac) const
+void MargulesVPSSTP::getLnActivityCoefficients(double* lnac) const
 {
     // Update the activity coefficients
     s_update_lnActCoeff();
@@ -56,7 +35,7 @@ void MargulesVPSSTP::getLnActivityCoefficients(doublereal* lnac) const
 
 // ------------ Partial Molar Properties of the Solution ------------
 
-void MargulesVPSSTP::getChemPotentials(doublereal* mu) const
+void MargulesVPSSTP::getChemPotentials(double* mu) const
 {
     // First get the standard chemical potentials in molar form. This requires
     // updates of standard state as a function of T and P
@@ -70,11 +49,11 @@ void MargulesVPSSTP::getChemPotentials(doublereal* mu) const
     }
 }
 
-doublereal MargulesVPSSTP::enthalpy_mole() const
+double MargulesVPSSTP::enthalpy_mole() const
 {
     size_t kk = nSpecies();
     double h = 0;
-    vector_fp hbar(kk);
+    vector<double> hbar(kk);
     getPartialMolarEnthalpies(&hbar[0]);
     for (size_t i = 0; i < kk; i++) {
         h += moleFractions_[i]*hbar[i];
@@ -82,11 +61,11 @@ doublereal MargulesVPSSTP::enthalpy_mole() const
     return h;
 }
 
-doublereal MargulesVPSSTP::entropy_mole() const
+double MargulesVPSSTP::entropy_mole() const
 {
     size_t kk = nSpecies();
     double s = 0;
-    vector_fp sbar(kk);
+    vector<double> sbar(kk);
     getPartialMolarEntropies(&sbar[0]);
     for (size_t i = 0; i < kk; i++) {
         s += moleFractions_[i]*sbar[i];
@@ -94,11 +73,11 @@ doublereal MargulesVPSSTP::entropy_mole() const
     return s;
 }
 
-doublereal MargulesVPSSTP::cp_mole() const
+double MargulesVPSSTP::cp_mole() const
 {
     size_t kk = nSpecies();
     double cp = 0;
-    vector_fp cpbar(kk);
+    vector<double> cpbar(kk);
     getPartialMolarCp(&cpbar[0]);
     for (size_t i = 0; i < kk; i++) {
         cp += moleFractions_[i]*cpbar[i];
@@ -106,12 +85,12 @@ doublereal MargulesVPSSTP::cp_mole() const
     return cp;
 }
 
-doublereal MargulesVPSSTP::cv_mole() const
+double MargulesVPSSTP::cv_mole() const
 {
     return cp_mole() - GasConstant;
 }
 
-void MargulesVPSSTP::getPartialMolarEnthalpies(doublereal* hbar) const
+void MargulesVPSSTP::getPartialMolarEnthalpies(double* hbar) const
 {
     // Get the nondimensional standard state enthalpies
     getEnthalpy_RT(hbar);
@@ -130,7 +109,7 @@ void MargulesVPSSTP::getPartialMolarEnthalpies(doublereal* hbar) const
     }
 }
 
-void MargulesVPSSTP::getPartialMolarCp(doublereal* cpbar) const
+void MargulesVPSSTP::getPartialMolarCp(double* cpbar) const
 {
     // Get the nondimensional standard state entropies
     getCp_R(cpbar);
@@ -150,7 +129,7 @@ void MargulesVPSSTP::getPartialMolarCp(doublereal* cpbar) const
     }
 }
 
-void MargulesVPSSTP::getPartialMolarEntropies(doublereal* sbar) const
+void MargulesVPSSTP::getPartialMolarEntropies(double* sbar) const
 {
     // Get the nondimensional standard state entropies
     getEntropy_R(sbar);
@@ -172,7 +151,7 @@ void MargulesVPSSTP::getPartialMolarEntropies(doublereal* sbar) const
     }
 }
 
-void MargulesVPSSTP::getPartialMolarVolumes(doublereal* vbar) const
+void MargulesVPSSTP::getPartialMolarVolumes(double* vbar) const
 {
     double T = temperature();
 
@@ -186,8 +165,8 @@ void MargulesVPSSTP::getPartialMolarVolumes(doublereal* vbar) const
         double XB = moleFractions_[iB];
         double g0 = (m_VHE_b_ij[i] - T * m_VSE_b_ij[i]);
         double g1 = (m_VHE_c_ij[i] - T * m_VSE_c_ij[i]);
-        const doublereal temp1 = g0 + g1 * XB;
-        const doublereal all = -1.0*XA*XB*temp1 - XA*XB*XB*g1;
+        const double temp1 = g0 + g1 * XB;
+        const double all = -1.0*XA*XB*temp1 - XA*XB*XB*g1;
 
         for (size_t iK = 0; iK < m_kk; iK++) {
             vbar[iK] += all;
@@ -203,7 +182,7 @@ void MargulesVPSSTP::initThermo()
     if (m_input.hasKey("interactions")) {
         for (auto& item : m_input["interactions"].asVector<AnyMap>()) {
             auto& species = item["species"].asVector<string>(2);
-            vector_fp h(2), s(2), vh(2), vs(2);
+            vector<double> h(2), s(2), vh(2), vs(2);
             if (item.hasKey("excess-enthalpy")) {
                 h = item.convertVector("excess-enthalpy", "J/kmol", 2);
             }
@@ -211,7 +190,7 @@ void MargulesVPSSTP::initThermo()
                 s = item.convertVector("excess-entropy", "J/kmol/K", 2);
             }
             if (item.hasKey("excess-volume-enthalpy")) {
-                vh = item.convertVector("excess-volume-enthalpy", "m^3/kmol/K", 2);
+                vh = item.convertVector("excess-volume-enthalpy", "m^3/kmol", 2);
             }
             if (item.hasKey("excess-volume-entropy")) {
                 vs = item.convertVector("excess-volume-entropy", "m^3/kmol/K", 2);
@@ -223,59 +202,42 @@ void MargulesVPSSTP::initThermo()
     GibbsExcessVPSSTP::initThermo();
 }
 
+void MargulesVPSSTP::getParameters(AnyMap& phaseNode) const
+{
+    GibbsExcessVPSSTP::getParameters(phaseNode);
+    vector<AnyMap> interactions;
+    for (size_t n = 0; n < m_pSpecies_A_ij.size(); n++) {
+        AnyMap interaction;
+        interaction["species"] = vector<string>{
+            speciesName(m_pSpecies_A_ij[n]), speciesName(m_pSpecies_B_ij[n])};
+        if (m_HE_b_ij[n] != 0 || m_HE_c_ij[n] != 0) {
+            interaction["excess-enthalpy"].setQuantity(
+                {m_HE_b_ij[n], m_HE_c_ij[n]}, "J/kmol");
+        }
+        if (m_SE_b_ij[n] != 0 || m_SE_c_ij[n] != 0) {
+            interaction["excess-entropy"].setQuantity(
+                {m_SE_b_ij[n], m_SE_c_ij[n]}, "J/kmol/K");
+        }
+        if (m_VHE_b_ij[n] != 0 || m_VHE_c_ij[n] != 0) {
+            interaction["excess-volume-enthalpy"].setQuantity(
+                {m_VHE_b_ij[n], m_VHE_c_ij[n]}, "m^3/kmol");
+        }
+        if (m_VSE_b_ij[n] != 0 || m_VSE_c_ij[n] != 0) {
+            interaction["excess-volume-entropy"].setQuantity(
+                {m_VSE_b_ij[n], m_VSE_c_ij[n]}, "m^3/kmol/K");
+        }
+        interactions.push_back(std::move(interaction));
+    }
+    phaseNode["interactions"] = std::move(interactions);
+}
+
 void MargulesVPSSTP::initLengths()
 {
     dlnActCoeffdlnN_.resize(m_kk, m_kk);
 }
 
-void MargulesVPSSTP::initThermoXML(XML_Node& phaseNode, const std::string& id_)
-{
-    if ((int) id_.size() > 0) {
-        string idp = phaseNode.id();
-        if (idp != id_) {
-            throw CanteraError("MargulesVPSSTP::initThermoXML", "phasenode and Id are incompatible");
-        }
-    }
-
-    // Find the Thermo XML node
-    if (!phaseNode.hasChild("thermo")) {
-        throw CanteraError("MargulesVPSSTP::initThermoXML",
-                           "no thermo XML node");
-    }
-    XML_Node& thermoNode = phaseNode.child("thermo");
-
-    // Make sure that the thermo model is Margules
-    if (!caseInsensitiveEquals(thermoNode["model"], "margules")) {
-        throw CanteraError("MargulesVPSSTP::initThermoXML",
-                           "model name isn't Margules: " + thermoNode["model"]);
-    }
-
-    // Go get all of the coefficients and factors in the activityCoefficients
-    // XML block
-    if (thermoNode.hasChild("activityCoefficients")) {
-        XML_Node& acNode = thermoNode.child("activityCoefficients");
-        if (!caseInsensitiveEquals(acNode["model"], "margules")) {
-            throw CanteraError("MargulesVPSSTP::initThermoXML",
-                               "Unknown activity coefficient model: " + acNode["model"]);
-        }
-        for (size_t i = 0; i < acNode.nChildren(); i++) {
-            XML_Node& xmlACChild = acNode.child(i);
-
-            // Process a binary salt field, or any of the other XML fields that
-            // make up the Pitzer Database. Entries will be ignored if any of
-            // the species in the entry isn't in the solution.
-            if (caseInsensitiveEquals(xmlACChild.name(), "binaryneutralspeciesparameters")) {
-                readXMLBinarySpecies(xmlACChild);
-            }
-        }
-    }
-
-    // Go down the chain
-    GibbsExcessVPSSTP::initThermoXML(phaseNode, id_);
-}
-
-void MargulesVPSSTP::addBinaryInteraction(const std::string& speciesA,
-    const std::string& speciesB, double h0, double h1, double s0, double s1,
+void MargulesVPSSTP::addBinaryInteraction(const string& speciesA,
+    const string& speciesB, double h0, double h1, double s0, double s1,
     double vh0, double vh1, double vs0, double vs1)
 {
     size_t kA = speciesIndex(speciesA);
@@ -311,9 +273,9 @@ void MargulesVPSSTP::s_update_lnActCoeff() const
         double g1 = (m_HE_c_ij[i] - T * m_SE_c_ij[i]) / RT();
         double XA = moleFractions_[iA];
         double XB = moleFractions_[iB];
-        const doublereal XAXB = XA * XB;
-        const doublereal g0g1XB = (g0 + g1 * XB);
-        const doublereal all = -1.0 * XAXB * g0g1XB - XAXB * XB * g1;
+        const double XAXB = XA * XB;
+        const double g0g1XB = (g0 + g1 * XB);
+        const double all = -1.0 * XAXB * g0g1XB - XAXB * XB * g1;
         for (size_t iK = 0; iK < m_kk; iK++) {
             lnActCoeff_Scaled_[iK] += all;
         }
@@ -324,8 +286,8 @@ void MargulesVPSSTP::s_update_lnActCoeff() const
 
 void MargulesVPSSTP::s_update_dlnActCoeff_dT() const
 {
-    doublereal invT = 1.0 / temperature();
-    doublereal invRTT = 1.0 / GasConstant*invT*invT;
+    double invT = 1.0 / temperature();
+    double invRTT = 1.0 / GasConstant*invT*invT;
     dlnActCoeffdT_Scaled_.assign(m_kk, 0.0);
     d2lnActCoeffdT2_Scaled_.assign(m_kk, 0.0);
     for (size_t i = 0; i < numBinaryInteractions_; i++) {
@@ -335,11 +297,11 @@ void MargulesVPSSTP::s_update_dlnActCoeff_dT() const
         double XB = moleFractions_[iB];
         double g0 = -m_HE_b_ij[i] * invRTT;
         double g1 = -m_HE_c_ij[i] * invRTT;
-        const doublereal XAXB = XA * XB;
-        const doublereal g0g1XB = (g0 + g1 * XB);
-        const doublereal all = -1.0 * XAXB * g0g1XB - XAXB * XB * g1;
-        const doublereal mult = 2.0 * invT;
-        const doublereal dT2all = mult * all;
+        const double XAXB = XA * XB;
+        const double g0g1XB = (g0 + g1 * XB);
+        const double all = -1.0 * XAXB * g0g1XB - XAXB * XB * g1;
+        const double mult = 2.0 * invT;
+        const double dT2all = mult * all;
         for (size_t iK = 0; iK < m_kk; iK++) {
             dlnActCoeffdT_Scaled_[iK] += all;
             d2lnActCoeffdT2_Scaled_[iK] -= dT2all;
@@ -351,7 +313,7 @@ void MargulesVPSSTP::s_update_dlnActCoeff_dT() const
     }
 }
 
-void MargulesVPSSTP::getdlnActCoeffdT(doublereal* dlnActCoeffdT) const
+void MargulesVPSSTP::getdlnActCoeffdT(double* dlnActCoeffdT) const
 {
     s_update_dlnActCoeff_dT();
     for (size_t k = 0; k < m_kk; k++) {
@@ -359,7 +321,7 @@ void MargulesVPSSTP::getdlnActCoeffdT(doublereal* dlnActCoeffdT) const
     }
 }
 
-void MargulesVPSSTP::getd2lnActCoeffdT2(doublereal* d2lnActCoeffdT2) const
+void MargulesVPSSTP::getd2lnActCoeffdT2(double* d2lnActCoeffdT2) const
 {
     s_update_dlnActCoeff_dT();
     for (size_t k = 0; k < m_kk; k++) {
@@ -367,8 +329,8 @@ void MargulesVPSSTP::getd2lnActCoeffdT2(doublereal* d2lnActCoeffdT2) const
     }
 }
 
-void MargulesVPSSTP::getdlnActCoeffds(const doublereal dTds, const doublereal* const dXds,
-                                       doublereal* dlnActCoeffds) const
+void MargulesVPSSTP::getdlnActCoeffds(const double dTds, const double* const dXds,
+                                       double* dlnActCoeffds) const
 {
     double T = temperature();
     s_update_dlnActCoeff_dT();
@@ -385,9 +347,9 @@ void MargulesVPSSTP::getdlnActCoeffds(const doublereal dTds, const doublereal* c
         double dXB = dXds[iB];
         double g0 = (m_HE_b_ij[i] - T * m_SE_b_ij[i]) / RT();
         double g1 = (m_HE_c_ij[i] - T * m_SE_c_ij[i]) / RT();
-        const doublereal g02g1XB = g0 + 2*g1*XB;
-        const doublereal g2XAdXB = 2*g1*XA*dXB;
-        const doublereal all = (-XB * dXA - XA *dXB) * g02g1XB - XB *g2XAdXB;
+        const double g02g1XB = g0 + 2*g1*XB;
+        const double g2XAdXB = 2*g1*XA*dXB;
+        const double all = (-XB * dXA - XA *dXB) * g02g1XB - XB *g2XAdXB;
         for (size_t iK = 0; iK < m_kk; iK++) {
             dlnActCoeffds[iK] += all + dlnActCoeffdT_Scaled_[iK]*dTds;
         }
@@ -469,25 +431,25 @@ void MargulesVPSSTP::s_update_dlnActCoeff_dlnN() const
 
 void MargulesVPSSTP::s_update_dlnActCoeff_dlnX_diag() const
 {
-    doublereal T = temperature();
+    double T = temperature();
     dlnActCoeffdlnX_diag_.assign(m_kk, 0.0);
 
     for (size_t i = 0; i < numBinaryInteractions_; i++) {
         size_t iA = m_pSpecies_A_ij[i];
         size_t iB = m_pSpecies_B_ij[i];
 
-        doublereal XA = moleFractions_[iA];
-        doublereal XB = moleFractions_[iB];
+        double XA = moleFractions_[iA];
+        double XB = moleFractions_[iB];
 
-        doublereal g0 = (m_HE_b_ij[i] - T * m_SE_b_ij[i]) / RT();
-        doublereal g1 = (m_HE_c_ij[i] - T * m_SE_c_ij[i]) / RT();
+        double g0 = (m_HE_b_ij[i] - T * m_SE_b_ij[i]) / RT();
+        double g1 = (m_HE_c_ij[i] - T * m_SE_c_ij[i]) / RT();
 
         dlnActCoeffdlnX_diag_[iA] += XA*XB*(2*g1*-2*g0-6*g1*XB);
         dlnActCoeffdlnX_diag_[iB] += XA*XB*(2*g1*-2*g0-6*g1*XB);
     }
 }
 
-void MargulesVPSSTP::getdlnActCoeffdlnN_diag(doublereal* dlnActCoeffdlnN_diag) const
+void MargulesVPSSTP::getdlnActCoeffdlnN_diag(double* dlnActCoeffdlnN_diag) const
 {
     s_update_dlnActCoeff_dlnN_diag();
     for (size_t k = 0; k < m_kk; k++) {
@@ -495,7 +457,7 @@ void MargulesVPSSTP::getdlnActCoeffdlnN_diag(doublereal* dlnActCoeffdlnN_diag) c
     }
 }
 
-void MargulesVPSSTP::getdlnActCoeffdlnX_diag(doublereal* dlnActCoeffdlnX_diag) const
+void MargulesVPSSTP::getdlnActCoeffdlnX_diag(double* dlnActCoeffdlnX_diag) const
 {
     s_update_dlnActCoeff_dlnX_diag();
     for (size_t k = 0; k < m_kk; k++) {
@@ -503,7 +465,7 @@ void MargulesVPSSTP::getdlnActCoeffdlnX_diag(doublereal* dlnActCoeffdlnX_diag) c
     }
 }
 
-void MargulesVPSSTP::getdlnActCoeffdlnN(const size_t ld, doublereal* dlnActCoeffdlnN)
+void MargulesVPSSTP::getdlnActCoeffdlnN(const size_t ld, double* dlnActCoeffdlnN)
 {
     s_update_dlnActCoeff_dlnN();
     double* data =  & dlnActCoeffdlnN_(0,0);
@@ -514,87 +476,4 @@ void MargulesVPSSTP::getdlnActCoeffdlnN(const size_t ld, doublereal* dlnActCoeff
     }
 }
 
-void MargulesVPSSTP::readXMLBinarySpecies(XML_Node& xmLBinarySpecies)
-{
-    string xname = xmLBinarySpecies.name();
-    if (xname != "binaryNeutralSpeciesParameters") {
-        throw CanteraError("MargulesVPSSTP::readXMLBinarySpecies",
-                           "Incorrect name for processing this routine: " + xname);
-    }
-    string aName = xmLBinarySpecies.attrib("speciesA");
-    if (aName == "") {
-        throw CanteraError("MargulesVPSSTP::readXMLBinarySpecies", "no speciesA attrib");
-    }
-    string bName = xmLBinarySpecies.attrib("speciesB");
-    if (bName == "") {
-        throw CanteraError("MargulesVPSSTP::readXMLBinarySpecies", "no speciesB attrib");
-    }
-
-    vector_fp vParams;
-    double h0 = 0.0;
-    double h1 = 0.0;
-    double s0 = 0.0;
-    double s1 = 0.0;
-    double vh0 = 0.0;
-    double vh1 = 0.0;
-    double vs0 = 0.0;
-    double vs1 = 0.0;
-
-    for (size_t iChild = 0; iChild < xmLBinarySpecies.nChildren(); iChild++) {
-        XML_Node& xmlChild = xmLBinarySpecies.child(iChild);
-        string nodeName = toLowerCopy(xmlChild.name());
-
-        // Process the binary species interaction parameters.
-        // They are in subblocks labeled:
-        //           excessEnthalpy
-        //           excessEntropy
-        //           excessVolume_Enthalpy
-        //           excessVolume_Entropy
-        // Other blocks are currently ignored.
-        // @TODO determine a policy about ignoring blocks that should or shouldn't be there.
-        if (nodeName == "excessenthalpy") {
-            // Get the string containing all of the values
-            getFloatArray(xmlChild, vParams, true, "toSI", "excessEnthalpy");
-            if (vParams.size() != 2) {
-                throw CanteraError("MargulesVPSSTP::readXMLBinarySpecies"
-                    "excessEnthalpy for {} : {}: wrong number of params found."
-                    " Need 2", aName, bName);
-            }
-            h0 = vParams[0];
-            h1 = vParams[1];
-        } else if (nodeName == "excessentropy") {
-            // Get the string containing all of the values
-            getFloatArray(xmlChild, vParams, true, "toSI", "excessEntropy");
-            if (vParams.size() != 2) {
-                throw CanteraError("MargulesVPSSTP::readXMLBinarySpecies"
-                    "excessEntropy for {} : {}: wrong number of params found."
-                    " Need 2", aName, bName);
-            }
-            s0 = vParams[0];
-            s1 = vParams[1];
-        } else if (nodeName == "excessvolume_enthalpy") {
-            // Get the string containing all of the values
-            getFloatArray(xmlChild, vParams, true, "toSI", "excessVolume_Enthalpy");
-            if (vParams.size() != 2) {
-                throw CanteraError("MargulesVPSSTP::readXMLBinarySpecies"
-                    "excessVolume_Enthalpy for {} : {}: wrong number of params"
-                    "  found. Need 2", aName, bName);
-            }
-            vh0 = vParams[0];
-            vh1 = vParams[1];
-        } else if (nodeName == "excessvolume_entropy") {
-            // Get the string containing all of the values
-            getFloatArray(xmlChild, vParams, true, "toSI", "excessVolume_Entropy");
-            if (vParams.size() != 2) {
-                throw CanteraError("MargulesVPSSTP::readXMLBinarySpecies"
-                    "excessVolume_Entropy for {} : {}: wrong number of params"
-                    " found. Need 2", aName, bName);
-            }
-            vs0 = vParams[0];
-            vs1 = vParams[1];
-        }
-    }
-    addBinaryInteraction(aName, bName, h0, h1, s0, s1, vh0, vh1, vs0, vs1);
-}
-
 }
