@@ -55,18 +55,6 @@ double MixtureFugacityTP::entropy_mole() const
     return s_ideal + s_nonideal;
 }
 
-// ---- Partial Molar Properties of the Solution -----------------
-
-void MixtureFugacityTP::getChemPotentials_RT(double* muRT) const
-{
-    warn_deprecated("MixtureFugacityTP::getChemPotentials_RT",
-                    "To be removed after Cantera 3.0. Use getChemPotentials instead.");
-    getChemPotentials(muRT);
-    for (size_t k = 0; k < m_kk; k++) {
-        muRT[k] *= 1.0 / RT();
-    }
-}
-
 // ----- Thermodynamic Values for the Species Standard States States ----
 
 void MixtureFugacityTP::getStandardChemPotentials(double* g) const
@@ -904,9 +892,9 @@ int MixtureFugacityTP::solveCubic(double T, double pres, double a, double b,
             if (fabs(tmp) > 1.0E-4) {
                 for (int j = 0; j < 3; j++) {
                     if (j != i && fabs(Vroot[i] - Vroot[j]) < 1.0E-4 * (fabs(Vroot[i]) + fabs(Vroot[j]))) {
-                        writelog("MixtureFugacityTP::solveCubic(T ={}, p ={}):"
-                                 " WARNING roots have merged: {}, {}\n",
-                                 T, pres, Vroot[i], Vroot[j]);
+                        warn_user("MixtureFugacityTP::solveCubic",
+                                  "roots have merged for T = {}, p = {}: {}, {}",
+                                  T, pres, Vroot[i], Vroot[j]);
                     }
                 }
             }
@@ -966,9 +954,9 @@ int MixtureFugacityTP::solveCubic(double T, double pres, double a, double b,
             }
         }
         if ((fabs(res) > 1.0E-14) && (fabs(res) > 1.0E-14 * fabs(dresdV) * fabs(Vroot[i]))) {
-            writelog("MixtureFugacityTP::solveCubic(T = {}, p = {}): "
-                "WARNING root didn't converge V = {}", T, pres, Vroot[i]);
-            writelogendl();
+            throw CanteraError("MixtureFugacityTP::solveCubic",
+                               "root failed to converge for T = {}, p = {} with "
+                               "V = {}", T, pres, Vroot[i]);
         }
     }
 
