@@ -780,4 +780,16 @@ int PengRobinson::solveCubic(double T, double pres, double a, double b, double a
                                          an, bn, cn, dn, tc, vc);
 }
 
+AnyMap PengRobinson::getAuxiliaryData()
+{
+    AnyMap parameters = ThermoPhase::getAuxiliaryData();
+
+    parameters["aAlpha_mix"] = m_aAlpha_mix;
+    parameters["b_mix"] = m_b;
+    parameters["daAlpha_dT"] = daAlpha_dT();
+    parameters["d2aAlpha_dT2"] = d2aAlpha_dT2();
+
+    return parameters;
+}
+
 }
