@@ -131,83 +131,6 @@ void ThermoPhase::setState_TP(double t, double p)
     }
 }
 
-void ThermoPhase::setState_RPX(double rho, double p, const double* x)
-{
-    warn_deprecated("ThermoPhase::setState_RPX",
-        "To be removed after Cantera 3.0. Replaceable by calls to "
-        "setMoleFractions and setState_DP.");
-    setMoleFractions(x);
-    setState_DP(rho, p);
-}
-
-void ThermoPhase::setState_RPX(double rho, double p, const Composition& x)
-{
-    warn_deprecated("ThermoPhase::setState_RPX",
-        "To be removed after Cantera 3.0. Replaceable by calls to "
-        "setMoleFractionsByName and setState_DP.");
-    setMoleFractionsByName(x);
-    setState_DP(rho, p);
-}
-
-void ThermoPhase::setState_RPX(double rho, double p, const string& x)
-{
-    warn_deprecated("ThermoPhase::setState_RPX",
-        "To be removed after Cantera 3.0. Replaceable by calls to "
-        "setMoleFractionsByName and setState_DP.");
-    setMoleFractionsByName(x);
-    setState_DP(rho, p);
-}
-
-void ThermoPhase::setState_RPY(double rho, double p, const double* y)
-{
-    warn_deprecated("ThermoPhase::setState_RPY",
-        "To be removed after Cantera 3.0. Replaceable by calls to "
-        "setMassFractions and setState_DP.");
-    setMassFractions(y);
-    setState_DP(rho, p);
-}
-
-void ThermoPhase::setState_RPY(double rho, double p, const Composition& y)
-{
-    warn_deprecated("ThermoPhase::setState_RPY",
-        "To be removed after Cantera 3.0. Replaceable by calls to "
-        "setMassFractionsByName and setState_DP.");
-    setMassFractionsByName(y);
-    setState_DP(rho, p);
-}
-
-void ThermoPhase::setState_RPY(double rho, double p, const string& y)
-{
-    warn_deprecated("ThermoPhase::setState_RPY",
-        "To be removed after Cantera 3.0. Replaceable by calls to "
-        "setMassFractionsByName and setState_DP.");
-    setMassFractionsByName(y);
-    setState_DP(rho, p);
-}
-
-void ThermoPhase::setState_RP(double rho, double p)
-{
-    warn_deprecated("ThermoPhase::setState_RP",
-        "To be removed after Cantera 3.0. Renamed to setState_DP.");
-    setState_DP(rho, p);
-}
-
-void ThermoPhase::setState_PX(double p, double* x)
-{
-    warn_deprecated("ThermoPhase::setState_PX", "To be removed after Cantera 3.0. "
-        "Call 'setMoleFractions' and 'setPressure' instead.");
-    setMoleFractions(x);
-    setPressure(p);
-}
-
-void ThermoPhase::setState_PY(double p, double* y)
-{
-    warn_deprecated("ThermoPhase::setState_PX", "To be removed after Cantera 3.0. "
-        "Call 'setMassFractions' and 'setPressure' instead.");
-    setMassFractions(y);
-    setPressure(p);
-}
-
 void ThermoPhase::setState_HP(double Htarget, double p, double rtol)
 {
     setState_HPorUV(Htarget, p, rtol, false);
@@ -1368,7 +1291,7 @@ string ThermoPhase::report(bool show_thermo, double threshold) const
 
     string one_property = fmt::format("{{:>{}}}   {{:<.5g}} {{}}\n", name_width);
 
-    string two_prop_header = "{}   {:^15}   {:^15}\n";
+    constexpr auto two_prop_header = "{}   {:^15}   {:^15}\n";
     string kg_kmol_header = fmt::format(
         two_prop_header, blank_leader, "1 kg", "1 kmol"
     );
@@ -1484,75 +1407,4 @@ string ThermoPhase::report(bool show_thermo, double threshold) const
     return to_string(b);
 }
 
-void ThermoPhase::reportCSV(std::ofstream& csvFile) const
-{
-    warn_deprecated("ThermoPhase::reportCSV", "To be removed after Cantera 3.0.");
-    int tabS = 15;
-    int tabM = 30;
-    csvFile.precision(8);
-    vector<double> X(nSpecies());
-    getMoleFractions(&X[0]);
-    vector<string> pNames;
-    vector<vector<double>> data;
-    getCsvReportData(pNames, data);
-
-    csvFile << setw(tabS) << "Species,";
-    for (size_t i = 0; i < pNames.size(); i++) {
-        csvFile << setw(tabM) << pNames[i] << ",";
-    }
-    csvFile << endl;
-    for (size_t k = 0; k < nSpecies(); k++) {
-        csvFile << setw(tabS) << speciesName(k) + ",";
-        if (X[k] > SmallNumber) {
-            for (size_t i = 0; i < pNames.size(); i++) {
-                csvFile << setw(tabM) << data[i][k] << ",";
-            }
-            csvFile << endl;
-        } else {
-            for (size_t i = 0; i < pNames.size(); i++) {
-                csvFile << setw(tabM) << 0 << ",";
-            }
-            csvFile << endl;
-        }
-    }
-}
-
-void ThermoPhase::getCsvReportData(vector<string>& names,
-                                   vector<vector<double>>& data) const
-{
-    warn_deprecated("ThermoPhase::getCsvReportData", "To be removed after Cantera 3.0.");
-    names.clear();
-    data.assign(10, vector<double>(nSpecies()));
-
-    names.push_back("X");
-    getMoleFractions(&data[0][0]);
-
-    names.push_back("Y");
-    getMassFractions(&data[1][0]);
-
-    names.push_back("Chem. Pot (J/kmol)");
-    getChemPotentials(&data[2][0]);
-
-    names.push_back("Activity");
-    getActivities(&data[3][0]);
-
-    names.push_back("Act. Coeff.");
-    getActivityCoefficients(&data[4][0]);
-
-    names.push_back("Part. Mol Enthalpy (J/kmol)");
-    getPartialMolarEnthalpies(&data[5][0]);
-
-    names.push_back("Part. Mol. Entropy (J/K/kmol)");
-    getPartialMolarEntropies(&data[6][0]);
-
-    names.push_back("Part. Mol. Energy (J/kmol)");
-    getPartialMolarIntEnergies(&data[7][0]);
-
-    names.push_back("Part. Mol. Cp (J/K/kmol");
-    getPartialMolarCp(&data[8][0]);
-
-    names.push_back("Part. Mol. Cv (J/K/kmol)");
-    getPartialMolarVolumes(&data[9][0]);
-}
-
 }
