@@ -68,6 +68,10 @@ void TransportFactory::deleteFactory()
 Transport* TransportFactory::newTransport(const string& transportModel,
         ThermoPhase* phase, int log_level)
 {
+    if (log_level != -7) {
+        warn_deprecated("TransportFactory::newTransport", "The log_level parameter "
+            "is deprecated and will be removed after Cantera 3.1.");
+    }
     if (transportModel != "DustyGas" && canonicalize(transportModel) == "none") {
         return create(transportModel);
     }
@@ -98,6 +102,10 @@ Transport* TransportFactory::newTransport(const string& transportModel,
 
 Transport* TransportFactory::newTransport(ThermoPhase* phase, int log_level)
 {
+    if (log_level != -7) {
+        warn_deprecated("TransportFactory::newTransport", "The log_level parameter "
+            "is deprecated and will be removed after Cantera 3.1.");
+    }
     string transportModel = "none";
     AnyMap& input = phase->input();
     if (input.hasKey("transport")) {
@@ -106,44 +114,15 @@ Transport* TransportFactory::newTransport(ThermoPhase* phase, int log_level)
     return newTransport(transportModel, phase,log_level);
 }
 
-Transport* newTransportMgr(const string& model, ThermoPhase* thermo, int log_level)
-{
-    warn_deprecated("newTransportMgr",
-        "To be removed after Cantera 3.0; superseded by newTransport.");
-    TransportFactory* f = TransportFactory::factory();
-    return f->newTransport(model, thermo, log_level);
-}
-
 shared_ptr<Transport> newTransport(shared_ptr<ThermoPhase> thermo, const string& model)
 {
     Transport* tr;
     if (model == "default") {
-        tr = TransportFactory::factory()->newTransport(thermo.get(), 0);
+        tr = TransportFactory::factory()->newTransport(thermo.get());
     } else {
-        tr = TransportFactory::factory()->newTransport(model, thermo.get(), 0);
+        tr = TransportFactory::factory()->newTransport(model, thermo.get());
     }
     return shared_ptr<Transport>(tr);
 }
 
-shared_ptr<Transport> newTransport(ThermoPhase* thermo, const string& model)
-{
-    warn_deprecated("newTransport",
-        "To be removed after Cantera 3.0; superseded by\n"
-        "newTransport(shared_ptr<ThermoPhase>, const string&).");
-    Transport* tr;
-    if (model == "default") {
-        tr = TransportFactory::factory()->newTransport(thermo, 0);
-    } else {
-        tr = TransportFactory::factory()->newTransport(model, thermo, 0);
-    }
-    return shared_ptr<Transport>(tr);
-}
-
-Transport* newDefaultTransportMgr(ThermoPhase* thermo, int loglevel)
-{
-    warn_deprecated("newDefaultTransportMgr",
-        "To be removed after Cantera 3.0; superseded by newTransport.");
-    return TransportFactory::factory()->newTransport(thermo, loglevel);
-}
-
 }
