@@ -13,15 +13,15 @@
 namespace Cantera
 {
 
-void IdealGasReactor::setThermoMgr(ThermoPhase& thermo)
+void IdealGasReactor::setThermo(ThermoPhase& thermo)
 {
     //! @todo: Add a method to ThermoPhase that indicates whether a given
     //! subclass is compatible with this reactor model
     if (thermo.type() != "ideal-gas") {
-        throw CanteraError("IdealGasReactor::setThermoMgr",
+        throw CanteraError("IdealGasReactor::setThermo",
                            "Incompatible phase type provided");
     }
-    Reactor::setThermoMgr(thermo);
+    Reactor::setThermo(thermo);
 }
 
 void IdealGasReactor::getState(double* y)
