@@ -22,9 +22,19 @@ namespace bmt = boost::math::tools;
 namespace Cantera
 {
 
-void Reactor::insert(shared_ptr<Solution> sol) {
-    setThermoMgr(*sol->thermo());
-    setKineticsMgr(*sol->kinetics());
+Reactor::Reactor(shared_ptr<Solution> sol, const string& name)
+    : ReactorBase(name)
+{
+    if (!sol || !(sol->thermo())) {
+        warn_deprecated("Reactor::Reactor",
+            "Creation of empty reactor objects is deprecated in Cantera 3.1 and will "
+            "raise\nexceptions thereafter; reactor contents should be provided in the "
+            "constructor.");
+        return;
+    }
+    setSolution(sol);
+    setThermo(*sol->thermo());
+    setKinetics(*sol->kinetics());
 }
 
 void Reactor::setDerivativeSettings(AnyMap& settings)
@@ -36,7 +46,7 @@ void Reactor::setDerivativeSettings(AnyMap& settings)
     }
 }
 
-void Reactor::setKineticsMgr(Kinetics& kin)
+void Reactor::setKinetics(Kinetics& kin)
 {
     m_kin = &kin;
     if (m_kin->nReactions() == 0) {
@@ -298,10 +308,8 @@ void Reactor::evalSurfaces(double* LHS, double* RHS, double* sdot)
         double sum = 0.0;
         S->syncState();
         kin->getNetProductionRates(&m_work[0]);
-        size_t ns = kin->reactionPhaseIndex();
-        size_t surfloc = kin->kineticsSpeciesIndex(0,ns);
         for (size_t k = 1; k < nk; k++) {
-            RHS[loc + k] = m_work[surfloc + k] * rs0 * surf->size(k);
+            RHS[loc + k] = m_work[k] * rs0 * surf->size(k);
             sum -= RHS[loc + k];
         }
         RHS[loc] = sum;
@@ -382,10 +390,8 @@ void Reactor::evalSurfaces(double* RHS, double* sdot)
         double sum = 0.0;
         S->syncState();
         kin->getNetProductionRates(&m_work[0]);
-        size_t ns = kin->reactionPhaseIndex();
-        size_t surfloc = kin->kineticsSpeciesIndex(0,ns);
         for (size_t k = 1; k < nk; k++) {
-            RHS[loc + k] = m_work[surfloc + k] * rs0 * surf->size(k);
+            RHS[loc + k] = m_work[k] * rs0 * surf->size(k);
             sum -= RHS[loc + k];
         }
         RHS[loc] = sum;
