@@ -14,7 +14,7 @@ std::mutex WallFactory::wall_mutex;
 
 WallFactory::WallFactory()
 {
-    reg("Wall", []() { return new Wall(); });
+    reg("Wall", [](const string& name) { return new Wall(name); });
 }
 
 WallFactory* WallFactory::factory() {
@@ -31,24 +31,16 @@ void WallFactory::deleteFactory() {
     s_factory = 0;
 }
 
-WallBase* WallFactory::newWall(const string& wallType)
+shared_ptr<WallBase> newWall(const string& model, const string& name)
 {
-    warn_deprecated("WallFactory::newWall",
-        "To be removed after Cantera 3.0; for new behavior, see 'newWall3'.");
-    return create(wallType);
-}
-
-WallBase* newWall(const string& model)
-{
-    warn_deprecated("newWall",
-        "To be changed after Cantera 3.0; for new behavior, see 'newWall3'.");
-    return WallFactory::factory()->newWall(model);
+    return shared_ptr<WallBase>(WallFactory::factory()->create(model, name));
 }
 
 shared_ptr<WallBase> newWall3(const string& model)
 {
-    shared_ptr<WallBase> wptr(WallFactory::factory()->create(model));
-    return wptr;
+    warn_deprecated("newWall3",
+        "Use newWall instead; to be removed after Cantera 3.1.");
+    return newWall(model);
 }
 
 }
