@@ -10,7 +10,8 @@ using namespace Cantera;
 
 TEST(ctmix, new)
 {
-    int thermo = thermo_newFromFile("gri30.yaml", "gri30");
+    int sol = soln_newSolution("gri30.yaml", "gri30", "none");
+    int thermo = soln_thermo(sol);
     int mix = mix_new();
     ASSERT_GE(mix, 0);
     int ret = mix_addPhase(mix, thermo, 1.);
