@@ -8,6 +8,7 @@
 #include "cantera/kinetics/Arrhenius.h"
 #include "cantera/kinetics/ChebyshevRate.h"
 #include "cantera/kinetics/Custom.h"
+#include "cantera/kinetics/ElectronCollisionPlasmaRate.h"
 #include "cantera/kinetics/Falloff.h"
 #include "cantera/kinetics/InterfaceRate.h"
 #include "cantera/kinetics/PlogRate.h"
@@ -531,6 +532,30 @@ TEST(Reaction, TwoTempPlasmaFromYaml)
     EXPECT_DOUBLE_EQ(rate->activationElectronEnergy(), 700 * GasConstant);
 }
 
+TEST(Reaction, ElectronCollisionPlasmaFromYaml)
+{
+    auto sol = newSolution("oxygen-plasma.yaml", "", "none");
+    AnyMap rxn = AnyMap::fromYamlString(
+        "{equation: O2 + E => E + O2,"
+        " type: electron-collision-plasma,"
+        " energy-levels: [0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0],"
+        " cross-sections: [0.0, 5.97e-20, 6.45e-20, 6.74e-20, 6.93e-20, 7.2e-20, "
+        " 7.52e-20, 7.86e-20, 8.21e-20, 8.49e-20, 8.8e-20]}");
+
+    auto R = newReaction(rxn, *(sol->kinetics()));
+    EXPECT_EQ(R->reactants.at("O2"), 1);
+    EXPECT_EQ(R->reactants.at("E"), 1);
+    EXPECT_EQ(R->products.at("O2"), 1);
+    EXPECT_EQ(R->products.at("E"), 1);
+
+    const auto rate = std::dynamic_pointer_cast<ElectronCollisionPlasmaRate>(R->rate());
+
+    for (size_t k = 0; k < rate->energyLevels().size(); k++) {
+        EXPECT_DOUBLE_EQ(rate->energyLevels()[k], rxn["energy-levels"].asVector<double>()[k]);
+        EXPECT_DOUBLE_EQ(rate->crossSections()[k], rxn["cross-sections"].asVector<double>()[k]);
+    }
+}
+
 TEST(Reaction, PythonExtensibleRate)
 {
     #ifdef CT_SKIP_PYTHON // Possibly set via test/SConscript
@@ -546,7 +571,7 @@ TEST(Reaction, PythonExtensibleRate)
     EXPECT_DOUBLE_EQ(kf[0], 3.14 * 300 * 300);
 }
 
-TEST(Kinetics, GasKineticsFromYaml1)
+TEST(Kinetics, BulkKineticsFromYaml1)
 {
     AnyMap infile = AnyMap::fromYamlFile("ideal-gas.yaml");
     auto& phaseNode = infile["phases"].getMapWhere("name", "simple-kinetics");
@@ -561,7 +586,7 @@ TEST(Kinetics, GasKineticsFromYaml1)
     EXPECT_DOUBLE_EQ(rate->preExponentialFactor(), 2.7e10);
 }
 
-TEST(Kinetics, GasKineticsFromYaml2)
+TEST(Kinetics, BulkKineticsFromYaml2)
 {
     AnyMap infile = AnyMap::fromYamlFile("ideal-gas.yaml");
     auto& phaseNode = infile["phases"].getMapWhere("name", "remote-kinetics");
@@ -682,7 +707,7 @@ TEST(KineticsFromYaml, KineticsModelWithReactionsNone1)
 {
     auto soln = newSolution("phase-reaction-spec1.yaml",
                             "kinetics-reactions-none");
-    EXPECT_EQ(soln->kinetics()->kineticsType(), "gas");
+    EXPECT_EQ(soln->kinetics()->kineticsType(), "bulk");
     EXPECT_EQ(soln->kinetics()->nReactions(), (size_t) 0);
 }
 
@@ -690,7 +715,7 @@ TEST(KineticsFromYaml, KineticsModelWithReactionsNone2)
 {
     auto soln = newSolution("phase-reaction-spec2.yaml",
                             "kinetics-reactions-none");
-    EXPECT_EQ(soln->kinetics()->kineticsType(), "gas");
+    EXPECT_EQ(soln->kinetics()->kineticsType(), "bulk");
     EXPECT_EQ(soln->kinetics()->nReactions(), (size_t) 0);
 }
 
@@ -727,7 +752,7 @@ TEST(KineticsFromYaml, KineticsModelWithoutReactionsField)
 {
     auto soln = newSolution("phase-reaction-spec2.yaml",
                             "kinetics-noreactions");
-    EXPECT_EQ(soln->kinetics()->kineticsType(), "gas");
+    EXPECT_EQ(soln->kinetics()->kineticsType(), "bulk");
     EXPECT_EQ(soln->kinetics()->nReactions(), (size_t) 1);
 }
 
