@@ -3,9 +3,6 @@ clear all
 % Copy library to test folder
 ctTestPath;
 
-% Load Cantera
-rootDir = getenv('CANTERA_ROOT');
-
 if ispc
     ctName = '/build/lib/cantera_shared.dll';
 elseif ismac
@@ -15,9 +12,9 @@ elseif isunix
 end
 % Load Cantera
 if ~libisloaded('libcantera_shared')
-    [~, warnings] = loadlibrary([rootDir, ctName], ...
-                                [rootDir, '/include/cantera/clib/ctmatlab.h'], ...
-                                'includepath', [rootDir, '/include'], ...
+    [~, warnings] = loadlibrary([cantera_root, ctName], ...
+                                [cantera_root, '/include/cantera/clib/ctmatlab.h'], ...
+                                'includepath', [cantera_root, '/include'], ...
                                 'addheader', 'ct', 'addheader', 'ctfunc', ...
                                 'addheader', 'ctmultiphase', 'addheader', ...
                                 'ctonedim', 'addheader', 'ctreactor', ...
