@@ -1,10 +1,14 @@
-from contextlib import nullcontext
 from dataclasses import dataclass
 from typing import Optional, Tuple, Dict
-import sys
 
 import pytest
-pytest.importorskip("pint", "0.17.0")
+try:
+    pint = pytest.importorskip("pint", "0.17.0")
+except TypeError as e:
+    # The extra exception handling is here because pint is incompatible with
+    # Python 3.13. Once https://github.com/hgrecco/pint/issues/1969 is resolved the
+    # try/except here can be restored to just the importorskip.
+    pytest.skip(f"pint import failed due to {e}", allow_module_level=True)
 import cantera.with_units as ctu
 import cantera as ct
 try:
